/*
 
                                                                          
         File:   makek101.c                                              
                                                                          
  Description:   Generate the binary 101-key keyboard resources          
                                                                          
 
                                                                          
                  Copyright (C) 1999 Symantec Corporation                 
                             All Rights Reserved                          
                                                                          
       Information in this file is proprietary and confidential, and      
         may not be copied, reproduced or distributed in any manner       
     without the express written permission of Symantec Corp.             
                                                                          
 
*/

#define  STRICT
#include <windows.h>
#include <stdio.h>
#include <string.h>
#include "gpwindlx.h"
#include "pwdlx.h"
#include "menudlx.h"
#include "kbdredlx.h"

#define DEBUG_KBD 1

typedef struct                // info about the function a key performs, and
{                             // appropriate indexes into the string heap and
   unsigned char vkeytype;    // internal function table
   unsigned char funcndx;
   unsigned int strndx;
}  VIRT_KEY_CODE_STRUCT;

typedef struct                // struct for a single key's type and contents
{                             // to be filled in when creating resource
   VIRT_KEY_CODE_STRUCT vks;
   unsigned char strsize;     // length of following mapped string
   unsigned char str[20];     // mapped string contents - no length byte at front
}  MAP_STRING_STRUCT;

typedef struct                // struct to create a resource for an entire
{                             // emulation
   char szResName[16];                    // resource name to create
   unsigned heapsize;
   unsigned Flag1;
   unsigned Flag2;
   MAP_STRING_STRUCT mss[NUMMAPSTRINGS];  // table of string resources
}  EMUL_RES_STRUCT;


#if DEBUG_KBD

EMUL_RES_STRUCT _far ers0  =           // TTY
{
// ers.szResName
   "simpkbd0.101",
// ers.heapsize
   0,                                  // not calculated yet!
// ers.Flag1
   0,
// ers.Flag2
   0,
// ers.mss[NUMMAPSTRINGS]
   {
//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      ,  0 },  4, "bksp"            }, //bksp        0
  {{ KBD_MAPECHO,KFN_NOP      ,  1 },  3, "tab"             }, //tab         1
  {{ KBD_MAPTEXT,KFN_NOP      ,  2 },  5, "clear"           }, //clear       2
  {{ KBD_MAPECHO,KFN_NOP      ,  3 },  5, "enter"           }, //enter       3
  {{ KBD_MAPECHO,KFN_NOP      ,  4 },  8, "pd enter"        }, //pd ent      4
  {{ KBD_MAPTEXT,KFN_NOP      ,  5 },  5, "pause"           }, //pause       5

  {{ KBD_MAPTEXT,KFN_NOP      ,  6 },  7, "pd pgup"         }, //pd pgup     6
  {{ KBD_MAPTEXT,KFN_NOP      ,  7 },  7, "pd pgdn"         }, //pd pgdn     7
  {{ KBD_MAPTEXT,KFN_NOP      ,  8 },  6, "pd end"          }, //pd end      8
  {{ KBD_MAPECHO,KFN_NOP      ,  9 },  7, "pd home"         }, //pd home     9
  {{ KBD_MAPECHO,KFN_NOP      , 10 },  7, "pd left"         }, //pd left    10
  {{ KBD_MAPECHO,KFN_NOP      , 11 },  5, "pd up"           }, //pd up      11
  {{ KBD_MAPECHO,KFN_NOP      , 12 },  8, "pd right"        }, //pd right   12
  {{ KBD_MAPECHO,KFN_NOP      , 13 },  7, "pd down"         }, //pd down    13

  {{ KBD_MAPTEXT,KFN_NOP      , 14 },  7, "gr pgup"         }, //gr pgup    14
  {{ KBD_MAPTEXT,KFN_NOP      , 15 },  7, "gr pgdn"         }, //gr pgdn    15
  {{ KBD_MAPTEXT,KFN_NOP      , 16 },  6, "gr end"          }, //gr end     16
  {{ KBD_MAPECHO,KFN_NOP      , 17 },  7, "gr home"         }, //gr home    17
  {{ KBD_MAPECHO,KFN_NOP      , 18 },  7, "gr left"         }, //gr left    18
  {{ KBD_MAPECHO,KFN_NOP      , 19 },  5, "gr up"           }, //gr up      19
  {{ KBD_MAPECHO,KFN_NOP      , 20 },  8, "gr right"        }, //gr right   20
  {{ KBD_MAPECHO,KFN_NOP      , 21 },  7, "gr down"         }, //gr down    21

  {{ KBD_MAPECHO,KFN_NOP      , 22 },  6, "pd ins"          }, //pd ins     22
  {{ KBD_MAPECHO,KFN_NOP      , 23 },  6, "pd del"          }, //pd del     23
  {{ KBD_MAPECHO,KFN_NOP      , 24 },  6, "gr ins"          }, //gr ins     24
  {{ KBD_MAPECHO,KFN_NOP      , 25 },  6, "gr del"          }, //gr del     25

  {{ KBD_NA_____,KFN_NOP      , 26 },  5, "numlk"           }, //numlk      26
  {{ KBD_MAPTEXT,KFN_NOP      , 27 },  5, "scrlk"           }, //scrlk      27

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 28 },  4, "pd 0" },            //pd 0       28
  {{ KBD_MAPTEXT,KFN_NOP      , 29 },  4, "pd 1" },            //pd 1       29
  {{ KBD_MAPTEXT,KFN_NOP      , 30 },  4, "pd 2" },            //pd 2       30
  {{ KBD_MAPTEXT,KFN_NOP      , 31 },  4, "pd 3" },            //pd 3       31
  {{ KBD_MAPTEXT,KFN_NOP      , 32 },  4, "pd 4" },            //pd 4       32
  {{ KBD_MAPTEXT,KFN_NOP      , 33 },  4, "pd 5" },            //pd 5       33
  {{ KBD_MAPTEXT,KFN_NOP      , 34 },  4, "pd 6" },            //pd 6       34
  {{ KBD_MAPTEXT,KFN_NOP      , 35 },  4, "pd 7" },            //pd 7       35
  {{ KBD_MAPTEXT,KFN_NOP      , 36 },  4, "pd 8" },            //pd 8       36
  {{ KBD_MAPTEXT,KFN_NOP      , 37 },  4, "pd 9" },            //pd 9       37

  {{ KBD_MAPTEXT,KFN_NOP      , 38 },  4, "pd *" },            //pd *       38
  {{ KBD_MAPTEXT,KFN_NOP      , 39 },  4, "pd +" },            //pd +       39
  {{ KBD_MAPTEXT,KFN_NOP      , 40 },  4, "pd -" },            //pd -       40
  {{ KBD_MAPTEXT,KFN_NOP      , 41 },  4, "pd ." },            //pd .       41
  {{ KBD_MAPTEXT,KFN_NOP      , 42 },  4, "pd /" },            //pd /       42

  {{ KBD_MAPTEXT,KFN_NOP      , 43 },  2, "F1"   },            //F1         43
  {{ KBD_MAPTEXT,KFN_NOP      , 44 },  2, "F2"   },            //F2         44
  {{ KBD_MAPTEXT,KFN_NOP      , 45 },  2, "F3"   },            //F3         45
  {{ KBD_MAPTEXT,KFN_NOP      , 46 },  2, "F4"   },            //F4         46
  {{ KBD_MAPTEXT,KFN_NOP      , 47 },  2, "F5"   },            //F5         47
  {{ KBD_MAPTEXT,KFN_NOP      , 48 },  2, "F6"   },            //F6         48
  {{ KBD_MAPTEXT,KFN_NOP      , 49 },  2, "F7"   },            //F7         49
  {{ KBD_MAPTEXT,KFN_NOP      , 50 },  2, "F8"   },            //F8         50
  {{ KBD_MAPTEXT,KFN_NOP      , 51 },  2, "F9"   },            //F9         51
  {{ KBD_MAPTEXT,KFN_NOP      , 52 },  3, "F10"  },            //F10        52
  {{ KBD_MAPTEXT,KFN_NOP      , 53 },  3, "F11"  },            //F11        53
  {{ KBD_MAPTEXT,KFN_NOP      , 54 },  3, "F12"  },            //F12        54

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 55 },  7, "sh bksp"         }, //sh bksp    55
  {{ KBD_MAPTEXT,KFN_NOP      , 56 },  6, "sh tab"          }, //sh tab     56
  {{ KBD_MAPTEXT,KFN_NOP      , 57 },  6, "sh clr"          }, //sh clr     57
  {{ KBD_MAPTEXT,KFN_NOP      , 58 },  6, "sh ent"          }, //sh ent     58
  {{ KBD_MAPTEXT,KFN_NOP      , 59 },  9, "sh pd ent"       }, //sh pd ent  59
  {{ KBD_MAPTEXT,KFN_NOP      , 60 },  8, "sh pause"        }, //sh pause   60

  {{ KBD_MAPTEXT,KFN_NOP      , 61 },  8, "sh pd pu"        }, //sh pd pu   61
  {{ KBD_MAPTEXT,KFN_NOP      , 62 },  8, "sh pd pd"        }, //sh pd pd   62
  {{ KBD_MAPTEXT,KFN_NOP      , 63 },  8, "sh pd en"        }, //sh pd en   63
  {{ KBD_MAPTEXT,KFN_NOP      , 64 },  8, "sh pd hm"        }, //sh pd hm   64
  {{ KBD_MAPTEXT,KFN_NOP      , 65 },  8, "sh pd lf"        }, //sh pd lf   65
  {{ KBD_MAPTEXT,KFN_NOP      , 66 },  8, "sh pd up"        }, //sh pd up   66
  {{ KBD_MAPTEXT,KFN_NOP      , 67 },  8, "sh pd rt"        }, //sh pd rt   67
  {{ KBD_MAPTEXT,KFN_NOP      , 68 },  8, "sh pd dn"        }, //sh pd dn   68

  {{ KBD_MAPTEXT,KFN_NOP      , 69 },  8, "sh gr pu"        }, //sh gr pu   69
  {{ KBD_MAPTEXT,KFN_NOP      , 70 },  8, "sh gr pd"        }, //sh gr pd   70
  {{ KBD_MAPTEXT,KFN_NOP      , 71 },  8, "sh gr en"        }, //sh gr en   71
  {{ KBD_MAPTEXT,KFN_NOP      , 72 },  8, "sh gr hm"        }, //sh gr hm   72
  {{ KBD_MAPTEXT,KFN_NOP      , 73 },  8, "sh gr lf"        }, //sh gr lf   73
  {{ KBD_MAPTEXT,KFN_NOP      , 74 },  8, "sh gr up"        }, //sh gr up   74
  {{ KBD_MAPTEXT,KFN_NOP      , 75 },  8, "sh gr rt"        }, //sh gr rt   75
  {{ KBD_MAPTEXT,KFN_NOP      , 76 },  8, "sh gr dn"        }, //sh gr dn   76

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 77 },  9, "sh pd ins"       }, //sh pd ins  77
  {{ KBD_MAPTEXT,KFN_NOP      , 78 },  9, "sh pd del"       }, //sh pd del  78
  {{ KBD_MAPTEXT,KFN_NOP      , 79 },  9, "sh gr ins"       }, //sh gr ins  79
  {{ KBD_MAPTEXT,KFN_NOP      , 80 },  9, "sh gr del"       }, //sh gr del  80

  {{ KBD_MAPTEXT,KFN_NOP      , 81 },  8, "sh numlk"        }, //sh numlk   81
  {{ KBD_MAPTEXT,KFN_NOP      , 82 },  8, "sh scrlk"        }, //sh scrlk   82

  {{ KBD_MAPTEXT,KFN_NOP      , 83 },  7, "sh pd *"         }, //sh pd *    83
  {{ KBD_MAPTEXT,KFN_NOP      , 84 },  7, "sh pd +"         }, //sh pd +    84
  {{ KBD_MAPTEXT,KFN_NOP      , 85 },  7, "sh pd -"         }, //sh pd -    85
  {{ KBD_MAPTEXT,KFN_NOP      , 86 },  7, "sh pd /"         }, //sh pd /    86

  {{ KBD_MAPTEXT,KFN_NOP      , 87 },  5, "sh F1"           }, //sh F1      87
  {{ KBD_MAPTEXT,KFN_NOP      , 88 },  5, "sh F2"           }, //sh F2      88
  {{ KBD_MAPTEXT,KFN_NOP      , 89 },  5, "sh F3"           }, //sh F3      89
  {{ KBD_MAPTEXT,KFN_NOP      , 90 },  5, "sh F4"           }, //sh F4      90
  {{ KBD_MAPTEXT,KFN_NOP      , 91 },  5, "sh F5"           }, //sh F5      91
  {{ KBD_MAPTEXT,KFN_NOP      , 92 },  5, "sh F6"           }, //sh F6      92
  {{ KBD_MAPTEXT,KFN_NOP      , 93 },  5, "sh F7"           }, //sh F7      93
  {{ KBD_MAPTEXT,KFN_NOP      , 94 },  5, "sh F8"           }, //sh F8      94
  {{ KBD_MAPTEXT,KFN_NOP      , 95 },  5, "sh F9"           }, //sh F9      95
  {{ KBD_MAPTEXT,KFN_NOP      , 96 },  6, "sh F10"          }, //sh F10     96
  {{ KBD_MAPTEXT,KFN_NOP      , 97 },  6, "sh F11"          }, //sh F11     97
  {{ KBD_MAPTEXT,KFN_NOP      , 98 },  6, "sh F12"          }, //sh F12     98

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 99 },  7, "ct bksp"         }, //ct bksp    99
  {{ KBD_MAPTEXT,KFN_NOP      ,100 },  6, "ct clr"          }, //ct clr    100
  {{ KBD_MAPTEXT,KFN_NOP      ,101 },  6, "ct ent"          }, //ct ent    101
  {{ KBD_MAPTEXT,KFN_NOP      ,102 },  9, "ct pd ent"       }, //ct pd ent 102
  {{ KBD_MAPTEXT,KFN_NOP      ,103 },  6, "ct pau"          }, //ct pau    103

  {{ KBD_MAPTEXT,KFN_NOP      ,104 },  8, "ct pd pu"        }, //ct pd pu  104
  {{ KBD_MAPTEXT,KFN_NOP      ,105 },  8, "ct pd pd"        }, //ct pd pd  105
  {{ KBD_MAPTEXT,KFN_NOP      ,106 },  8, "ct pd en"        }, //ct pd en  106
  {{ KBD_MAPTEXT,KFN_NOP      ,107 },  8, "ct pd hm"        }, //ct pd hm  107
  {{ KBD_MAPTEXT,KFN_NOP      ,108 },  8, "ct pd lf"        }, //ct pd lf  108
  {{ KBD_MAPTEXT,KFN_NOP      ,109 },  8, "ct pd up"        }, //ct pd up  109
  {{ KBD_MAPTEXT,KFN_NOP      ,110 },  8, "ct pd rt"        }, //ct pd rt  110
  {{ KBD_MAPTEXT,KFN_NOP      ,111 },  8, "ct pd dn"        }, //ct pd dn  111

  {{ KBD_MAPTEXT,KFN_NOP      ,112 },  8, "ct gr pu"        }, //ct gr pu  112
  {{ KBD_MAPTEXT,KFN_NOP      ,113 },  8, "ct gr pd"        }, //ct gr pd  113
  {{ KBD_MAPTEXT,KFN_NOP      ,114 },  8, "ct gr en"        }, //ct gr en  114
  {{ KBD_MAPTEXT,KFN_NOP      ,115 },  8, "ct gr hm"        }, //ct gr hm  115
  {{ KBD_MAPTEXT,KFN_NOP      ,116 },  8, "ct gr lf"        }, //ct gr lf  116
  {{ KBD_MAPTEXT,KFN_NOP      ,117 },  8, "ct gr up"        }, //ct gr up  117
  {{ KBD_MAPTEXT,KFN_NOP      ,118 },  8, "ct gr rt"        }, //ct gr rt  118
  {{ KBD_MAPTEXT,KFN_NOP      ,119 },  8, "ct gr dn"        }, //ct gr dn  119

  {{ KBD_MAPTEXT,KFN_NOP      ,120 },  9, "ct pd ins"       }, //ct pd ins 120
  {{ KBD_MAPTEXT,KFN_NOP      ,121 },  9, "ct pd del"       }, //ct pd del 121
  {{ KBD_MAPTEXT,KFN_NOP      ,122 },  9, "ct gr ins"       }, //ct gr ins 122
  {{ KBD_MAPTEXT,KFN_NOP      ,123 },  9, "ct gr del"       }, //ct gr del 123

  {{ KBD_MAPTEXT,KFN_NOP      ,124 },  8, "ct numlk"        }, //ct numlk  124
  {{ KBD_MAPTEXT,KFN_NOP      ,125 },  8, "ct scrlk"        }, //ct scrlk  125

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,126 },  7, "ct pd 0"         }, //ct pd 0   126
  {{ KBD_MAPTEXT,KFN_NOP      ,127 },  7, "ct pd 1"         }, //ct pd 1   127
  {{ KBD_MAPTEXT,KFN_NOP      ,128 },  7, "ct pd 2"         }, //ct pd 2   128
  {{ KBD_MAPTEXT,KFN_NOP      ,129 },  7, "ct pd 3"         }, //ct pd 3   129
  {{ KBD_MAPTEXT,KFN_NOP      ,130 },  7, "ct pd 4"         }, //ct pd 4   130
  {{ KBD_MAPTEXT,KFN_NOP      ,131 },  7, "ct pd 5"         }, //ct pd 5   131
  {{ KBD_MAPTEXT,KFN_NOP      ,132 },  7, "ct pd 6"         }, //ct pd 6   132
  {{ KBD_MAPTEXT,KFN_NOP      ,133 },  7, "ct pd 7"         }, //ct pd 7   133
  {{ KBD_MAPTEXT,KFN_NOP      ,134 },  7, "ct pd 8"         }, //ct pd 8   134
  {{ KBD_MAPTEXT,KFN_NOP      ,135 },  7, "ct pd 9"         }, //ct pd 9   135

  {{ KBD_MAPTEXT,KFN_NOP      ,136 },  7, "ct pd *"         }, //ct pd *   136
  {{ KBD_MAPTEXT,KFN_NOP      ,137 },  7, "ct pd +"         }, //ct pd +   137
  {{ KBD_MAPTEXT,KFN_NOP      ,138 },  7, "ct pd -"         }, //ct pd -   138
  {{ KBD_MAPTEXT,KFN_NOP      ,139 },  7, "ct pd ."         }, //ct pd .   139
  {{ KBD_MAPTEXT,KFN_NOP      ,140 },  7, "ct pd /"         }, //ct pd /   140

  {{ KBD_MAPTEXT,KFN_NOP      ,141 },  5, "ct F1"           }, //ct F1     141
  {{ KBD_MAPTEXT,KFN_NOP      ,142 },  5, "ct F2"           }, //ct F2     142
  {{ KBD_MAPTEXT,KFN_NOP      ,143 },  5, "ct F3"           }, //ct F3     143
  {{ KBD_MAPTEXT,KFN_NOP      ,144 },  5, "ct F4"           }, //ct F4     144
  {{ KBD_MAPTEXT,KFN_NOP      ,145 },  5, "ct F5"           }, //ct F5     145
  {{ KBD_MAPTEXT,KFN_NOP      ,146 },  5, "ct F6"           }, //ct F6     146
  {{ KBD_MAPTEXT,KFN_NOP      ,147 },  5, "ct F7"           }, //ct F7     147
  {{ KBD_MAPTEXT,KFN_NOP      ,148 },  5, "ct F8"           }, //ct F8     148
  {{ KBD_MAPTEXT,KFN_NOP      ,149 },  5, "ct F9"           }, //ct F9     149
  {{ KBD_MAPTEXT,KFN_NOP      ,150 },  6, "ct F10"          }, //ct F10    150
  {{ KBD_MAPTEXT,KFN_NOP      ,151 },  6, "ct F11"          }, //ct F11    151
  {{ KBD_MAPTEXT,KFN_NOP      ,152 },  6, "ct F12"          }, //ct F12    152

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,153 },  8, "s/c bksp"        }, //s/c bksp  153
  {{ KBD_MAPTEXT,KFN_NOP      ,154 },  7, "s/c clr"         }, //s/c clr   154
  {{ KBD_MAPTEXT,KFN_NOP      ,155 },  7, "s/c ent"         }, //s/c ent   155
  {{ KBD_MAPTEXT,KFN_NOP      ,156 }, 10, "s/c pd ent"      }, //s/c pd ent156
  {{ KBD_MAPTEXT,KFN_NOP      ,157 },  7, "s/c pau"         }, //s/c pau   157

  {{ KBD_MAPTEXT,KFN_NOP      ,158 },  9, "s/c pd pu"       }, //s/c pd pu 158
  {{ KBD_MAPTEXT,KFN_NOP      ,159 },  9, "s/c pd pd"       }, //s/c pd pd 159
  {{ KBD_MAPTEXT,KFN_NOP      ,160 },  9, "s/c pd en"       }, //s/c pd en 160
  {{ KBD_MAPTEXT,KFN_NOP      ,161 },  9, "s/c pd hm"       }, //s/c pd hm 161
  {{ KBD_MAPTEXT,KFN_NOP      ,162 },  9, "s/c pd lf"       }, //s/c pd lf 162
  {{ KBD_MAPTEXT,KFN_NOP      ,163 },  9, "s/c pd up"       }, //s/c pd up 163
  {{ KBD_MAPTEXT,KFN_NOP      ,164 },  9, "s/c pd rt"       }, //s/c pd rt 164
  {{ KBD_MAPTEXT,KFN_NOP      ,165 },  9, "s/c pd dn"       }, //s/c pd dn 165

  {{ KBD_MAPTEXT,KFN_NOP      ,166 },  9, "s/c gr pu"       }, //s/c gr pu 166
  {{ KBD_MAPTEXT,KFN_NOP      ,167 },  9, "s/c gr pd"       }, //s/c gr pd 167
  {{ KBD_MAPTEXT,KFN_NOP      ,168 },  9, "s/c gr en"       }, //s/c gr en 168
  {{ KBD_MAPTEXT,KFN_NOP      ,169 },  9, "s/c gr hm"       }, //s/c gr hm 169
  {{ KBD_MAPTEXT,KFN_NOP      ,170 },  9, "s/c gr lf"       }, //s/c gr lf 170
  {{ KBD_MAPTEXT,KFN_NOP      ,171 },  9, "s/c gr up"       }, //s/c gr up 171
  {{ KBD_MAPTEXT,KFN_NOP      ,172 },  9, "s/c gr rt"       }, //s/c gr rt 172
  {{ KBD_MAPTEXT,KFN_NOP      ,173 },  9, "s/c gr dn"       }, //s/c gr dn 173

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,174 }, 10, "s/c pd ins"      }, //s/c pd ins174
  {{ KBD_MAPTEXT,KFN_NOP      ,175 }, 10, "s/c pd del"      }, //s/c pd del175
  {{ KBD_MAPTEXT,KFN_NOP      ,176 }, 10, "s/c gr ins"      }, //s/c gr ins176
  {{ KBD_MAPTEXT,KFN_NOP      ,177 }, 10, "s/c gr del"      }, //s/c gr del177

  {{ KBD_MAPTEXT,KFN_NOP      ,178 },  9, "s/c numlk"       }, //s/c numlk 178
  {{ KBD_MAPTEXT,KFN_NOP      ,179 },  9, "s/c scrlk"       }, //s/c scrlk 179

  {{ KBD_MAPTEXT,KFN_NOP      ,180 },  8, "s/c pd *"        }, //s/c pd *  180
  {{ KBD_MAPTEXT,KFN_NOP      ,181 },  8, "s/c pd +"        }, //s/c pd +  181
  {{ KBD_MAPTEXT,KFN_NOP      ,182 },  8, "s/c pd -"        }, //s/c pd -  182
  {{ KBD_MAPTEXT,KFN_NOP      ,183 },  8, "s/c pd /"        }, //s/c pd /  183

  {{ KBD_MAPTEXT,KFN_NOP      ,184 },  6, "s/c F1"          }, //s/c F1    184
  {{ KBD_MAPTEXT,KFN_NOP      ,185 },  6, "s/c F2"          }, //s/c F2    185
  {{ KBD_MAPTEXT,KFN_NOP      ,186 },  6, "s/c F3"          }, //s/c F3    186
  {{ KBD_MAPTEXT,KFN_NOP      ,187 },  6, "s/c F4"          }, //s/c F4    187
  {{ KBD_MAPTEXT,KFN_NOP      ,188 },  6, "s/c F5"          }, //s/c F5    188
  {{ KBD_MAPTEXT,KFN_NOP      ,189 },  6, "s/c F6"          }, //s/c F6    189
  {{ KBD_MAPTEXT,KFN_NOP      ,190 },  6, "s/c F7"          }, //s/c F7    190
  {{ KBD_MAPTEXT,KFN_NOP      ,191 },  6, "s/c F8"          }, //s/c F8    191
  {{ KBD_MAPTEXT,KFN_NOP      ,192 },  6, "s/c F9"          }, //s/c F9    192
  {{ KBD_MAPTEXT,KFN_NOP      ,193 },  7, "s/c F10"         }, //s/c F10   193
  {{ KBD_MAPTEXT,KFN_NOP      ,194 },  7, "s/c F11"         }, //s/c F11   194
  {{ KBD_MAPTEXT,KFN_NOP      ,195 },  7, "s/c F12"         }, //s/c F12   195

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,196 },  9, "a/sh bksp"    }, //a/sh bksp    196
  {{ KBD_MAPTEXT,KFN_NOP      ,197 },  8, "a/sh tab"     }, //a/sh tab     197
  {{ KBD_MAPTEXT,KFN_NOP      ,198 },  8, "a/sh clr"     }, //a/sh clr     198
  {{ KBD_MAPTEXT,KFN_NOP      ,199 },  8, "a/sh ent"     }, //a/sh ent     199
  {{ KBD_MAPTEXT,KFN_NOP      ,200 }, 11, "a/sh pd ent"  }, //a/sh pd ent  200
  {{ KBD_MAPTEXT,KFN_NOP      ,201 }, 10, "a/sh pause"   }, //a/sh pause   201

  {{ KBD_MAPTEXT,KFN_NOP      ,202 }, 10, "a/sh pd pu"   }, //a/sh pd pu   202
  {{ KBD_MAPTEXT,KFN_NOP      ,203 }, 10, "a/sh pd pd"   }, //a/sh pd pd   203
  {{ KBD_MAPTEXT,KFN_NOP      ,204 }, 10, "a/sh pd en"   }, //a/sh pd en   204
  {{ KBD_MAPTEXT,KFN_NOP      ,205 }, 10, "a/sh pd hm"   }, //a/sh pd hm   205
  {{ KBD_MAPTEXT,KFN_NOP      ,206 }, 10, "a/sh pd lf"   }, //a/sh pd lf   206
  {{ KBD_MAPTEXT,KFN_NOP      ,207 }, 10, "a/sh pd up"   }, //a/sh pd up   207
  {{ KBD_MAPTEXT,KFN_NOP      ,208 }, 10, "a/sh pd rt"   }, //a/sh pd rt   208
  {{ KBD_MAPTEXT,KFN_NOP      ,209 }, 10, "a/sh pd dn"   }, //a/sh pd dn   209

  {{ KBD_MAPTEXT,KFN_NOP      ,210 }, 10, "a/sh gr pu"   }, //a/sh gr pu   210
  {{ KBD_MAPTEXT,KFN_NOP      ,211 }, 10, "a/sh gr pd"   }, //a/sh gr pd   211
  {{ KBD_MAPTEXT,KFN_NOP      ,212 }, 10, "a/sh gr en"   }, //a/sh gr en   212
  {{ KBD_MAPTEXT,KFN_NOP      ,213 }, 10, "a/sh gr hm"   }, //a/sh gr hm   213
  {{ KBD_MAPTEXT,KFN_NOP      ,214 }, 10, "a/sh gr lf"   }, //a/sh gr lf   214
  {{ KBD_MAPTEXT,KFN_NOP      ,215 }, 10, "a/sh gr up"   }, //a/sh gr up   215
  {{ KBD_MAPTEXT,KFN_NOP      ,216 }, 10, "a/sh gr rt"   }, //a/sh gr rt   216
  {{ KBD_MAPTEXT,KFN_NOP      ,217 }, 10, "a/sh gr dn"   }, //a/sh gr dn   217

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,218 }, 11, "a/sh pd ins"  }, //a/sh pd ins  218
  {{ KBD_MAPTEXT,KFN_NOP      ,219 }, 11, "a/sh pd del"  }, //a/sh pd del  219
  {{ KBD_MAPTEXT,KFN_NOP      ,220 }, 11, "a/sh gr ins"  }, //a/sh gr ins  220
  {{ KBD_MAPTEXT,KFN_NOP      ,221 }, 11, "a/sh gr del"  }, //a/sh gr del  221

  {{ KBD_MAPTEXT,KFN_NOP      ,222 }, 10, "a/sh numlk"   }, //a/sh numlk   222
  {{ KBD_MAPTEXT,KFN_NOP      ,223 }, 10, "a/sh scrlk"   }, //a/sh scrlk   223

  {{ KBD_MAPTEXT,KFN_NOP      ,224 },  9, "a/sh pd *"    }, //a/sh pd *    224
  {{ KBD_MAPTEXT,KFN_NOP      ,225 },  9, "a/sh pd +"    }, //a/sh pd +    225
  {{ KBD_MAPTEXT,KFN_NOP      ,226 },  9, "a/sh pd -"    }, //a/sh pd -    226
  {{ KBD_MAPTEXT,KFN_NOP      ,227 },  9, "a/sh pd /"    }, //a/sh pd /    227

  {{ KBD_MAPTEXT,KFN_NOP      ,228 },  7, "a/sh F1"      }, //a/sh F1      228
  {{ KBD_MAPTEXT,KFN_NOP      ,229 },  7, "a/sh F2"      }, //a/sh F2      229
  {{ KBD_MAPTEXT,KFN_NOP      ,230 },  7, "a/sh F3"      }, //a/sh F3      230
  {{ KBD_MAPTEXT,KFN_NOP      ,231 },  7, "a/sh F4"      }, //a/sh F4      231
  {{ KBD_MAPTEXT,KFN_NOP      ,232 },  7, "a/sh F5"      }, //a/sh F5      232
  {{ KBD_MAPTEXT,KFN_NOP      ,233 },  7, "a/sh F6"      }, //a/sh F6      233
  {{ KBD_MAPTEXT,KFN_NOP      ,234 },  7, "a/sh F7"      }, //a/sh F7      234
  {{ KBD_MAPTEXT,KFN_NOP      ,235 },  7, "a/sh F8"      }, //a/sh F8      235
  {{ KBD_MAPTEXT,KFN_NOP      ,236 },  7, "a/sh F9"      }, //a/sh F9      236
  {{ KBD_MAPTEXT,KFN_NOP      ,237 },  8, "a/sh F10"     }, //a/sh F10     237
  {{ KBD_MAPTEXT,KFN_NOP      ,238 },  8, "a/sh F11"     }, //a/sh F11     238
  {{ KBD_MAPTEXT,KFN_NOP      ,239 },  8, "a/sh F12"     }, //a/sh F12     239

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,240 },  9, "a/ct bksp"    }, //a/ct bksp    240
  {{ KBD_MAPTEXT,KFN_NOP      ,241 },  8, "a/ct tab"     }, //a/ct tab     241
  {{ KBD_MAPTEXT,KFN_NOP      ,242 },  8, "a/ct clr"     }, //a/ct clr     242
  {{ KBD_MAPTEXT,KFN_NOP      ,243 },  8, "a/ct ent"     }, //a/ct ent     243
  {{ KBD_MAPTEXT,KFN_NOP      ,244 }, 11, "a/ct pd ent"  }, //a/ct pd ent  244
  {{ KBD_MAPTEXT,KFN_NOP      ,245 },  8, "a/ct pau"     }, //a/ct pau     245

  {{ KBD_MAPTEXT,KFN_NOP      ,246 }, 10, "a/ct pd pu"   }, //a/ct pd pu   246
  {{ KBD_MAPTEXT,KFN_NOP      ,247 }, 10, "a/ct pd pd"   }, //a/ct pd pd   247
  {{ KBD_MAPTEXT,KFN_NOP      ,248 }, 10, "a/ct pd en"   }, //a/ct pd en   248
  {{ KBD_MAPTEXT,KFN_NOP      ,249 }, 10, "a/ct pd hm"   }, //a/ct pd hm   249
  {{ KBD_MAPTEXT,KFN_NOP      ,250 }, 10, "a/ct pd lf"   }, //a/ct pd lf   250
  {{ KBD_MAPTEXT,KFN_NOP      ,251 }, 10, "a/ct pd up"   }, //a/ct pd up   251
  {{ KBD_MAPTEXT,KFN_NOP      ,252 }, 10, "a/ct pd rt"   }, //a/ct pd rt   252
  {{ KBD_MAPTEXT,KFN_NOP      ,253 }, 10, "a/ct pd dn"   }, //a/ct pd dn   253

  {{ KBD_MAPTEXT,KFN_NOP      ,254 }, 10, "a/ct gr pu"   }, //a/ct gr pu   254
  {{ KBD_MAPTEXT,KFN_NOP      ,255 }, 10, "a/ct gr pd"   }, //a/ct gr pd   255
  {{ KBD_MAPTEXT,KFN_NOP      ,256 }, 10, "a/ct gr en"   }, //a/ct gr en   256
  {{ KBD_MAPTEXT,KFN_NOP      ,257 }, 10, "a/ct gr hm"   }, //a/ct gr hm   257
  {{ KBD_MAPTEXT,KFN_NOP      ,258 }, 10, "a/ct gr lf"   }, //a/ct gr lf   258
  {{ KBD_MAPTEXT,KFN_NOP      ,259 }, 10, "a/ct gr up"   }, //a/ct gr up   259
  {{ KBD_MAPTEXT,KFN_NOP      ,260 }, 10, "a/ct gr rt"   }, //a/ct gr rt   260
  {{ KBD_MAPTEXT,KFN_NOP      ,261 }, 10, "a/ct gr dn"   }, //a/ct gr dn   261

  {{ KBD_MAPTEXT,KFN_NOP      ,262 }, 11, "a/ct pd ins"  }, //a/ct pd ins  262
  {{ KBD_MAPTEXT,KFN_NOP      ,263 }, 11, "a/ct gr ins"  }, //a/ct gr ins  263

  {{ KBD_MAPTEXT,KFN_NOP      ,264 }, 10, "a/ct numlk"   }, //a/ct numlk   264
  {{ KBD_MAPTEXT,KFN_NOP      ,265 }, 10, "a/ct scrlk"   }, //a/ct scrlk   265

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,266 },  9, "a/ct pd 0"    }, //a/ct pd 0    266
  {{ KBD_MAPTEXT,KFN_NOP      ,267 },  9, "a/ct pd 1"    }, //a/ct pd 1    267
  {{ KBD_MAPTEXT,KFN_NOP      ,268 },  9, "a/ct pd 2"    }, //a/ct pd 2    268
  {{ KBD_MAPTEXT,KFN_NOP      ,269 },  9, "a/ct pd 3"    }, //a/ct pd 3    269
  {{ KBD_MAPTEXT,KFN_NOP      ,270 },  9, "a/ct pd 4"    }, //a/ct pd 4    270
  {{ KBD_MAPTEXT,KFN_NOP      ,271 },  9, "a/ct pd 5"    }, //a/ct pd 5    271
  {{ KBD_MAPTEXT,KFN_NOP      ,272 },  9, "a/ct pd 6"    }, //a/ct pd 6    272
  {{ KBD_MAPTEXT,KFN_NOP      ,273 },  9, "a/ct pd 7"    }, //a/ct pd 7    273
  {{ KBD_MAPTEXT,KFN_NOP      ,274 },  9, "a/ct pd 8"    }, //a/ct pd 8    274
  {{ KBD_MAPTEXT,KFN_NOP      ,275 },  9, "a/ct pd 9"    }, //a/ct pd 9    275

  {{ KBD_MAPTEXT,KFN_NOP      ,276 },  9, "a/ct pd *"    }, //a/ct pd *    276
  {{ KBD_MAPTEXT,KFN_NOP      ,277 },  9, "a/ct pd +"    }, //a/ct pd +    277
  {{ KBD_MAPTEXT,KFN_NOP      ,278 },  9, "a/ct pd -"    }, //a/ct pd -    278
  {{ KBD_MAPTEXT,KFN_NOP      ,279 },  9, "a/ct pd ."    }, //a/ct pd .    279
  {{ KBD_MAPTEXT,KFN_NOP      ,280 },  9, "a/ct pd /"    }, //a/ct pd /    280

  {{ KBD_MAPTEXT,KFN_NOP      ,281 },  7, "a/ct F1"      }, //a/ct F1      281
  {{ KBD_MAPTEXT,KFN_NOP      ,282 },  7, "a/ct F2"      }, //a/ct F2      282
  {{ KBD_MAPTEXT,KFN_NOP      ,283 },  7, "a/ct F3"      }, //a/ct F3      283
  {{ KBD_MAPTEXT,KFN_NOP      ,284 },  7, "a/ct F4"      }, //a/ct F4      284
  {{ KBD_MAPTEXT,KFN_NOP      ,285 },  7, "a/ct F5"      }, //a/ct F5      285
  {{ KBD_MAPTEXT,KFN_NOP      ,286 },  7, "a/ct F6"      }, //a/ct F6      286
  {{ KBD_MAPTEXT,KFN_NOP      ,287 },  7, "a/ct F7"      }, //a/ct F7      287
  {{ KBD_MAPTEXT,KFN_NOP      ,288 },  7, "a/ct F8"      }, //a/ct F8      288
  {{ KBD_MAPTEXT,KFN_NOP      ,289 },  7, "a/ct F9"      }, //a/ct F9      289
  {{ KBD_MAPTEXT,KFN_NOP      ,290 },  8, "a/ct F10"     }, //a/ct F10     290
  {{ KBD_MAPTEXT,KFN_NOP      ,291 },  8, "a/ct F11"     }, //a/ct F11     291
  {{ KBD_MAPTEXT,KFN_NOP      ,292 },  8, "a/ct F12"     }, //a/ct F12     292

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,293 }, 10, "a/s/c bksp"   }, //a/s/c bksp   293
  {{ KBD_MAPTEXT,KFN_NOP      ,294 },  9, "a/s/c tab"    }, //a/s/c tab    294
  {{ KBD_MAPTEXT,KFN_NOP      ,295 },  9, "a/s/c clr"    }, //a/s/c clr    295
  {{ KBD_MAPTEXT,KFN_NOP      ,296 },  9, "a/s/c ent"    }, //a/s/c ent    296
  {{ KBD_MAPTEXT,KFN_NOP      ,297 }, 12, "a/s/c pd ent" }, //a/s/c pd ent 297
  {{ KBD_MAPTEXT,KFN_NOP      ,298 },  9, "a/s/c pau"    }, //a/s/c pau    298

  {{ KBD_MAPTEXT,KFN_NOP      ,299 }, 11, "a/s/c pd pu"  }, //a/s/c pd pu  299
  {{ KBD_MAPTEXT,KFN_NOP      ,300 }, 11, "a/s/c pd pd"  }, //a/s/c pd pd  300
  {{ KBD_MAPTEXT,KFN_NOP      ,301 }, 11, "a/s/c pd en"  }, //a/s/c pd en  301
  {{ KBD_MAPTEXT,KFN_NOP      ,302 }, 11, "a/s/c pd hm"  }, //a/s/c pd hm  302
  {{ KBD_MAPTEXT,KFN_NOP      ,303 }, 11, "a/s/c pd lf"  }, //a/s/c pd lf  303
  {{ KBD_MAPTEXT,KFN_NOP      ,304 }, 11, "a/s/c pd up"  }, //a/s/c pd up  304
  {{ KBD_MAPTEXT,KFN_NOP      ,305 }, 11, "a/s/c pd rt"  }, //a/s/c pd rt  305
  {{ KBD_MAPTEXT,KFN_NOP      ,306 }, 11, "a/s/c pd dn"  }, //a/s/c pd dn  306

  {{ KBD_MAPTEXT,KFN_NOP      ,307 }, 11, "a/s/c gr pu"  }, //a/s/c gr pu  307
  {{ KBD_MAPTEXT,KFN_NOP      ,308 }, 11, "a/s/c gr pd"  }, //a/s/c gr pd  308
  {{ KBD_MAPTEXT,KFN_NOP      ,309 }, 11, "a/s/c gr en"  }, //a/s/c gr en  309
  {{ KBD_MAPTEXT,KFN_NOP      ,310 }, 11, "a/s/c gr hm"  }, //a/s/c gr hm  310
  {{ KBD_MAPTEXT,KFN_NOP      ,311 }, 11, "a/s/c gr lf"  }, //a/s/c gr lf  311
  {{ KBD_MAPTEXT,KFN_NOP      ,312 }, 11, "a/s/c gr up"  }, //a/s/c gr up  312
  {{ KBD_MAPTEXT,KFN_NOP      ,313 }, 11, "a/s/c gr rt"  }, //a/s/c gr rt  313
  {{ KBD_MAPTEXT,KFN_NOP      ,314 }, 11, "a/s/c gr dn"  }, //a/s/c gr dn  314

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,315 }, 12, "a/s/c pd ins" }, //a/s/c pd ins 315
  {{ KBD_MAPTEXT,KFN_NOP      ,316 }, 12, "a/s/c gr ins" }, //a/s/c gr ins 316

  {{ KBD_MAPTEXT,KFN_NOP      ,317 }, 11, "a/s/c numlk"  }, //a/s/c numlk  317
  {{ KBD_MAPTEXT,KFN_NOP      ,318 }, 11, "a/s/c scrlk"  }, //a/s/c scrlk  318

  {{ KBD_MAPTEXT,KFN_NOP      ,319 }, 10, "a/s/c pd *"   }, //a/s/c pd *   319
  {{ KBD_MAPTEXT,KFN_NOP      ,320 }, 10, "a/s/c pd +"   }, //a/s/c pd +   320
  {{ KBD_MAPTEXT,KFN_NOP      ,321 }, 10, "a/s/c pd -"   }, //a/s/c pd -   321
  {{ KBD_MAPTEXT,KFN_NOP      ,322 }, 10, "a/s/c pd /"   }, //a/s/c pd /   322

  {{ KBD_MAPTEXT,KFN_NOP      ,323 },  8, "a/s/c F1"     }, //a/s/c F1     323
  {{ KBD_MAPTEXT,KFN_NOP      ,324 },  8, "a/s/c F2"     }, //a/s/c F2     324
  {{ KBD_MAPTEXT,KFN_NOP      ,325 },  8, "a/s/c F3"     }, //a/s/c F3     325
  {{ KBD_MAPTEXT,KFN_NOP      ,326 },  8, "a/s/c F4"     }, //a/s/c F4     326
  {{ KBD_MAPTEXT,KFN_NOP      ,327 },  8, "a/s/c F5"     }, //a/s/c F5     327
  {{ KBD_MAPTEXT,KFN_NOP      ,328 },  8, "a/s/c F6"     }, //a/s/c F6     328
  {{ KBD_MAPTEXT,KFN_NOP      ,329 },  8, "a/s/c F7"     }, //a/s/c F7     329
  {{ KBD_MAPTEXT,KFN_NOP      ,330 },  8, "a/s/c F8"     }, //a/s/c F8     330
  {{ KBD_MAPTEXT,KFN_NOP      ,331 },  8, "a/s/c F9"     }, //a/s/c F9     331
  {{ KBD_MAPTEXT,KFN_NOP      ,332 },  9, "a/s/c F10"    }, //a/s/c F10    332
  {{ KBD_MAPTEXT,KFN_NOP      ,333 },  9, "a/s/c F11"    }, //a/s/c F11    333
  {{ KBD_MAPTEXT,KFN_NOP      ,334 },  9, "a/s/c F12"    }  //a/s/c F12    334

   }
};

#else

EMUL_RES_STRUCT _far ers0  =           // Simpldlt emulation 0
{
// ers.szResName
   "simpkbd0.101",
// ers.heapsize
   0,             // not calculated yet!
// ers.Flag1
   0,
// ers.Flag2
   0,
// ers.mss[NUMMAPSTRINGS]
   {
//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      ,  0 },  1, "\x08"            }, //bksp        0
  {{ KBD_MAPECHO,KFN_NOP      ,  1 },  1, "\x09"            }, //tab         1
  {{ KBD_MAPTEXT,KFN_NOP      ,  2 },  0, ""                }, //clear       2
  {{ KBD_MAPECHO,KFN_NOP      ,  3 },  1, "\x0D"            }, //enter       3
  {{ KBD_MAPECHO,KFN_NOP      ,  4 },  1, "\x1C"            }, //pd ent      4
  {{ KBD_MAPTEXT,KFN_NOP      ,  5 },  0, ""                }, //pause       5

  {{ KBD_MAPTEXT,KFN_NOP      ,  6 },  0, ""                }, //pd pgup     6
  {{ KBD_MAPTEXT,KFN_NOP      ,  7 },  0, ""                }, //pd pgdn     7
  {{ KBD_MAPTEXT,KFN_NOP      ,  8 },  0, ""                }, //pd end      8
  {{ KBD_MAPECHO,KFN_NOP      ,  9 },  1, "\x1E"            }, //pd home     9
  {{ KBD_MAPECHO,KFN_NOP      , 10 },  1, "\x08"            }, //pd left    10
  {{ KBD_MAPECHO,KFN_NOP      , 11 },  1, "\x0B"            }, //pd up      11
  {{ KBD_MAPECHO,KFN_NOP      , 12 },  1, "\x09"            }, //pd right   12
  {{ KBD_MAPECHO,KFN_NOP      , 13 },  1, "\x0A"            }, //pd down    13

  {{ KBD_MAPTEXT,KFN_SEND     , 14 },  0, ""                }, //gr pgup    14
  {{ KBD_MAPTEXT,KFN_RCV      , 15 },  0, ""                }, //gr pgdn    15
  {{ KBD_MAPTEXT,KFN_NOP      , 16 },  0, ""                }, //gr end     16
  {{ KBD_MAPECHO,KFN_NOP      , 17 },  1, "\x1E"            }, //gr home    17
  {{ KBD_MAPECHO,KFN_NOP      , 18 },  1, "\x08"            }, //gr left    18
  {{ KBD_MAPECHO,KFN_NOP      , 19 },  1, "\x0B"            }, //gr up      19
  {{ KBD_MAPECHO,KFN_NOP      , 20 },  1, "\x09"            }, //gr right   20
  {{ KBD_MAPECHO,KFN_NOP      , 21 },  1, "\x0A"            }, //gr down    21

  {{ KBD_MAPECHO,KFN_NOP      , 22 },  0, ""                }, //pd ins     22
  {{ KBD_MAPECHO,KFN_NOP      , 23 },  0, ""                }, //pd del     23
  {{ KBD_MAPECHO,KFN_NOP      , 24 },  0, ""                }, //gr ins     24
  {{ KBD_MAPECHO,KFN_NOP      , 25 },  0, ""                }, //gr del     25

  {{ KBD_NA_____,KFN_NOP      , 26 },  0, ""                }, //numlk      26
  {{ KBD_MAPTEXT,KFN_NOP      , 27 },  0, ""                }, //scrlk      27

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      , 28 },  1, "0"               }, //pd 0       28
  {{ KBD_MAPECHO,KFN_NOP      , 29 },  1, "1"               }, //pd 1       29
  {{ KBD_MAPECHO,KFN_NOP      , 30 },  1, "2"               }, //pd 2       30
  {{ KBD_MAPECHO,KFN_NOP      , 31 },  1, "3"               }, //pd 3       31
  {{ KBD_MAPECHO,KFN_NOP      , 32 },  1, "4"               }, //pd 4       32
  {{ KBD_MAPECHO,KFN_NOP      , 33 },  1, "5"               }, //pd 5       33
  {{ KBD_MAPECHO,KFN_NOP      , 34 },  1, "6"               }, //pd 6       34
  {{ KBD_MAPECHO,KFN_NOP      , 35 },  1, "7"               }, //pd 7       35
  {{ KBD_MAPECHO,KFN_NOP      , 36 },  1, "8"               }, //pd 8       36
  {{ KBD_MAPECHO,KFN_NOP      , 37 },  1, "9"               }, //pd 9       37

  {{ KBD_MAPECHO,KFN_NOP      , 38 },  1, "*"               }, //pd *       38
  {{ KBD_TRMINTL,1            , 39 },  0, ""                }, //pd +       39
  {{ KBD_TRMINTL,2            , 40 },  0, ""                }, //pd -       40
  {{ KBD_MAPECHO,KFN_NOP      , 41 },  1, "."               }, //pd .       41
  {{ KBD_MAPECHO,KFN_NOP      , 42 },  1, "/"               }, //pd /       42

  {{ KBD_MAPTEXT,KFN_NOP      , 43 },  0, ""                }, //F1         43
  {{ KBD_MAPTEXT,KFN_NOP      , 44 },  0, ""                }, //F2         44
  {{ KBD_MAPTEXT,KFN_NOP      , 45 },  0, ""                }, //F3         45
  {{ KBD_MAPTEXT,KFN_NOP      , 46 },  0, ""                }, //F4         46
  {{ KBD_MAPTEXT,KFN_NOP      , 47 },  0, ""                }, //F5         47
  {{ KBD_MAPTEXT,KFN_NOP      , 48 },  0, ""                }, //F6         48
  {{ KBD_MAPTEXT,KFN_NOP      , 49 },  1, "\x13"            }, //F7         49
  {{ KBD_MAPTEXT,KFN_NOP      , 50 },  1, "\x1C"            }, //F8         50
  {{ KBD_MAPTEXT,KFN_NOP      , 51 },  1, "\x1E"            }, //F9         51
  {{ KBD_MAPTEXT,KFN_NOP      , 52 },  0, ""                }, //F10        52
  {{ KBD_MAPTEXT,KFN_NOP      , 53 },  0, ""                }, //F11        53
  {{ KBD_MAPTEXT,KFN_NOP      , 54 },  0, ""                }, //F12        54

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 55 },  0, ""                }, //sh bksp    55
  {{ KBD_MAPTEXT,KFN_NOP      , 56 },  0, ""                }, //sh tab     56
  {{ KBD_MAPTEXT,KFN_NOP      , 57 },  0, ""                }, //sh clr     57
  {{ KBD_MAPTEXT,KFN_NOP      , 58 },  0, ""                }, //sh ent     58
  {{ KBD_MAPTEXT,KFN_NOP      , 59 },  1, "\x1C"            }, //sh pd ent  59
  {{ KBD_MAPTEXT,KFN_NOP      , 60 },  0, ""                }, //sh pause   60

  {{ KBD_MAPTEXT,KFN_NOP      , 61 },  0, ""                }, //sh pd pu   61
  {{ KBD_MAPTEXT,KFN_NOP      , 62 },  0, ""                }, //sh pd pd   62
  {{ KBD_MAPTEXT,KFN_NOP      , 63 },  0, ""                }, //sh pd en   63
  {{ KBD_MAPTEXT,KFN_NOP      , 64 },  0, ""                }, //sh pd hm   64
  {{ KBD_MAPTEXT,KFN_NOP      , 65 },  0, ""                }, //sh pd lf   65
  {{ KBD_MAPTEXT,KFN_NOP      , 66 },  0, ""                }, //sh pd up   66
  {{ KBD_MAPTEXT,KFN_NOP      , 67 },  0, ""                }, //sh pd rt   67
  {{ KBD_MAPTEXT,KFN_NOP      , 68 },  0, ""                }, //sh pd dn   68

  {{ KBD_MAPTEXT,KFN_NOP      , 69 },  0, ""                }, //sh gr pu   69
  {{ KBD_MAPTEXT,KFN_NOP      , 70 },  0, ""                }, //sh gr pd   70
  {{ KBD_MAPTEXT,KFN_NOP      , 71 },  0, ""                }, //sh gr en   71
  {{ KBD_MAPTEXT,KFN_NOP      , 72 },  0, ""                }, //sh gr hm   72
  {{ KBD_MAPTEXT,KFN_NOP      , 73 },  0, ""                }, //sh gr lf   73
  {{ KBD_MAPTEXT,KFN_NOP      , 74 },  0, ""                }, //sh gr up   74
  {{ KBD_MAPTEXT,KFN_NOP      , 75 },  0, ""                }, //sh gr rt   75
  {{ KBD_MAPTEXT,KFN_NOP      , 76 },  0, ""                }, //sh gr dn   76

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 77 },  0, ""                }, //sh pd ins  77
  {{ KBD_MAPTEXT,KFN_NOP      , 78 },  0, ""                }, //sh pd del  78
  {{ KBD_NA_____,KFN_NOP      , 79 },  0, ""                }, //sh gr ins  79
  {{ KBD_MAPTEXT,KFN_NOP      , 80 },  0, ""                }, //sh gr del  80

  {{ KBD_MAPTEXT,KFN_NOP      , 81 },  0, ""                }, //sh numlk   81
  {{ KBD_MAPTEXT,KFN_NOP      , 82 },  0, ""                }, //sh scrlk   82

  {{ KBD_MAPTEXT,KFN_NOP      , 83 },  0, ""                }, //sh pd *    83
  {{ KBD_MAPTEXT,KFN_NOP      , 84 },  0, ""                }, //sh pd +    84
  {{ KBD_MAPTEXT,KFN_NOP      , 85 },  0, ""                }, //sh pd -    85
  {{ KBD_MAPTEXT,KFN_NOP      , 86 },  0, ""                }, //sh pd /    86

  {{ KBD_MAPTEXT,KFN_NOP      , 87 },  0, ""                }, //sh F1      87
  {{ KBD_MAPTEXT,KFN_NOP      , 88 },  0, ""                }, //sh F2      88
  {{ KBD_MAPTEXT,KFN_NOP      , 89 },  0, ""                }, //sh F3      89
  {{ KBD_MAPTEXT,KFN_NOP      , 90 },  0, ""                }, //sh F4      90
  {{ KBD_MAPTEXT,KFN_NOP      , 91 },  0, ""                }, //sh F5      91
  {{ KBD_MAPTEXT,KFN_NOP      , 92 },  0, ""                }, //sh F6      92
  {{ KBD_MAPTEXT,KFN_NOP      , 93 },  0, ""                }, //sh F7      93
  {{ KBD_MAPTEXT,KFN_NOP      , 94 },  0, ""                }, //sh F8      94
  {{ KBD_MAPTEXT,KFN_NOP      , 95 },  0, ""                }, //sh F9      95
  {{ KBD_MAPTEXT,KFN_NOP      , 96 },  0, ""                }, //sh F10     96
  {{ KBD_MAPTEXT,KFN_NOP      , 97 },  0, ""                }, //sh F11     97
  {{ KBD_MAPTEXT,KFN_NOP      , 98 },  0, ""                }, //sh F12     98

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 99 },  0, ""                }, //ct bksp    99
  {{ KBD_MAPTEXT,KFN_NOP      ,100 },  0, ""                }, //ct clr    100
  {{ KBD_MAPTEXT,KFN_NOP      ,101 },  0, ""                }, //ct ent    101
  {{ KBD_MAPTEXT,KFN_NOP      ,102 },  0, ""                }, //ct pd ent 102
  {{ KBD_MAPTEXT,KFN_NOP      ,103 },  0, ""                }, //ct pau    103

  {{ KBD_MAPTEXT,KFN_NOP      ,104 },  0, ""                }, //ct pd pu  104
  {{ KBD_MAPTEXT,KFN_NOP      ,105 },  0, ""                }, //ct pd pd  105
  {{ KBD_MAPTEXT,KFN_NOP      ,106 },  0, ""                }, //ct pd en  106
  {{ KBD_MAPTEXT,KFN_NOP      ,107 },  0, ""                }, //ct pd hm  107
  {{ KBD_MAPTEXT,KFN_NOP      ,108 },  0, ""                }, //ct pd lf  108
  {{ KBD_MAPTEXT,KFN_NOP      ,109 },  0, ""                }, //ct pd up  109
  {{ KBD_MAPTEXT,KFN_NOP      ,110 },  0, ""                }, //ct pd rt  110
  {{ KBD_MAPTEXT,KFN_NOP      ,111 },  0, ""                }, //ct pd dn  111

  {{ KBD_MAPTEXT,KFN_NOP      ,112 },  0, ""                }, //ct gr pu  112
  {{ KBD_MAPTEXT,KFN_NOP      ,113 },  0, ""                }, //ct gr pd  113
  {{ KBD_MAPTEXT,KFN_NOP      ,114 },  0, ""                }, //ct gr en  114
  {{ KBD_MAPTEXT,KFN_NOP      ,115 },  0, ""                }, //ct gr hm  115
  {{ KBD_MAPTEXT,KFN_NOP      ,116 },  0, ""                }, //ct gr lf  116
  {{ KBD_MAPTEXT,KFN_NOP      ,117 },  0, ""                }, //ct gr up  117
  {{ KBD_MAPTEXT,KFN_NOP      ,118 },  0, ""                }, //ct gr rt  118
  {{ KBD_MAPTEXT,KFN_NOP      ,119 },  0, ""                }, //ct gr dn  119

  {{ KBD_MAPTEXT,KFN_NOP      ,120 },  0, ""                }, //ct pd ins 120
  {{ KBD_MAPTEXT,KFN_NOP      ,121 },  0, ""                }, //ct pd del 121
  {{ KBD_MAPTEXT,KFN_NOP      ,122 },  0, ""                }, //ct gr ins 122
  {{ KBD_MAPTEXT,KFN_NOP      ,123 },  0, ""                }, //ct gr del 123

  {{ KBD_NA_____,KFN_NOP      ,124 },  0, ""                }, //ct numlk  124
  {{ KBD_MAPTEXT,KFN_NOP      ,125 },  0, ""                }, //ct scrlk  125

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,126 },  0, ""                }, //ct pd 0   126
  {{ KBD_MAPTEXT,KFN_NOP      ,127 },  0, ""                }, //ct pd 1   127
  {{ KBD_MAPTEXT,KFN_NOP      ,128 },  0, ""                }, //ct pd 2   128
  {{ KBD_MAPTEXT,KFN_NOP      ,129 },  0, ""                }, //ct pd 3   129
  {{ KBD_MAPTEXT,KFN_NOP      ,130 },  0, ""                }, //ct pd 4   130
  {{ KBD_MAPTEXT,KFN_NOP      ,131 },  0, ""                }, //ct pd 5   131
  {{ KBD_MAPTEXT,KFN_NOP      ,132 },  0, ""                }, //ct pd 6   132
  {{ KBD_MAPTEXT,KFN_NOP      ,133 },  0, ""                }, //ct pd 7   133
  {{ KBD_MAPTEXT,KFN_NOP      ,134 },  0, ""                }, //ct pd 8   134
  {{ KBD_MAPTEXT,KFN_NOP      ,135 },  0, ""                }, //ct pd 9   135

  {{ KBD_MAPTEXT,KFN_NOP      ,136 },  0, ""                }, //ct pd *   136
  {{ KBD_MAPTEXT,KFN_NOP      ,137 },  0, ""                }, //ct pd +   137
  {{ KBD_MAPTEXT,KFN_NOP      ,138 },  0, ""                }, //ct pd -   138
  {{ KBD_MAPTEXT,KFN_NOP      ,139 },  0, ""                }, //ct pd .   139
  {{ KBD_MAPTEXT,KFN_NOP      ,140 },  0, ""                }, //ct pd /   140

  {{ KBD_MAPTEXT,KFN_NOP      ,141 },  0, ""                }, //ct F1     141
  {{ KBD_MAPTEXT,KFN_NOP      ,142 },  0, ""                }, //ct F2     142
  {{ KBD_MAPTEXT,KFN_NOP      ,143 },  0, ""                }, //ct F3     143
  {{ KBD_MAPTEXT,KFN_NOP      ,144 },  0, ""                }, //ct F4     144
  {{ KBD_MAPTEXT,KFN_NOP      ,145 },  0, ""                }, //ct F5     145
  {{ KBD_MAPTEXT,KFN_NOP      ,146 },  0, ""                }, //ct F6     146
  {{ KBD_MAPTEXT,KFN_NOP      ,147 },  0, ""                }, //ct F7     147
  {{ KBD_MAPTEXT,KFN_NOP      ,148 },  0, ""                }, //ct F8     148
  {{ KBD_MAPTEXT,KFN_NOP      ,149 },  0, ""                }, //ct F9     149
  {{ KBD_MAPTEXT,KFN_NOP      ,150 },  0, ""                }, //ct F10    150
  {{ KBD_MAPTEXT,KFN_NOP      ,151 },  0, ""                }, //ct F11    151
  {{ KBD_MAPTEXT,KFN_NOP      ,152 },  0, ""                }, //ct F12    152

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,153 },  0, ""                }, //s/c bksp  153
  {{ KBD_MAPTEXT,KFN_NOP      ,154 },  0, ""                }, //s/c clr   154
  {{ KBD_MAPTEXT,KFN_NOP      ,155 },  0, ""                }, //s/c ent   155
  {{ KBD_MAPTEXT,KFN_NOP      ,156 },  0, ""                }, //s/c pd ent156
  {{ KBD_MAPTEXT,KFN_NOP      ,157 },  0, ""                }, //s/c pau   157

  {{ KBD_MAPTEXT,KFN_NOP      ,158 },  0, ""                }, //s/c pd pu 158
  {{ KBD_MAPTEXT,KFN_NOP      ,159 },  0, ""                }, //s/c pd pd 159
  {{ KBD_MAPTEXT,KFN_NOP      ,160 },  0, ""                }, //s/c pd en 160
  {{ KBD_MAPTEXT,KFN_NOP      ,161 },  0, ""                }, //s/c pd hm 161
  {{ KBD_MAPTEXT,KFN_NOP      ,162 },  0, ""                }, //s/c pd lf 162
  {{ KBD_MAPTEXT,KFN_NOP      ,163 },  0, ""                }, //s/c pd up 163
  {{ KBD_MAPTEXT,KFN_NOP      ,164 },  0, ""                }, //s/c pd rt 164
  {{ KBD_MAPTEXT,KFN_NOP      ,165 },  0, ""                }, //s/c pd dn 165

  {{ KBD_MAPTEXT,KFN_NOP      ,166 },  0, ""                }, //s/c gr pu 166
  {{ KBD_MAPTEXT,KFN_NOP      ,167 },  0, ""                }, //s/c gr pd 167
  {{ KBD_MAPTEXT,KFN_NOP      ,168 },  0, ""                }, //s/c gr en 168
  {{ KBD_MAPTEXT,KFN_NOP      ,169 },  0, ""                }, //s/c gr hm 169
  {{ KBD_MAPTEXT,KFN_NOP      ,170 },  0, ""                }, //s/c gr lf 170
  {{ KBD_MAPTEXT,KFN_NOP      ,171 },  0, ""                }, //s/c gr up 171
  {{ KBD_MAPTEXT,KFN_NOP      ,172 },  0, ""                }, //s/c gr rt 172
  {{ KBD_MAPTEXT,KFN_NOP      ,173 },  0, ""                }, //s/c gr dn 173

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,174 },  0, ""                }, //s/c pd ins174
  {{ KBD_MAPTEXT,KFN_NOP      ,175 },  0, ""                }, //s/c pd del175
  {{ KBD_MAPTEXT,KFN_NOP      ,176 },  0, ""                }, //s/c gr ins176
  {{ KBD_MAPTEXT,KFN_NOP      ,177 },  0, ""                }, //s/c gr del177

  {{ KBD_NA_____,KFN_NOP      ,178 },  0, ""                }, //s/c numlk 178
  {{ KBD_NA_____,KFN_NOP      ,179 },  0, ""                }, //s/c scrlk 179

  {{ KBD_MAPTEXT,KFN_NOP      ,180 },  0, ""                }, //s/c pd *  180
  {{ KBD_MAPTEXT,KFN_NOP      ,181 },  0, ""                }, //s/c pd +  181
  {{ KBD_MAPTEXT,KFN_NOP      ,182 },  0, ""                }, //s/c pd -  182
  {{ KBD_MAPTEXT,KFN_NOP      ,183 },  0, ""                }, //s/c pd /  183

  {{ KBD_MAPTEXT,KFN_NOP      ,184 },  0, ""                }, //s/c F1    184
  {{ KBD_MAPTEXT,KFN_NOP      ,185 },  0, ""                }, //s/c F2    185
  {{ KBD_MAPTEXT,KFN_NOP      ,186 },  0, ""                }, //s/c F3    186
  {{ KBD_MAPTEXT,KFN_NOP      ,187 },  0, ""                }, //s/c F4    187
  {{ KBD_MAPTEXT,KFN_NOP      ,188 },  0, ""                }, //s/c F5    188
  {{ KBD_MAPTEXT,KFN_NOP      ,189 },  0, ""                }, //s/c F6    189
  {{ KBD_MAPTEXT,KFN_NOP      ,190 },  0, ""                }, //s/c F7    190
  {{ KBD_MAPTEXT,KFN_NOP      ,191 },  0, ""                }, //s/c F8    191
  {{ KBD_MAPTEXT,KFN_NOP      ,192 },  0, ""                }, //s/c F9    192
  {{ KBD_MAPTEXT,KFN_NOP      ,193 },  0, ""                }, //s/c F10   193
  {{ KBD_MAPTEXT,KFN_NOP      ,194 },  0, ""                }, //s/c F11   194
  {{ KBD_MAPTEXT,KFN_NOP      ,195 },  0, ""                }, //s/c F12   195

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,196 },  0, ""             }, //a/sh bksp    196
  {{ KBD_MAPTEXT,KFN_NOP      ,197 },  0, ""             }, //a/sh tab     197
  {{ KBD_MAPTEXT,KFN_NOP      ,198 },  0, ""             }, //a/sh clr     198
  {{ KBD_MAPTEXT,KFN_NOP      ,199 },  0, ""             }, //a/sh ent     199
  {{ KBD_MAPTEXT,KFN_NOP      ,200 },  0, ""             }, //a/sh pd ent  200
  {{ KBD_MAPTEXT,KFN_NOP      ,201 },  0, ""             }, //a/sh pause   201

  {{ KBD_MAPTEXT,KFN_NOP      ,202 },  0, ""             }, //a/sh pd pu   202
  {{ KBD_MAPTEXT,KFN_NOP      ,203 },  0, ""             }, //a/sh pd pd   203
  {{ KBD_MAPTEXT,KFN_NOP      ,204 },  0, ""             }, //a/sh pd en   204
  {{ KBD_MAPTEXT,KFN_NOP      ,205 },  0, ""             }, //a/sh pd hm   205
  {{ KBD_MAPTEXT,KFN_NOP      ,206 },  0, ""             }, //a/sh pd lf   206
  {{ KBD_MAPTEXT,KFN_NOP      ,207 },  0, ""             }, //a/sh pd up   207
  {{ KBD_MAPTEXT,KFN_NOP      ,208 },  0, ""             }, //a/sh pd rt   208
  {{ KBD_MAPTEXT,KFN_NOP      ,209 },  0, ""             }, //a/sh pd dn   209

  {{ KBD_MAPTEXT,KFN_NOP      ,210 },  0, ""             }, //a/sh gr pu   210
  {{ KBD_MAPTEXT,KFN_NOP      ,211 },  0, ""             }, //a/sh gr pd   211
  {{ KBD_MAPTEXT,KFN_NOP      ,212 },  0, ""             }, //a/sh gr en   212
  {{ KBD_MAPTEXT,KFN_NOP      ,213 },  0, ""             }, //a/sh gr hm   213
  {{ KBD_MAPTEXT,KFN_NOP      ,214 },  0, ""             }, //a/sh gr lf   214
  {{ KBD_MAPTEXT,KFN_NOP      ,215 },  0, ""             }, //a/sh gr up   215
  {{ KBD_MAPTEXT,KFN_NOP      ,216 },  0, ""             }, //a/sh gr rt   216
  {{ KBD_MAPTEXT,KFN_NOP      ,217 },  0, ""             }, //a/sh gr dn   217

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,218 },  0, ""             }, //a/sh pd ins  218
  {{ KBD_MAPTEXT,KFN_NOP      ,219 },  0, ""             }, //a/sh pd del  219
  {{ KBD_NA_____,KFN_NOP      ,220 },  0, ""             }, //a/sh gr ins  220
  {{ KBD_MAPTEXT,KFN_NOP      ,221 },  0, ""             }, //a/sh gr del  221

  {{ KBD_MAPTEXT,KFN_NOP      ,222 },  0, ""             }, //a/sh numlk   222
  {{ KBD_MAPTEXT,KFN_NOP      ,223 },  0, ""             }, //a/sh scrlk   223

  {{ KBD_MAPTEXT,KFN_NOP      ,224 },  0, ""             }, //a/sh pd *    224
  {{ KBD_MAPTEXT,KFN_NOP      ,225 },  0, ""             }, //a/sh pd +    225
  {{ KBD_MAPTEXT,KFN_NOP      ,226 },  0, ""             }, //a/sh pd -    226
  {{ KBD_MAPTEXT,KFN_NOP      ,227 },  0, ""             }, //a/sh pd /    227

  {{ KBD_MAPTEXT,KFN_NOP      ,228 },  0, ""             }, //a/sh F1      228
  {{ KBD_MAPTEXT,KFN_NOP      ,229 },  0, ""             }, //a/sh F2      229
  {{ KBD_MAPTEXT,KFN_NOP      ,230 },  0, ""             }, //a/sh F3      230
  {{ KBD_MAPTEXT,KFN_NOP      ,231 },  0, ""             }, //a/sh F4      231
  {{ KBD_MAPTEXT,KFN_NOP      ,232 },  0, ""             }, //a/sh F5      232
  {{ KBD_MAPTEXT,KFN_NOP      ,233 },  0, ""             }, //a/sh F6      233
  {{ KBD_MAPTEXT,KFN_NOP      ,234 },  0, ""             }, //a/sh F7      234
  {{ KBD_MAPTEXT,KFN_NOP      ,235 },  0, ""             }, //a/sh F8      235
  {{ KBD_MAPTEXT,KFN_NOP      ,236 },  0, ""             }, //a/sh F9      236
  {{ KBD_MAPTEXT,KFN_NOP      ,237 },  0, ""             }, //a/sh F10     237
  {{ KBD_MAPTEXT,KFN_NOP      ,238 },  0, ""             }, //a/sh F11     238
  {{ KBD_MAPTEXT,KFN_NOP      ,239 },  0, ""             }, //a/sh F12     239

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,240 },  0, ""             }, //a/ct bksp    240
  {{ KBD_MAPTEXT,KFN_NOP      ,241 },  0, ""             }, //a/ct tab     241
  {{ KBD_MAPTEXT,KFN_NOP      ,242 },  0, ""             }, //a/ct clr     242
  {{ KBD_MAPTEXT,KFN_NOP      ,243 },  0, ""             }, //a/ct ent     243
  {{ KBD_MAPTEXT,KFN_NOP      ,244 },  0, ""             }, //a/ct pd ent  244
  {{ KBD_MAPTEXT,KFN_NOP      ,245 },  0, ""             }, //a/ct pau     245

  {{ KBD_MAPTEXT,KFN_NOP      ,246 },  0, ""             }, //a/ct pd pu   246
  {{ KBD_MAPTEXT,KFN_NOP      ,247 },  0, ""             }, //a/ct pd pd   247
  {{ KBD_MAPTEXT,KFN_NOP      ,248 },  0, ""             }, //a/ct pd en   248
  {{ KBD_MAPTEXT,KFN_NOP      ,249 },  0, ""             }, //a/ct pd hm   249
  {{ KBD_MAPTEXT,KFN_NOP      ,250 },  0, ""             }, //a/ct pd lf   250
  {{ KBD_MAPTEXT,KFN_NOP      ,251 },  0, ""             }, //a/ct pd up   251
  {{ KBD_MAPTEXT,KFN_NOP      ,252 },  0, ""             }, //a/ct pd rt   252
  {{ KBD_MAPTEXT,KFN_NOP      ,253 },  0, ""             }, //a/ct pd dn   253

  {{ KBD_MAPTEXT,KFN_NOP      ,254 },  0, ""             }, //a/ct gr pu   254
  {{ KBD_MAPTEXT,KFN_NOP      ,255 },  0, ""             }, //a/ct gr pd   255
  {{ KBD_MAPTEXT,KFN_NOP      ,256 },  0, ""             }, //a/ct gr en   256
  {{ KBD_MAPTEXT,KFN_NOP      ,257 },  0, ""             }, //a/ct gr hm   257
  {{ KBD_MAPTEXT,KFN_NOP      ,258 },  0, ""             }, //a/ct gr lf   258
  {{ KBD_MAPTEXT,KFN_NOP      ,259 },  0, ""             }, //a/ct gr up   259
  {{ KBD_MAPTEXT,KFN_NOP      ,260 },  0, ""             }, //a/ct gr rt   260
  {{ KBD_MAPTEXT,KFN_NOP      ,261 },  0, ""             }, //a/ct gr dn   261

  {{ KBD_MAPTEXT,KFN_NOP      ,262 },  0, ""             }, //a/ct pd ins  262
  {{ KBD_MAPTEXT,KFN_NOP      ,263 },  0, ""             }, //a/ct gr ins  263

  {{ KBD_NA_____,KFN_NOP      ,264 },  0, ""             }, //a/ct numlk   264
  {{ KBD_MAPTEXT,KFN_NOP      ,265 },  0, ""             }, //a/ct scrlk   265

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,266 },  0, ""             }, //a/ct pd 0    266
  {{ KBD_MAPTEXT,KFN_NOP      ,267 },  0, ""             }, //a/ct pd 1    267
  {{ KBD_MAPTEXT,KFN_NOP      ,268 },  0, ""             }, //a/ct pd 2    268
  {{ KBD_MAPTEXT,KFN_NOP      ,269 },  0, ""             }, //a/ct pd 3    269
  {{ KBD_MAPTEXT,KFN_NOP      ,270 },  0, ""             }, //a/ct pd 4    270
  {{ KBD_MAPTEXT,KFN_NOP      ,271 },  0, ""             }, //a/ct pd 5    271
  {{ KBD_MAPTEXT,KFN_NOP      ,272 },  0, ""             }, //a/ct pd 6    272
  {{ KBD_MAPTEXT,KFN_NOP      ,273 },  0, ""             }, //a/ct pd 7    273
  {{ KBD_MAPTEXT,KFN_NOP      ,274 },  0, ""             }, //a/ct pd 8    274
  {{ KBD_MAPTEXT,KFN_NOP      ,275 },  0, ""             }, //a/ct pd 9    275

  {{ KBD_MAPTEXT,KFN_NOP      ,276 },  0, ""             }, //a/ct pd *    276
  {{ KBD_MAPTEXT,KFN_NOP      ,277 },  0, ""             }, //a/ct pd +    277
  {{ KBD_MAPTEXT,KFN_NOP      ,278 },  0, ""             }, //a/ct pd -    278
  {{ KBD_MAPTEXT,KFN_NOP      ,279 },  0, ""             }, //a/ct pd .    279
  {{ KBD_MAPTEXT,KFN_NOP      ,280 },  0, ""             }, //a/ct pd /    280

  {{ KBD_MAPTEXT,KFN_NOP      ,281 },  0, ""             }, //a/ct F1      281
  {{ KBD_MAPTEXT,KFN_NOP      ,282 },  0, ""             }, //a/ct F2      282
  {{ KBD_MAPTEXT,KFN_NOP      ,283 },  0, ""             }, //a/ct F3      283
  {{ KBD_MAPTEXT,KFN_NOP      ,284 },  0, ""             }, //a/ct F4      284
  {{ KBD_MAPTEXT,KFN_NOP      ,285 },  0, ""             }, //a/ct F5      285
  {{ KBD_MAPTEXT,KFN_NOP      ,286 },  0, ""             }, //a/ct F6      286
  {{ KBD_MAPTEXT,KFN_NOP      ,287 },  0, ""             }, //a/ct F7      287
  {{ KBD_MAPTEXT,KFN_NOP      ,288 },  0, ""             }, //a/ct F8      288
  {{ KBD_MAPTEXT,KFN_NOP      ,289 },  0, ""             }, //a/ct F9      289
  {{ KBD_MAPTEXT,KFN_NOP      ,290 },  0, ""             }, //a/ct F10     290
  {{ KBD_MAPTEXT,KFN_NOP      ,291 },  0, ""             }, //a/ct F11     291
  {{ KBD_MAPTEXT,KFN_NOP      ,292 },  0, ""             }, //a/ct F12     292

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,293 },  0, ""             }, //a/s/c bksp   293
  {{ KBD_MAPTEXT,KFN_NOP      ,294 },  0, ""             }, //a/s/c tab    294
  {{ KBD_MAPTEXT,KFN_NOP      ,295 },  0, ""             }, //a/s/c clr    295
  {{ KBD_MAPTEXT,KFN_NOP      ,296 },  0, ""             }, //a/s/c ent    296
  {{ KBD_MAPTEXT,KFN_NOP      ,297 },  0, ""             }, //a/s/c pd ent 297
  {{ KBD_MAPTEXT,KFN_NOP      ,298 },  0, ""             }, //a/s/c pau    298

  {{ KBD_MAPTEXT,KFN_NOP      ,299 },  0, ""             }, //a/s/c pd pu  299
  {{ KBD_MAPTEXT,KFN_NOP      ,300 },  0, ""             }, //a/s/c pd pd  300
  {{ KBD_MAPTEXT,KFN_NOP      ,301 },  0, ""             }, //a/s/c pd en  301
  {{ KBD_MAPTEXT,KFN_NOP      ,302 },  0, ""             }, //a/s/c pd hm  302
  {{ KBD_MAPTEXT,KFN_NOP      ,303 },  0, ""             }, //a/s/c pd lf  303
  {{ KBD_MAPTEXT,KFN_NOP      ,304 },  0, ""             }, //a/s/c pd up  304
  {{ KBD_MAPTEXT,KFN_NOP      ,305 },  0, ""             }, //a/s/c pd rt  305
  {{ KBD_MAPTEXT,KFN_NOP      ,306 },  0, ""             }, //a/s/c pd dn  306

  {{ KBD_MAPTEXT,KFN_NOP      ,307 },  0, ""             }, //a/s/c gr pu  307
  {{ KBD_MAPTEXT,KFN_NOP      ,308 },  0, ""             }, //a/s/c gr pd  308
  {{ KBD_MAPTEXT,KFN_NOP      ,309 },  0, ""             }, //a/s/c gr en  309
  {{ KBD_MAPTEXT,KFN_NOP      ,310 },  0, ""             }, //a/s/c gr hm  310
  {{ KBD_MAPTEXT,KFN_NOP      ,311 },  0, ""             }, //a/s/c gr lf  311
  {{ KBD_MAPTEXT,KFN_NOP      ,312 },  0, ""             }, //a/s/c gr up  312
  {{ KBD_MAPTEXT,KFN_NOP      ,313 },  0, ""             }, //a/s/c gr rt  313
  {{ KBD_MAPTEXT,KFN_NOP      ,314 },  0, ""             }, //a/s/c gr dn  314

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,315 },  0, ""             }, //a/s/c pd ins 315
  {{ KBD_MAPTEXT,KFN_NOP      ,316 },  0, ""             }, //a/s/c gr ins 316

  {{ KBD_NA_____,KFN_NOP      ,317 },  0, ""             }, //a/s/c numlk  317
  {{ KBD_NA_____,KFN_NOP      ,318 },  0, ""             }, //a/s/c scrlk  318

  {{ KBD_MAPTEXT,KFN_NOP      ,319 },  0, ""             }, //a/s/c pd *   319
  {{ KBD_MAPTEXT,KFN_NOP      ,320 },  0, ""             }, //a/s/c pd +   320
  {{ KBD_MAPTEXT,KFN_NOP      ,321 },  0, ""             }, //a/s/c pd -   321
  {{ KBD_MAPTEXT,KFN_NOP      ,322 },  0, ""             }, //a/s/c pd /   322

  {{ KBD_MAPTEXT,KFN_NOP      ,323 },  0, ""             }, //a/s/c F1     323
  {{ KBD_MAPTEXT,KFN_NOP      ,324 },  0, ""             }, //a/s/c F2     324
  {{ KBD_MAPTEXT,KFN_NOP      ,325 },  0, ""             }, //a/s/c F3     325
  {{ KBD_MAPTEXT,KFN_NOP      ,326 },  0, ""             }, //a/s/c F4     326
  {{ KBD_MAPTEXT,KFN_NOP      ,327 },  0, ""             }, //a/s/c F5     327
  {{ KBD_MAPTEXT,KFN_NOP      ,328 },  0, ""             }, //a/s/c F6     328
  {{ KBD_MAPTEXT,KFN_NOP      ,329 },  0, ""             }, //a/s/c F7     329
  {{ KBD_MAPTEXT,KFN_NOP      ,330 },  0, ""             }, //a/s/c F8     330
  {{ KBD_MAPTEXT,KFN_NOP      ,331 },  0, ""             }, //a/s/c F9     331
  {{ KBD_MAPTEXT,KFN_NOP      ,332 },  0, ""             }, //a/s/c F10    332
  {{ KBD_MAPTEXT,KFN_NOP      ,333 },  0, ""             }, //a/s/c F11    333
  {{ KBD_MAPTEXT,KFN_NOP      ,334 },  0, ""             }  //a/s/c F12    334

   }
};

#endif                                 // !DEBUG_KBD


EMUL_RES_STRUCT _far ers1  =           // Simpldlt emulation 1
{
// ers.szResName
   "simpkbd1.101",
// ers.heapsize
   0,             // not calculated yet!
// ers.Flag1
   0,
// ers.Flag2
   0,
// ers.mss[NUMMAPSTRINGS]
   {
//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      ,  0 },  1, "\x08"            }, //bksp        0
  {{ KBD_MAPECHO,KFN_NOP      ,  1 },  1, "\x09"            }, //tab         1
  {{ KBD_MAPTEXT,KFN_NOP      ,  2 },  0, ""                }, //clear       2
  {{ KBD_MAPECHO,KFN_NOP      ,  3 },  1, "\x0D"            }, //enter       3
  {{ KBD_MAPECHO,KFN_NOP      ,  4 },  1, "\x1C"            }, //pd ent      4
  {{ KBD_MAPTEXT,KFN_NOP      ,  5 },  0, ""                }, //pause       5

  {{ KBD_MAPTEXT,KFN_NOP      ,  6 },  0, ""                }, //pd pgup     6
  {{ KBD_MAPTEXT,KFN_NOP      ,  7 },  0, ""                }, //pd pgdn     7
  {{ KBD_MAPTEXT,KFN_NOP      ,  8 },  0, ""                }, //pd end      8
  {{ KBD_MAPECHO,KFN_NOP      ,  9 },  1, "\x1E"            }, //pd home     9
  {{ KBD_MAPECHO,KFN_NOP      , 10 },  1, "\x08"            }, //pd left    10
  {{ KBD_MAPECHO,KFN_NOP      , 11 },  1, "\x0B"            }, //pd up      11
  {{ KBD_MAPECHO,KFN_NOP      , 12 },  1, "\x09"            }, //pd right   12
  {{ KBD_MAPECHO,KFN_NOP      , 13 },  1, "\x0A"            }, //pd down    13

  {{ KBD_MAPTEXT,KFN_SEND     , 14 },  0, ""                }, //gr pgup    14
  {{ KBD_MAPTEXT,KFN_RCV      , 15 },  0, ""                }, //gr pgdn    15
  {{ KBD_MAPTEXT,KFN_NOP      , 16 },  0, ""                }, //gr end     16
  {{ KBD_MAPECHO,KFN_NOP      , 17 },  1, "\x1E"            }, //gr home    17
  {{ KBD_MAPECHO,KFN_NOP      , 18 },  1, "\x08"            }, //gr left    18
  {{ KBD_MAPECHO,KFN_NOP      , 19 },  1, "\x0B"            }, //gr up      19
  {{ KBD_MAPECHO,KFN_NOP      , 20 },  1, "\x09"            }, //gr right   20
  {{ KBD_MAPECHO,KFN_NOP      , 21 },  1, "\x0A"            }, //gr down    21

  {{ KBD_MAPECHO,KFN_NOP      , 22 },  0, ""                }, //pd ins     22
  {{ KBD_MAPECHO,KFN_NOP      , 23 },  0, ""                }, //pd del     23
  {{ KBD_MAPECHO,KFN_NOP      , 24 },  0, ""                }, //gr ins     24
  {{ KBD_MAPECHO,KFN_NOP      , 25 },  0, ""                }, //gr del     25

  {{ KBD_NA_____,KFN_NOP      , 26 },  0, ""                }, //numlk      26
  {{ KBD_MAPTEXT,KFN_NOP      , 27 },  0, ""                }, //scrlk      27

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      , 28 },  1, "0"               }, //pd 0       28
  {{ KBD_MAPECHO,KFN_NOP      , 29 },  1, "1"               }, //pd 1       29
  {{ KBD_MAPECHO,KFN_NOP      , 30 },  1, "2"               }, //pd 2       30
  {{ KBD_MAPECHO,KFN_NOP      , 31 },  1, "3"               }, //pd 3       31
  {{ KBD_MAPECHO,KFN_NOP      , 32 },  1, "4"               }, //pd 4       32
  {{ KBD_MAPECHO,KFN_NOP      , 33 },  1, "5"               }, //pd 5       33
  {{ KBD_MAPECHO,KFN_NOP      , 34 },  1, "6"               }, //pd 6       34
  {{ KBD_MAPECHO,KFN_NOP      , 35 },  1, "7"               }, //pd 7       35
  {{ KBD_MAPECHO,KFN_NOP      , 36 },  1, "8"               }, //pd 8       36
  {{ KBD_MAPECHO,KFN_NOP      , 37 },  1, "9"               }, //pd 9       37

  {{ KBD_MAPECHO,KFN_NOP      , 38 },  1, "*"               }, //pd *       38
  {{ KBD_TRMINTL,1            , 39 },  0, ""                }, //pd +       39
  {{ KBD_TRMINTL,2            , 40 },  0, ""                }, //pd -       40
  {{ KBD_MAPECHO,KFN_NOP      , 41 },  1, "."               }, //pd .       41
  {{ KBD_MAPECHO,KFN_NOP      , 42 },  1, "/"               }, //pd /       42

  {{ KBD_MAPTEXT,KFN_NOP      , 43 },  0, ""                }, //F1         43
  {{ KBD_MAPTEXT,KFN_NOP      , 44 },  0, ""                }, //F2         44
  {{ KBD_MAPTEXT,KFN_NOP      , 45 },  0, ""                }, //F3         45
  {{ KBD_MAPTEXT,KFN_NOP      , 46 },  0, ""                }, //F4         46
  {{ KBD_MAPTEXT,KFN_NOP      , 47 },  0, ""                }, //F5         47
  {{ KBD_MAPTEXT,KFN_NOP      , 48 },  0, ""                }, //F6         48
  {{ KBD_MAPTEXT,KFN_NOP      , 49 },  1, "\x13"            }, //F7         49
  {{ KBD_MAPTEXT,KFN_NOP      , 50 },  1, "\x1C"            }, //F8         50
  {{ KBD_MAPTEXT,KFN_NOP      , 51 },  1, "\x1E"            }, //F9         51
  {{ KBD_MAPTEXT,KFN_NOP      , 52 },  0, ""                }, //F10        52
  {{ KBD_MAPTEXT,KFN_NOP      , 53 },  0, ""                }, //F11        53
  {{ KBD_MAPTEXT,KFN_NOP      , 54 },  0, ""                }, //F12        54

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 55 },  0, ""                }, //sh bksp    55
  {{ KBD_MAPTEXT,KFN_NOP      , 56 },  0, ""                }, //sh tab     56
  {{ KBD_MAPTEXT,KFN_NOP      , 57 },  0, ""                }, //sh clr     57
  {{ KBD_MAPTEXT,KFN_NOP      , 58 },  0, ""                }, //sh ent     58
  {{ KBD_MAPTEXT,KFN_NOP      , 59 },  1, "\x1C"            }, //sh pd ent  59
  {{ KBD_MAPTEXT,KFN_NOP      , 60 },  0, ""                }, //sh pause   60

  {{ KBD_MAPTEXT,KFN_NOP      , 61 },  0, ""                }, //sh pd pu   61
  {{ KBD_MAPTEXT,KFN_NOP      , 62 },  0, ""                }, //sh pd pd   62
  {{ KBD_MAPTEXT,KFN_NOP      , 63 },  0, ""                }, //sh pd en   63
  {{ KBD_MAPTEXT,KFN_NOP      , 64 },  0, ""                }, //sh pd hm   64
  {{ KBD_MAPTEXT,KFN_NOP      , 65 },  0, ""                }, //sh pd lf   65
  {{ KBD_MAPTEXT,KFN_NOP      , 66 },  0, ""                }, //sh pd up   66
  {{ KBD_MAPTEXT,KFN_NOP      , 67 },  0, ""                }, //sh pd rt   67
  {{ KBD_MAPTEXT,KFN_NOP      , 68 },  0, ""                }, //sh pd dn   68

  {{ KBD_MAPTEXT,KFN_NOP      , 69 },  0, ""                }, //sh gr pu   69
  {{ KBD_MAPTEXT,KFN_NOP      , 70 },  0, ""                }, //sh gr pd   70
  {{ KBD_MAPTEXT,KFN_NOP      , 71 },  0, ""                }, //sh gr en   71
  {{ KBD_MAPTEXT,KFN_NOP      , 72 },  0, ""                }, //sh gr hm   72
  {{ KBD_MAPTEXT,KFN_NOP      , 73 },  0, ""                }, //sh gr lf   73
  {{ KBD_MAPTEXT,KFN_NOP      , 74 },  0, ""                }, //sh gr up   74
  {{ KBD_MAPTEXT,KFN_NOP      , 75 },  0, ""                }, //sh gr rt   75
  {{ KBD_MAPTEXT,KFN_NOP      , 76 },  0, ""                }, //sh gr dn   76

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 77 },  0, ""                }, //sh pd ins  77
  {{ KBD_MAPTEXT,KFN_NOP      , 78 },  0, ""                }, //sh pd del  78
  {{ KBD_NA_____,KFN_NOP      , 79 },  0, ""                }, //sh gr ins  79
  {{ KBD_MAPTEXT,KFN_NOP      , 80 },  0, ""                }, //sh gr del  80

  {{ KBD_MAPTEXT,KFN_NOP      , 81 },  0, ""                }, //sh numlk   81
  {{ KBD_MAPTEXT,KFN_NOP      , 82 },  0, ""                }, //sh scrlk   82

  {{ KBD_MAPTEXT,KFN_NOP      , 83 },  0, ""                }, //sh pd *    83
  {{ KBD_MAPTEXT,KFN_NOP      , 84 },  0, ""                }, //sh pd +    84
  {{ KBD_MAPTEXT,KFN_NOP      , 85 },  0, ""                }, //sh pd -    85
  {{ KBD_MAPTEXT,KFN_NOP      , 86 },  0, ""                }, //sh pd /    86

  {{ KBD_MAPTEXT,KFN_NOP      , 87 },  0, ""                }, //sh F1      87
  {{ KBD_MAPTEXT,KFN_NOP      , 88 },  0, ""                }, //sh F2      88
  {{ KBD_MAPTEXT,KFN_NOP      , 89 },  0, ""                }, //sh F3      89
  {{ KBD_MAPTEXT,KFN_NOP      , 90 },  0, ""                }, //sh F4      90
  {{ KBD_MAPTEXT,KFN_NOP      , 91 },  0, ""                }, //sh F5      91
  {{ KBD_MAPTEXT,KFN_NOP      , 92 },  0, ""                }, //sh F6      92
  {{ KBD_MAPTEXT,KFN_NOP      , 93 },  0, ""                }, //sh F7      93
  {{ KBD_MAPTEXT,KFN_NOP      , 94 },  0, ""                }, //sh F8      94
  {{ KBD_MAPTEXT,KFN_NOP      , 95 },  0, ""                }, //sh F9      95
  {{ KBD_MAPTEXT,KFN_NOP      , 96 },  0, ""                }, //sh F10     96
  {{ KBD_MAPTEXT,KFN_NOP      , 97 },  0, ""                }, //sh F11     97
  {{ KBD_MAPTEXT,KFN_NOP      , 98 },  0, ""                }, //sh F12     98

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      , 99 },  0, ""                }, //ct bksp    99
  {{ KBD_MAPTEXT,KFN_NOP      ,100 },  0, ""                }, //ct clr    100
  {{ KBD_MAPTEXT,KFN_NOP      ,101 },  0, ""                }, //ct ent    101
  {{ KBD_MAPTEXT,KFN_NOP      ,102 },  0, ""                }, //ct pd ent 102
  {{ KBD_MAPTEXT,KFN_NOP      ,103 },  0, ""                }, //ct pau    103

  {{ KBD_MAPTEXT,KFN_NOP      ,104 },  0, ""                }, //ct pd pu  104
  {{ KBD_MAPTEXT,KFN_NOP      ,105 },  0, ""                }, //ct pd pd  105
  {{ KBD_MAPTEXT,KFN_NOP      ,106 },  0, ""                }, //ct pd en  106
  {{ KBD_MAPTEXT,KFN_NOP      ,107 },  0, ""                }, //ct pd hm  107
  {{ KBD_MAPTEXT,KFN_NOP      ,108 },  0, ""                }, //ct pd lf  108
  {{ KBD_MAPTEXT,KFN_NOP      ,109 },  0, ""                }, //ct pd up  109
  {{ KBD_MAPTEXT,KFN_NOP      ,110 },  0, ""                }, //ct pd rt  110
  {{ KBD_MAPTEXT,KFN_NOP      ,111 },  0, ""                }, //ct pd dn  111

  {{ KBD_MAPTEXT,KFN_NOP      ,112 },  0, ""                }, //ct gr pu  112
  {{ KBD_MAPTEXT,KFN_NOP      ,113 },  0, ""                }, //ct gr pd  113
  {{ KBD_MAPTEXT,KFN_NOP      ,114 },  0, ""                }, //ct gr en  114
  {{ KBD_MAPTEXT,KFN_NOP      ,115 },  0, ""                }, //ct gr hm  115
  {{ KBD_MAPTEXT,KFN_NOP      ,116 },  0, ""                }, //ct gr lf  116
  {{ KBD_MAPTEXT,KFN_NOP      ,117 },  0, ""                }, //ct gr up  117
  {{ KBD_MAPTEXT,KFN_NOP      ,118 },  0, ""                }, //ct gr rt  118
  {{ KBD_MAPTEXT,KFN_NOP      ,119 },  0, ""                }, //ct gr dn  119

  {{ KBD_MAPTEXT,KFN_NOP      ,120 },  0, ""                }, //ct pd ins 120
  {{ KBD_MAPTEXT,KFN_NOP      ,121 },  0, ""                }, //ct pd del 121
  {{ KBD_MAPTEXT,KFN_NOP      ,122 },  0, ""                }, //ct gr ins 122
  {{ KBD_MAPTEXT,KFN_NOP      ,123 },  0, ""                }, //ct gr del 123

  {{ KBD_NA_____,KFN_NOP      ,124 },  0, ""                }, //ct numlk  124
  {{ KBD_MAPTEXT,KFN_NOP      ,125 },  0, ""                }, //ct scrlk  125

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,126 },  0, ""                }, //ct pd 0   126
  {{ KBD_MAPTEXT,KFN_NOP      ,127 },  0, ""                }, //ct pd 1   127
  {{ KBD_MAPTEXT,KFN_NOP      ,128 },  0, ""                }, //ct pd 2   128
  {{ KBD_MAPTEXT,KFN_NOP      ,129 },  0, ""                }, //ct pd 3   129
  {{ KBD_MAPTEXT,KFN_NOP      ,130 },  0, ""                }, //ct pd 4   130
  {{ KBD_MAPTEXT,KFN_NOP      ,131 },  0, ""                }, //ct pd 5   131
  {{ KBD_MAPTEXT,KFN_NOP      ,132 },  0, ""                }, //ct pd 6   132
  {{ KBD_MAPTEXT,KFN_NOP      ,133 },  0, ""                }, //ct pd 7   133
  {{ KBD_MAPTEXT,KFN_NOP      ,134 },  0, ""                }, //ct pd 8   134
  {{ KBD_MAPTEXT,KFN_NOP      ,135 },  0, ""                }, //ct pd 9   135

  {{ KBD_MAPTEXT,KFN_NOP      ,136 },  0, ""                }, //ct pd *   136
  {{ KBD_MAPTEXT,KFN_NOP      ,137 },  0, ""                }, //ct pd +   137
  {{ KBD_MAPTEXT,KFN_NOP      ,138 },  0, ""                }, //ct pd -   138
  {{ KBD_MAPTEXT,KFN_NOP      ,139 },  0, ""                }, //ct pd .   139
  {{ KBD_MAPTEXT,KFN_NOP      ,140 },  0, ""                }, //ct pd /   140

  {{ KBD_MAPTEXT,KFN_NOP      ,141 },  0, ""                }, //ct F1     141
  {{ KBD_MAPTEXT,KFN_NOP      ,142 },  0, ""                }, //ct F2     142
  {{ KBD_MAPTEXT,KFN_NOP      ,143 },  0, ""                }, //ct F3     143
  {{ KBD_MAPTEXT,KFN_NOP      ,144 },  0, ""                }, //ct F4     144
  {{ KBD_MAPTEXT,KFN_NOP      ,145 },  0, ""                }, //ct F5     145
  {{ KBD_MAPTEXT,KFN_NOP      ,146 },  0, ""                }, //ct F6     146
  {{ KBD_MAPTEXT,KFN_NOP      ,147 },  0, ""                }, //ct F7     147
  {{ KBD_MAPTEXT,KFN_NOP      ,148 },  0, ""                }, //ct F8     148
  {{ KBD_MAPTEXT,KFN_NOP      ,149 },  0, ""                }, //ct F9     149
  {{ KBD_MAPTEXT,KFN_NOP      ,150 },  0, ""                }, //ct F10    150
  {{ KBD_MAPTEXT,KFN_NOP      ,151 },  0, ""                }, //ct F11    151
  {{ KBD_MAPTEXT,KFN_NOP      ,152 },  0, ""                }, //ct F12    152

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,153 },  0, ""                }, //s/c bksp  153
  {{ KBD_MAPTEXT,KFN_NOP      ,154 },  0, ""                }, //s/c clr   154
  {{ KBD_MAPTEXT,KFN_NOP      ,155 },  0, ""                }, //s/c ent   155
  {{ KBD_MAPTEXT,KFN_NOP      ,156 },  0, ""                }, //s/c pd ent156
  {{ KBD_MAPTEXT,KFN_NOP      ,157 },  0, ""                }, //s/c pau   157

  {{ KBD_MAPTEXT,KFN_NOP      ,158 },  0, ""                }, //s/c pd pu 158
  {{ KBD_MAPTEXT,KFN_NOP      ,159 },  0, ""                }, //s/c pd pd 159
  {{ KBD_MAPTEXT,KFN_NOP      ,160 },  0, ""                }, //s/c pd en 160
  {{ KBD_MAPTEXT,KFN_NOP      ,161 },  0, ""                }, //s/c pd hm 161
  {{ KBD_MAPTEXT,KFN_NOP      ,162 },  0, ""                }, //s/c pd lf 162
  {{ KBD_MAPTEXT,KFN_NOP      ,163 },  0, ""                }, //s/c pd up 163
  {{ KBD_MAPTEXT,KFN_NOP      ,164 },  0, ""                }, //s/c pd rt 164
  {{ KBD_MAPTEXT,KFN_NOP      ,165 },  0, ""                }, //s/c pd dn 165

  {{ KBD_MAPTEXT,KFN_NOP      ,166 },  0, ""                }, //s/c gr pu 166
  {{ KBD_MAPTEXT,KFN_NOP      ,167 },  0, ""                }, //s/c gr pd 167
  {{ KBD_MAPTEXT,KFN_NOP      ,168 },  0, ""                }, //s/c gr en 168
  {{ KBD_MAPTEXT,KFN_NOP      ,169 },  0, ""                }, //s/c gr hm 169
  {{ KBD_MAPTEXT,KFN_NOP      ,170 },  0, ""                }, //s/c gr lf 170
  {{ KBD_MAPTEXT,KFN_NOP      ,171 },  0, ""                }, //s/c gr up 171
  {{ KBD_MAPTEXT,KFN_NOP      ,172 },  0, ""                }, //s/c gr rt 172
  {{ KBD_MAPTEXT,KFN_NOP      ,173 },  0, ""                }, //s/c gr dn 173

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,174 },  0, ""                }, //s/c pd ins174
  {{ KBD_MAPTEXT,KFN_NOP      ,175 },  0, ""                }, //s/c pd del175
  {{ KBD_MAPTEXT,KFN_NOP      ,176 },  0, ""                }, //s/c gr ins176
  {{ KBD_MAPTEXT,KFN_NOP      ,177 },  0, ""                }, //s/c gr del177

  {{ KBD_NA_____,KFN_NOP      ,178 },  0, ""                }, //s/c numlk 178
  {{ KBD_NA_____,KFN_NOP      ,179 },  0, ""                }, //s/c scrlk 179

  {{ KBD_MAPTEXT,KFN_NOP      ,180 },  0, ""                }, //s/c pd *  180
  {{ KBD_MAPTEXT,KFN_NOP      ,181 },  0, ""                }, //s/c pd +  181
  {{ KBD_MAPTEXT,KFN_NOP      ,182 },  0, ""                }, //s/c pd -  182
  {{ KBD_MAPTEXT,KFN_NOP      ,183 },  0, ""                }, //s/c pd /  183

  {{ KBD_MAPTEXT,KFN_NOP      ,184 },  0, ""                }, //s/c F1    184
  {{ KBD_MAPTEXT,KFN_NOP      ,185 },  0, ""                }, //s/c F2    185
  {{ KBD_MAPTEXT,KFN_NOP      ,186 },  0, ""                }, //s/c F3    186
  {{ KBD_MAPTEXT,KFN_NOP      ,187 },  0, ""                }, //s/c F4    187
  {{ KBD_MAPTEXT,KFN_NOP      ,188 },  0, ""                }, //s/c F5    188
  {{ KBD_MAPTEXT,KFN_NOP      ,189 },  0, ""                }, //s/c F6    189
  {{ KBD_MAPTEXT,KFN_NOP      ,190 },  0, ""                }, //s/c F7    190
  {{ KBD_MAPTEXT,KFN_NOP      ,191 },  0, ""                }, //s/c F8    191
  {{ KBD_MAPTEXT,KFN_NOP      ,192 },  0, ""                }, //s/c F9    192
  {{ KBD_MAPTEXT,KFN_NOP      ,193 },  0, ""                }, //s/c F10   193
  {{ KBD_MAPTEXT,KFN_NOP      ,194 },  0, ""                }, //s/c F11   194
  {{ KBD_MAPTEXT,KFN_NOP      ,195 },  0, ""                }, //s/c F12   195

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,196 },  0, ""             }, //a/sh bksp    196
  {{ KBD_MAPTEXT,KFN_NOP      ,197 },  0, ""             }, //a/sh tab     197
  {{ KBD_MAPTEXT,KFN_NOP      ,198 },  0, ""             }, //a/sh clr     198
  {{ KBD_MAPTEXT,KFN_NOP      ,199 },  0, ""             }, //a/sh ent     199
  {{ KBD_MAPTEXT,KFN_NOP      ,200 },  0, ""             }, //a/sh pd ent  200
  {{ KBD_MAPTEXT,KFN_NOP      ,201 },  0, ""             }, //a/sh pause   201

  {{ KBD_MAPTEXT,KFN_NOP      ,202 },  0, ""             }, //a/sh pd pu   202
  {{ KBD_MAPTEXT,KFN_NOP      ,203 },  0, ""             }, //a/sh pd pd   203
  {{ KBD_MAPTEXT,KFN_NOP      ,204 },  0, ""             }, //a/sh pd en   204
  {{ KBD_MAPTEXT,KFN_NOP      ,205 },  0, ""             }, //a/sh pd hm   205
  {{ KBD_MAPTEXT,KFN_NOP      ,206 },  0, ""             }, //a/sh pd lf   206
  {{ KBD_MAPTEXT,KFN_NOP      ,207 },  0, ""             }, //a/sh pd up   207
  {{ KBD_MAPTEXT,KFN_NOP      ,208 },  0, ""             }, //a/sh pd rt   208
  {{ KBD_MAPTEXT,KFN_NOP      ,209 },  0, ""             }, //a/sh pd dn   209

  {{ KBD_MAPTEXT,KFN_NOP      ,210 },  0, ""             }, //a/sh gr pu   210
  {{ KBD_MAPTEXT,KFN_NOP      ,211 },  0, ""             }, //a/sh gr pd   211
  {{ KBD_MAPTEXT,KFN_NOP      ,212 },  0, ""             }, //a/sh gr en   212
  {{ KBD_MAPTEXT,KFN_NOP      ,213 },  0, ""             }, //a/sh gr hm   213
  {{ KBD_MAPTEXT,KFN_NOP      ,214 },  0, ""             }, //a/sh gr lf   214
  {{ KBD_MAPTEXT,KFN_NOP      ,215 },  0, ""             }, //a/sh gr up   215
  {{ KBD_MAPTEXT,KFN_NOP      ,216 },  0, ""             }, //a/sh gr rt   216
  {{ KBD_MAPTEXT,KFN_NOP      ,217 },  0, ""             }, //a/sh gr dn   217

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,218 },  0, ""             }, //a/sh pd ins  218
  {{ KBD_MAPTEXT,KFN_NOP      ,219 },  0, ""             }, //a/sh pd del  219
  {{ KBD_NA_____,KFN_NOP      ,220 },  0, ""             }, //a/sh gr ins  220
  {{ KBD_MAPTEXT,KFN_NOP      ,221 },  0, ""             }, //a/sh gr del  221

  {{ KBD_MAPTEXT,KFN_NOP      ,222 },  0, ""             }, //a/sh numlk   222
  {{ KBD_MAPTEXT,KFN_NOP      ,223 },  0, ""             }, //a/sh scrlk   223

  {{ KBD_MAPTEXT,KFN_NOP      ,224 },  0, ""             }, //a/sh pd *    224
  {{ KBD_MAPTEXT,KFN_NOP      ,225 },  0, ""             }, //a/sh pd +    225
  {{ KBD_MAPTEXT,KFN_NOP      ,226 },  0, ""             }, //a/sh pd -    226
  {{ KBD_MAPTEXT,KFN_NOP      ,227 },  0, ""             }, //a/sh pd /    227

  {{ KBD_MAPTEXT,KFN_NOP      ,228 },  0, ""             }, //a/sh F1      228
  {{ KBD_MAPTEXT,KFN_NOP      ,229 },  0, ""             }, //a/sh F2      229
  {{ KBD_MAPTEXT,KFN_NOP      ,230 },  0, ""             }, //a/sh F3      230
  {{ KBD_MAPTEXT,KFN_NOP      ,231 },  0, ""             }, //a/sh F4      231
  {{ KBD_MAPTEXT,KFN_NOP      ,232 },  0, ""             }, //a/sh F5      232
  {{ KBD_MAPTEXT,KFN_NOP      ,233 },  0, ""             }, //a/sh F6      233
  {{ KBD_MAPTEXT,KFN_NOP      ,234 },  0, ""             }, //a/sh F7      234
  {{ KBD_MAPTEXT,KFN_NOP      ,235 },  0, ""             }, //a/sh F8      235
  {{ KBD_MAPTEXT,KFN_NOP      ,236 },  0, ""             }, //a/sh F9      236
  {{ KBD_MAPTEXT,KFN_NOP      ,237 },  0, ""             }, //a/sh F10     237
  {{ KBD_MAPTEXT,KFN_NOP      ,238 },  0, ""             }, //a/sh F11     238
  {{ KBD_MAPTEXT,KFN_NOP      ,239 },  0, ""             }, //a/sh F12     239

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,240 },  0, ""             }, //a/ct bksp    240
  {{ KBD_MAPTEXT,KFN_NOP      ,241 },  0, ""             }, //a/ct tab     241
  {{ KBD_MAPTEXT,KFN_NOP      ,242 },  0, ""             }, //a/ct clr     242
  {{ KBD_MAPTEXT,KFN_NOP      ,243 },  0, ""             }, //a/ct ent     243
  {{ KBD_MAPTEXT,KFN_NOP      ,244 },  0, ""             }, //a/ct pd ent  244
  {{ KBD_MAPTEXT,KFN_NOP      ,245 },  0, ""             }, //a/ct pau     245

  {{ KBD_MAPTEXT,KFN_NOP      ,246 },  0, ""             }, //a/ct pd pu   246
  {{ KBD_MAPTEXT,KFN_NOP      ,247 },  0, ""             }, //a/ct pd pd   247
  {{ KBD_MAPTEXT,KFN_NOP      ,248 },  0, ""             }, //a/ct pd en   248
  {{ KBD_MAPTEXT,KFN_NOP      ,249 },  0, ""             }, //a/ct pd hm   249
  {{ KBD_MAPTEXT,KFN_NOP      ,250 },  0, ""             }, //a/ct pd lf   250
  {{ KBD_MAPTEXT,KFN_NOP      ,251 },  0, ""             }, //a/ct pd up   251
  {{ KBD_MAPTEXT,KFN_NOP      ,252 },  0, ""             }, //a/ct pd rt   252
  {{ KBD_MAPTEXT,KFN_NOP      ,253 },  0, ""             }, //a/ct pd dn   253

  {{ KBD_MAPTEXT,KFN_NOP      ,254 },  0, ""             }, //a/ct gr pu   254
  {{ KBD_MAPTEXT,KFN_NOP      ,255 },  0, ""             }, //a/ct gr pd   255
  {{ KBD_MAPTEXT,KFN_NOP      ,256 },  0, ""             }, //a/ct gr en   256
  {{ KBD_MAPTEXT,KFN_NOP      ,257 },  0, ""             }, //a/ct gr hm   257
  {{ KBD_MAPTEXT,KFN_NOP      ,258 },  0, ""             }, //a/ct gr lf   258
  {{ KBD_MAPTEXT,KFN_NOP      ,259 },  0, ""             }, //a/ct gr up   259
  {{ KBD_MAPTEXT,KFN_NOP      ,260 },  0, ""             }, //a/ct gr rt   260
  {{ KBD_MAPTEXT,KFN_NOP      ,261 },  0, ""             }, //a/ct gr dn   261

  {{ KBD_MAPTEXT,KFN_NOP      ,262 },  0, ""             }, //a/ct pd ins  262
  {{ KBD_MAPTEXT,KFN_NOP      ,263 },  0, ""             }, //a/ct gr ins  263

  {{ KBD_NA_____,KFN_NOP      ,264 },  0, ""             }, //a/ct numlk   264
  {{ KBD_MAPTEXT,KFN_NOP      ,265 },  0, ""             }, //a/ct scrlk   265

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,266 },  0, ""             }, //a/ct pd 0    266
  {{ KBD_MAPTEXT,KFN_NOP      ,267 },  0, ""             }, //a/ct pd 1    267
  {{ KBD_MAPTEXT,KFN_NOP      ,268 },  0, ""             }, //a/ct pd 2    268
  {{ KBD_MAPTEXT,KFN_NOP      ,269 },  0, ""             }, //a/ct pd 3    269
  {{ KBD_MAPTEXT,KFN_NOP      ,270 },  0, ""             }, //a/ct pd 4    270
  {{ KBD_MAPTEXT,KFN_NOP      ,271 },  0, ""             }, //a/ct pd 5    271
  {{ KBD_MAPTEXT,KFN_NOP      ,272 },  0, ""             }, //a/ct pd 6    272
  {{ KBD_MAPTEXT,KFN_NOP      ,273 },  0, ""             }, //a/ct pd 7    273
  {{ KBD_MAPTEXT,KFN_NOP      ,274 },  0, ""             }, //a/ct pd 8    274
  {{ KBD_MAPTEXT,KFN_NOP      ,275 },  0, ""             }, //a/ct pd 9    275

  {{ KBD_MAPTEXT,KFN_NOP      ,276 },  0, ""             }, //a/ct pd *    276
  {{ KBD_MAPTEXT,KFN_NOP      ,277 },  0, ""             }, //a/ct pd +    277
  {{ KBD_MAPTEXT,KFN_NOP      ,278 },  0, ""             }, //a/ct pd -    278
  {{ KBD_MAPTEXT,KFN_NOP      ,279 },  0, ""             }, //a/ct pd .    279
  {{ KBD_MAPTEXT,KFN_NOP      ,280 },  0, ""             }, //a/ct pd /    280

  {{ KBD_MAPTEXT,KFN_NOP      ,281 },  0, ""             }, //a/ct F1      281
  {{ KBD_MAPTEXT,KFN_NOP      ,282 },  0, ""             }, //a/ct F2      282
  {{ KBD_MAPTEXT,KFN_NOP      ,283 },  0, ""             }, //a/ct F3      283
  {{ KBD_MAPTEXT,KFN_NOP      ,284 },  0, ""             }, //a/ct F4      284
  {{ KBD_MAPTEXT,KFN_NOP      ,285 },  0, ""             }, //a/ct F5      285
  {{ KBD_MAPTEXT,KFN_NOP      ,286 },  0, ""             }, //a/ct F6      286
  {{ KBD_MAPTEXT,KFN_NOP      ,287 },  0, ""             }, //a/ct F7      287
  {{ KBD_MAPTEXT,KFN_NOP      ,288 },  0, ""             }, //a/ct F8      288
  {{ KBD_MAPTEXT,KFN_NOP      ,289 },  0, ""             }, //a/ct F9      289
  {{ KBD_MAPTEXT,KFN_NOP      ,290 },  0, ""             }, //a/ct F10     290
  {{ KBD_MAPTEXT,KFN_NOP      ,291 },  0, ""             }, //a/ct F11     291
  {{ KBD_MAPTEXT,KFN_NOP      ,292 },  0, ""             }, //a/ct F12     292

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,293 },  0, ""             }, //a/s/c bksp   293
  {{ KBD_MAPTEXT,KFN_NOP      ,294 },  0, ""             }, //a/s/c tab    294
  {{ KBD_MAPTEXT,KFN_NOP      ,295 },  0, ""             }, //a/s/c clr    295
  {{ KBD_MAPTEXT,KFN_NOP      ,296 },  0, ""             }, //a/s/c ent    296
  {{ KBD_MAPTEXT,KFN_NOP      ,297 },  0, ""             }, //a/s/c pd ent 297
  {{ KBD_MAPTEXT,KFN_NOP      ,298 },  0, ""             }, //a/s/c pau    298

  {{ KBD_MAPTEXT,KFN_NOP      ,299 },  0, ""             }, //a/s/c pd pu  299
  {{ KBD_MAPTEXT,KFN_NOP      ,300 },  0, ""             }, //a/s/c pd pd  300
  {{ KBD_MAPTEXT,KFN_NOP      ,301 },  0, ""             }, //a/s/c pd en  301
  {{ KBD_MAPTEXT,KFN_NOP      ,302 },  0, ""             }, //a/s/c pd hm  302
  {{ KBD_MAPTEXT,KFN_NOP      ,303 },  0, ""             }, //a/s/c pd lf  303
  {{ KBD_MAPTEXT,KFN_NOP      ,304 },  0, ""             }, //a/s/c pd up  304
  {{ KBD_MAPTEXT,KFN_NOP      ,305 },  0, ""             }, //a/s/c pd rt  305
  {{ KBD_MAPTEXT,KFN_NOP      ,306 },  0, ""             }, //a/s/c pd dn  306

  {{ KBD_MAPTEXT,KFN_NOP      ,307 },  0, ""             }, //a/s/c gr pu  307
  {{ KBD_MAPTEXT,KFN_NOP      ,308 },  0, ""             }, //a/s/c gr pd  308
  {{ KBD_MAPTEXT,KFN_NOP      ,309 },  0, ""             }, //a/s/c gr en  309
  {{ KBD_MAPTEXT,KFN_NOP      ,310 },  0, ""             }, //a/s/c gr hm  310
  {{ KBD_MAPTEXT,KFN_NOP      ,311 },  0, ""             }, //a/s/c gr lf  311
  {{ KBD_MAPTEXT,KFN_NOP      ,312 },  0, ""             }, //a/s/c gr up  312
  {{ KBD_MAPTEXT,KFN_NOP      ,313 },  0, ""             }, //a/s/c gr rt  313
  {{ KBD_MAPTEXT,KFN_NOP      ,314 },  0, ""             }, //a/s/c gr dn  314

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPTEXT,KFN_NOP      ,315 },  0, ""             }, //a/s/c pd ins 315
  {{ KBD_MAPTEXT,KFN_NOP      ,316 },  0, ""             }, //a/s/c gr ins 316

  {{ KBD_NA_____,KFN_NOP      ,317 },  0, ""             }, //a/s/c numlk  317
  {{ KBD_NA_____,KFN_NOP      ,318 },  0, ""             }, //a/s/c scrlk  318

  {{ KBD_MAPTEXT,KFN_NOP      ,319 },  0, ""             }, //a/s/c pd *   319
  {{ KBD_MAPTEXT,KFN_NOP      ,320 },  0, ""             }, //a/s/c pd +   320
  {{ KBD_MAPTEXT,KFN_NOP      ,321 },  0, ""             }, //a/s/c pd -   321
  {{ KBD_MAPTEXT,KFN_NOP      ,322 },  0, ""             }, //a/s/c pd /   322

  {{ KBD_MAPTEXT,KFN_NOP      ,323 },  0, ""             }, //a/s/c F1     323
  {{ KBD_MAPTEXT,KFN_NOP      ,324 },  0, ""             }, //a/s/c F2     324
  {{ KBD_MAPTEXT,KFN_NOP      ,325 },  0, ""             }, //a/s/c F3     325
  {{ KBD_MAPTEXT,KFN_NOP      ,326 },  0, ""             }, //a/s/c F4     326
  {{ KBD_MAPTEXT,KFN_NOP      ,327 },  0, ""             }, //a/s/c F5     327
  {{ KBD_MAPTEXT,KFN_NOP      ,328 },  0, ""             }, //a/s/c F6     328
  {{ KBD_MAPTEXT,KFN_NOP      ,329 },  0, ""             }, //a/s/c F7     329
  {{ KBD_MAPTEXT,KFN_NOP      ,330 },  0, ""             }, //a/s/c F8     330
  {{ KBD_MAPTEXT,KFN_NOP      ,331 },  0, ""             }, //a/s/c F9     331
  {{ KBD_MAPTEXT,KFN_NOP      ,332 },  0, ""             }, //a/s/c F10    332
  {{ KBD_MAPTEXT,KFN_NOP      ,333 },  0, ""             }, //a/s/c F11    333
  {{ KBD_MAPTEXT,KFN_NOP      ,334 },  0, ""             }  //a/s/c F12    334
   }
};


EMUL_RES_STRUCT _far* rgers[] =
{
   &ers0, &ers1
};

int main(int argc, char * argv[])
{
   int  size;
   FILE *fptr;
   int  i,j,k;
   char FAR *a;
   char filespec[256];
   char *filename;

   // create files in same path used to launch app
   _fstrcpy(filespec,argv[0]);
   filename = filespec + strlen(filespec);
   while((filename != filespec) && (*(filename - 1) != '\\') &&
      (*(filename - 1) != ':'))
      --filename;

   for ( i=0; i<(sizeof(rgers)/sizeof(rgers[0])); i++)
   {
      _fstrcpy(filename,rgers[i]->szResName);
      if(!(fptr = fopen(filespec,"wb")))
         continue;

      // calc heapsize first
      rgers[i]->heapsize = 0;
      for (j=0;j<NUMMAPSTRINGS;j++)
         rgers[i]->heapsize += rgers[i]->mss[j].strsize+1;
      size = sizeof(unsigned int);

      // we are now writing info out in a format compatible with
      // EMUL_VKEY_FILE_STRUCT, which it will be read into during a file load.
      a = (char FAR *)&rgers[i]->heapsize;
      for (k=0;k<size;k++)
      {
         putc(*a,fptr);
         a++;
      }
      a = (char FAR *)&rgers[i]->Flag1;
      for (k=0;k<size;k++)
      {
         putc(*a,fptr);
         a++;
      }
      a = (char FAR *)&rgers[i]->Flag2;
      for (k=0;k<size;k++)
      {
         putc(*a,fptr);
         a++;
      }

      for (j=0;j<NUMMAPSTRINGS;j++)
      {
         a = (char FAR *)&rgers[i]->mss[j].vks.vkeytype;
         for (k=0;k<sizeof(VIRT_KEY_CODE_STRUCT);k++) // copy virt key structs
         {
            putc(*a,fptr);
            a++;
         }
      }
      for (j=0;j<NUMMAPSTRINGS;j++)
      {
         a = (char FAR *)&rgers[i]->mss[j].strsize;
         size = *a;
         putc(*a++,fptr);     // put size char no matter what
         for (k=0;k<size;k++) // copy str chars
            putc(*a++,fptr);
      }
      fclose(fptr);
   }

   _fstrcpy(filename,"makek101.bin");
   if(fptr = fopen(filespec, "wb"))
      fclose(fptr) ;

   return 0 ;
}

