/*
 
                                                                          
         File:   pwmkacc.c                                               
                                                                          
  Description:   Generate an accelerator key file                        
                                                                          
 
                                                                          
                  Copyright (C) 1999 Symantec Corporation                 
                             All Rights Reserved                          
                                                                          
       Information in this file is proprietary and confidential, and      
         may not be copied, reproduced or distributed in any manner       
     without the express written permission of Symantec Corp.             
                                                                          
 
*/

#define  STRICT
#include <windows.h>
#include <stdio.h>
#include <string.h>
#include "gpwindlx.h"
#include "pwdlx.h"
#include "menudlx.h"
#include "kbdredlx.h"
//#include "trmdefs.h"

#define ACCDEBUG 1


typedef struct                // info about the function a key performs, and
{                             // appropriate indexes into the string heap and
   unsigned char vkeytype;    // internal function table
   unsigned char funcndx;
   unsigned int strndx;
}  VIRT_KEY_CODE_STRUCT;

typedef struct                // struct for a single key's type and contents
{                             // to be filled in when creating resource
   VIRT_KEY_CODE_STRUCT vks;
   unsigned char strsize;     // length of following mapped string
   unsigned char str[20];     // mapped string contents - no length byte at front
}  MAP_STRING_STRUCT;

typedef struct                // struct to create a resource for an entire
{                             // accel key file
   unsigned heapsize;
   unsigned Flag1;
   unsigned Flag2;
   MAP_STRING_STRUCT mss[NUMACCSTRINGS];  // table of string resources
}  ACC_RES_STRUCT;


#ifdef ACCDEBUG

ACC_RES_STRUCT ars   =
{
// ars.heapsize
   0,             // not calculated yet!
// ars.Flag1
   0,
// ars.Flag2
   0,
// ars.mss[NUMACCSTRINGS]
   {

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      ,  0 },  4, "ct a"            }, //ct a        0
  {{ ACC_MAPTEXT,KFN_NOP      ,  1 },  4, "ct b"            }, //ct b        1
  {{ ACC_MAPTEXT,KFN_NOP      ,  2 },  4, "ct c"            }, //ct c        2
  {{ ACC_MAPTEXT,KFN_NOP      ,  3 },  4, "ct d"            }, //ct d        3
  {{ ACC_MAPTEXT,KFN_NOP      ,  4 },  4, "ct e"            }, //ct e        4
  {{ ACC_MAPTEXT,KFN_NOP      ,  5 },  4, "ct f"            }, //ct f        5
  {{ ACC_MAPTEXT,KFN_NOP      ,  6 },  4, "ct g"            }, //ct g        6
  {{ ACC_MAPTEXT,KFN_NOP      ,  7 },  4, "ct h"            }, //ct h        7
  {{ ACC_MAPTEXT,KFN_NOP      ,  8 },  4, "ct i"            }, //ct i        8
  {{ ACC_MAPTEXT,KFN_NOP      ,  9 },  4, "ct j"            }, //ct j        9
  {{ ACC_MAPTEXT,KFN_NOP      , 10 },  4, "ct k"            }, //ct k       10
  {{ ACC_MAPTEXT,KFN_NOP      , 11 },  4, "ct l"            }, //ct l       11
  {{ ACC_MAPTEXT,KFN_NOP      , 12 },  4, "ct m"            }, //ct m       12

  {{ ACC_MAPTEXT,KFN_NOP      , 13 },  4, "ct n"            }, //ct n       13
  {{ ACC_MAPTEXT,KFN_NOP      , 14 },  4, "ct o"            }, //ct o       14
  {{ ACC_MAPTEXT,KFN_NOP      , 15 },  4, "ct p"            }, //ct p       15
  {{ ACC_MAPTEXT,KFN_NOP      , 16 },  4, "ct q"            }, //ct q       16
  {{ ACC_MAPTEXT,KFN_NOP      , 17 },  4, "ct r"            }, //ct r       17
  {{ ACC_MAPTEXT,KFN_NOP      , 18 },  4, "ct s"            }, //ct s       18
  {{ ACC_MAPTEXT,KFN_NOP      , 19 },  4, "ct t"            }, //ct t       19
  {{ ACC_MAPTEXT,KFN_NOP      , 20 },  4, "ct u"            }, //ct u       20
  {{ ACC_MAPTEXT,KFN_NOP      , 21 },  4, "ct v"            }, //ct v       21
  {{ ACC_MAPTEXT,KFN_NOP      , 22 },  4, "ct w"            }, //ct w       22
  {{ ACC_MAPTEXT,KFN_NOP      , 23 },  4, "ct x"            }, //ct x       23
  {{ ACC_MAPTEXT,KFN_NOP      , 24 },  4, "ct y"            }, //ct y       24
  {{ ACC_MAPTEXT,KFN_NOP      , 25 },  4, "ct z"            }, //ct z       25

  {{ ACC_MAPTEXT,KFN_NOP      , 26 },  4, "ct `"            }, //ct `       26
  {{ ACC_MAPTEXT,KFN_NOP      , 27 },  4, "ct -"            }, //ct -       27
  {{ ACC_MAPTEXT,KFN_NOP      , 28 },  4, "ct ="            }, //ct =       28
  {{ ACC_MAPTEXT,KFN_NOP      , 29 },  4, "ct ["            }, //ct [       29
  {{ ACC_MAPTEXT,KFN_NOP      , 30 },  4, "ct ]"            }, //ct ]       30
  {{ ACC_MAPTEXT,KFN_NOP      , 31 },  4, "ct ;"            }, //ct ;       31
  {{ ACC_MAPTEXT,KFN_NOP      , 32 },  4, "ct '"            }, //ct '       32
  {{ ACC_MAPTEXT,KFN_NOP      , 33 },  4, "ct ,"            }, //ct ,       33
  {{ ACC_MAPTEXT,KFN_NOP      , 34 },  4, "ct ."            }, //ct .       34
  {{ ACC_MAPTEXT,KFN_NOP      , 35 },  4, "ct /"            }, //ct /       35
  {{ ACC_MAPTEXT,KFN_NOP      , 36 },  4, "ct \\"           }, //ct \       36

  {{ ACC_MAPTEXT,KFN_NOP      , 37 },  4, "ct 1"            }, //ct 1       37
  {{ ACC_MAPTEXT,KFN_NOP      , 38 },  4, "ct 2"            }, //ct 2       38
  {{ ACC_MAPTEXT,KFN_NOP      , 39 },  4, "ct 3"            }, //ct 3       39
  {{ ACC_MAPTEXT,KFN_NOP      , 40 },  4, "ct 4"            }, //ct 4       40
  {{ ACC_MAPTEXT,KFN_NOP      , 41 },  4, "ct 5"            }, //ct 5       41
  {{ ACC_MAPTEXT,KFN_NOP      , 42 },  4, "ct 6"            }, //ct 6       42
  {{ ACC_MAPTEXT,KFN_NOP      , 43 },  4, "ct 7"            }, //ct 7       43
  {{ ACC_MAPTEXT,KFN_NOP      , 44 },  4, "ct 8"            }, //ct 8       44
  {{ ACC_MAPTEXT,KFN_NOP      , 45 },  4, "ct 9"            }, //ct 9       45
  {{ ACC_MAPTEXT,KFN_NOP      , 46 },  4, "ct 0"            }, //ct 0       46

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      , 47 },  7, "ct sh a"         }, //ct sh a    47
  {{ ACC_MAPTEXT,KFN_NOP      , 48 },  7, "ct sh b"         }, //ct sh b    48
  {{ ACC_MAPTEXT,KFN_NOP      , 49 },  7, "ct sh c"         }, //ct sh c    49
  {{ ACC_MAPTEXT,KFN_NOP      , 50 },  7, "ct sh d"         }, //ct sh d    50
  {{ ACC_MAPTEXT,KFN_NOP      , 51 },  7, "ct sh e"         }, //ct sh e    51
  {{ ACC_MAPTEXT,KFN_NOP      , 52 },  7, "ct sh f"         }, //ct sh f    52
  {{ ACC_MAPTEXT,KFN_NOP      , 53 },  7, "ct sh g"         }, //ct sh g    53
  {{ ACC_MAPTEXT,KFN_NOP      , 54 },  7, "ct sh h"         }, //ct sh h    54
  {{ ACC_MAPTEXT,KFN_NOP      , 55 },  7, "ct sh i"         }, //ct sh i    55
  {{ ACC_MAPTEXT,KFN_NOP      , 56 },  7, "ct sh j"         }, //ct sh j    56
  {{ ACC_MAPTEXT,KFN_NOP      , 57 },  7, "ct sh k"         }, //ct sh k    57
  {{ ACC_MAPTEXT,KFN_NOP      , 58 },  7, "ct sh l"         }, //ct sh l    58
  {{ ACC_MAPTEXT,KFN_NOP      , 59 },  7, "ct sh m"         }, //ct sh m    59

  {{ ACC_MAPTEXT,KFN_NOP      , 60 },  7, "ct sh n"         }, //ct sh n    60
  {{ ACC_MAPTEXT,KFN_NOP      , 61 },  7, "ct sh o"         }, //ct sh o    61
  {{ ACC_MAPTEXT,KFN_NOP      , 62 },  7, "ct sh p"         }, //ct sh p    62
  {{ ACC_MAPTEXT,KFN_NOP      , 63 },  7, "ct sh q"         }, //ct sh q    63
  {{ ACC_MAPTEXT,KFN_NOP      , 64 },  7, "ct sh r"         }, //ct sh r    64
  {{ ACC_MAPTEXT,KFN_NOP      , 65 },  7, "ct sh s"         }, //ct sh s    65
  {{ ACC_MAPTEXT,KFN_NOP      , 66 },  7, "ct sh t"         }, //ct sh t    66
  {{ ACC_MAPTEXT,KFN_NOP      , 67 },  7, "ct sh u"         }, //ct sh u    67
  {{ ACC_MAPTEXT,KFN_NOP      , 68 },  7, "ct sh v"         }, //ct sh v    68
  {{ ACC_MAPTEXT,KFN_NOP      , 69 },  7, "ct sh w"         }, //ct sh w    69
  {{ ACC_MAPTEXT,KFN_NOP      , 70 },  7, "ct sh x"         }, //ct sh x    70
  {{ ACC_MAPTEXT,KFN_NOP      , 71 },  7, "ct sh y"         }, //ct sh y    71
  {{ ACC_MAPTEXT,KFN_NOP      , 72 },  7, "ct sh z"         }, //ct sh z    72

  {{ ACC_MAPTEXT,KFN_NOP      , 73 },  7, "ct sh `"         }, //ct sh `    73
  {{ ACC_MAPTEXT,KFN_NOP      , 74 },  7, "ct sh -"         }, //ct sh -    74
  {{ ACC_MAPTEXT,KFN_NOP      , 75 },  7, "ct sh ="         }, //ct sh =    75
  {{ ACC_MAPTEXT,KFN_NOP      , 76 },  7, "ct sh ["         }, //ct sh [    76
  {{ ACC_MAPTEXT,KFN_NOP      , 77 },  7, "ct sh ]"         }, //ct sh ]    77
  {{ ACC_MAPTEXT,KFN_NOP      , 78 },  7, "ct sh ;"         }, //ct sh ;    78
  {{ ACC_MAPTEXT,KFN_NOP      , 79 },  7, "ct sh '"         }, //ct sh '    79
  {{ ACC_MAPTEXT,KFN_NOP      , 80 },  7, "ct sh ,"         }, //ct sh ,    80
  {{ ACC_MAPTEXT,KFN_NOP      , 81 },  7, "ct sh ."         }, //ct sh .    81
  {{ ACC_MAPTEXT,KFN_NOP      , 82 },  7, "ct sh /"         }, //ct sh /    82
  {{ ACC_MAPTEXT,KFN_NOP      , 83 },  7, "ct sh \\"        }, //ct sh \    83

  {{ ACC_MAPTEXT,KFN_NOP      , 84 },  7, "ct sh 1"         }, //ct sh 1    84
  {{ ACC_MAPTEXT,KFN_NOP      , 85 },  7, "ct sh 2"         }, //ct sh 2    85
  {{ ACC_MAPTEXT,KFN_NOP      , 86 },  7, "ct sh 3"         }, //ct sh 3    86
  {{ ACC_MAPTEXT,KFN_NOP      , 87 },  7, "ct sh 4"         }, //ct sh 4    87
  {{ ACC_MAPTEXT,KFN_NOP      , 88 },  7, "ct sh 5"         }, //ct sh 5    88
  {{ ACC_MAPTEXT,KFN_NOP      , 89 },  7, "ct sh 6"         }, //ct sh 6    89
  {{ ACC_MAPTEXT,KFN_NOP      , 90 },  7, "ct sh 7"         }, //ct sh 7    90
  {{ ACC_MAPTEXT,KFN_NOP      , 91 },  7, "ct sh 8"         }, //ct sh 8    91
  {{ ACC_MAPTEXT,KFN_NOP      , 92 },  7, "ct sh 9"         }, //ct sh 9    92
  {{ ACC_MAPTEXT,KFN_NOP      , 93 },  7, "ct sh 0"         }, //ct sh 0    93

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      , 94 },  5, "alt a"           }, //alt a      94
  {{ ACC_MAPTEXT,KFN_NOP      , 95 },  5, "alt b"           }, //alt b      95
  {{ ACC_MAPTEXT,KFN_NOP      , 96 },  5, "alt c"           }, //alt c      96
  {{ ACC_MAPTEXT,KFN_NOP      , 97 },  5, "alt d"           }, //alt d      97
  {{ ACC_MAPTEXT,KFN_NOP      , 98 },  5, "alt e"           }, //alt e      98
  {{ ACC_MAPTEXT,KFN_NOP      , 99 },  5, "alt f"           }, //alt f      99
  {{ ACC_MAPTEXT,KFN_NOP      ,100 },  5, "alt g"           }, //alt g     100
  {{ ACC_MAPTEXT,KFN_NOP      ,101 },  5, "alt h"           }, //alt h     101
  {{ ACC_MAPTEXT,KFN_NOP      ,102 },  5, "alt i"           }, //alt i     102
  {{ ACC_MAPTEXT,KFN_NOP      ,103 },  5, "alt j"           }, //alt j     103
  {{ ACC_MAPTEXT,KFN_NOP      ,104 },  5, "alt k"           }, //alt k     104
  {{ ACC_MAPTEXT,KFN_NOP      ,105 },  5, "alt l"           }, //alt l     105
  {{ ACC_MAPTEXT,KFN_NOP      ,106 },  5, "alt m"           }, //alt m     106

  {{ ACC_MAPTEXT,KFN_NOP      ,107 },  5, "alt n"           }, //alt n     107
  {{ ACC_MAPTEXT,KFN_NOP      ,108 },  5, "alt o"           }, //alt o     108
  {{ ACC_MAPTEXT,KFN_NOP      ,109 },  5, "alt p"           }, //alt p     109
  {{ ACC_MAPTEXT,KFN_NOP      ,110 },  5, "alt q"           }, //alt q     110
  {{ ACC_MAPTEXT,KFN_NOP      ,111 },  5, "alt r"           }, //alt r     111
  {{ ACC_MAPTEXT,KFN_NOP      ,112 },  5, "alt s"           }, //alt s     112
  {{ ACC_MAPTEXT,KFN_NOP      ,113 },  5, "alt t"           }, //alt t     113
  {{ ACC_MAPTEXT,KFN_NOP      ,114 },  5, "alt u"           }, //alt u     114
  {{ ACC_MAPTEXT,KFN_NOP      ,115 },  5, "alt v"           }, //alt v     115
  {{ ACC_MAPTEXT,KFN_NOP      ,116 },  5, "alt w"           }, //alt w     116
  {{ ACC_MAPTEXT,KFN_NOP      ,117 },  5, "alt x"           }, //alt x     117
  {{ ACC_MAPTEXT,KFN_NOP      ,118 },  5, "alt y"           }, //alt y     118
  {{ ACC_MAPTEXT,KFN_NOP      ,119 },  5, "alt z"           }, //alt z     119

  {{ ACC_MAPTEXT,KFN_NOP      ,120 },  5, "alt `"           }, //alt `     120
  {{ ACC_MAPTEXT,KFN_NOP      ,121 },  5, "alt -"           }, //alt -     121
  {{ ACC_MAPTEXT,KFN_NOP      ,122 },  5, "alt ="           }, //alt =     122
  {{ ACC_MAPTEXT,KFN_NOP      ,123 },  5, "alt ["           }, //alt [     123
  {{ ACC_MAPTEXT,KFN_NOP      ,124 },  5, "alt ]"           }, //alt ]     124
  {{ ACC_MAPTEXT,KFN_NOP      ,125 },  5, "alt ;"           }, //alt ;     125
  {{ ACC_MAPTEXT,KFN_NOP      ,126 },  5, "alt '"           }, //alt '     126
  {{ ACC_MAPTEXT,KFN_NOP      ,127 },  5, "alt ,"           }, //alt ,     127
  {{ ACC_MAPTEXT,KFN_NOP      ,128 },  5, "alt ."           }, //alt .     128
  {{ ACC_MAPTEXT,KFN_NOP      ,129 },  5, "alt /"           }, //alt /     129
  {{ ACC_MAPTEXT,KFN_NOP      ,130 },  5, "alt \\"          }, //alt \     130

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      ,131 },  6, "a/bksp"          }, //a/bksp    131
  {{ ACC_MAPTEXT,KFN_NOP      ,132 },  5, "a/tab"           }, //a/tab     132
  {{ ACC_MAPTEXT,KFN_NOP      ,133 },  7, "a/clear"         }, //a/clear   133
  {{ ACC_MAPTEXT,KFN_NOP      ,134 },  7, "a/enter"         }, //a/enter   134
  {{ ACC_MAPTEXT,KFN_NOP      ,135 },  8, "a/pd ent"        }, //a/pd ent  135
  {{ ACC_MAPTEXT,KFN_NOP      ,136 },  7, "a/pause"         }, //a/pause   136

  {{ ACC_MAPTEXT,KFN_NOP      ,137 },  9, "a/pd pgup"       }, //a/pd pgup 137
  {{ ACC_MAPTEXT,KFN_NOP      ,138 },  9, "a/pd pgdn"       }, //a/pd pgdn 138
  {{ ACC_MAPTEXT,KFN_NOP      ,139 },  8, "a/pd end"        }, //a/pd end  139
  {{ ACC_MAPTEXT,KFN_NOP      ,140 },  9, "a/pd home"       }, //a/pd home 140
  {{ ACC_MAPTEXT,KFN_NOP      ,141 },  7, "a/pd lf"         }, //a/pd lf   141
  {{ ACC_MAPTEXT,KFN_NOP      ,142 },  7, "a/pd up"         }, //a/pd up   142
  {{ ACC_MAPTEXT,KFN_NOP      ,143 },  7, "a/pd rt"         }, //a/pd rt   143
  {{ ACC_MAPTEXT,KFN_NOP      ,144 },  7, "a/pd dn"         }, //a/pd dn   144

  {{ ACC_MAPTEXT,KFN_NOP      ,145 },  9, "a/gr pgup"       }, //a/gr pgup 145
  {{ ACC_MAPTEXT,KFN_NOP      ,146 },  9, "a/gr pgdn"       }, //a/gr pgdn 146
  {{ ACC_MAPTEXT,KFN_NOP      ,147 },  8, "a/gr end"        }, //a/gr end  147
  {{ ACC_MAPTEXT,KFN_NOP      ,148 },  9, "a/gr home"       }, //a/gr home 148
  {{ ACC_MAPTEXT,KFN_NOP      ,149 },  7, "a/gr lf"         }, //a/gr lf   149
  {{ ACC_MAPTEXT,KFN_NOP      ,150 },  7, "a/gr up"         }, //a/gr up   150
  {{ ACC_MAPTEXT,KFN_NOP      ,151 },  7, "a/gr rt"         }, //a/gr rt   151
  {{ ACC_MAPTEXT,KFN_NOP      ,152 },  7, "a/gr dn"         }, //a/gr dn   152

  {{ ACC_MAPTEXT,KFN_NOP      ,153 },  8, "a/pd ins"        }, //a/pd ins  153
  {{ ACC_MAPTEXT,KFN_NOP      ,154 },  8, "a/pd del"        }, //a/pd del  154
  {{ ACC_MAPTEXT,KFN_NOP      ,155 },  8, "a/gr ins"        }, //a/gr ins  155
  {{ ACC_MAPTEXT,KFN_NOP      ,156 },  8, "a/gr del"        }, //a/gr del  156

  {{ ACC_MAPTEXT,KFN_NOP      ,157 },  7, "a/numlk"         }, //a/numlk   157
  {{ ACC_MAPTEXT,KFN_NOP      ,158 },  7, "a/scrlk"         }, //a/scrlk   158

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      ,159 },  6, "a/pd *"          }, //a/pd *    159
  {{ ACC_MAPTEXT,KFN_NOP      ,160 },  6, "a/pd +"          }, //a/pd +    160
  {{ ACC_MAPTEXT,KFN_NOP      ,161 },  6, "a/pd -"          }, //a/pd -    161
  {{ ACC_MAPTEXT,KFN_NOP      ,162 },  6, "a/pd ."          }, //a/pd .    162
  {{ ACC_MAPTEXT,KFN_NOP      ,163 },  6, "a/pd /"          }, //a/pd /    146
  {{ ACC_MAPTEXT,KFN_LOG      ,164 },  4, "a/F1"            }, //a/F1      164
  {{ ACC_MAPTEXT,KFN_NOP      ,165 },  4, "a/F2"            }, //a/F2      165
  {{ ACC_MAPTEXT,KFN_NOP      ,166 },  4, "a/F3"            }, //a/F3      166
  {{ ACC_MAPTEXT,KFN_NOP      ,167 },  4, "a/F4"            }, //a/F4      167
  {{ ACC_MAPTEXT,KFN_NOP      ,168 },  4, "a/F5"            }, //a/F5      168
  {{ ACC_MAPTEXT,KFN_NOP      ,169 },  4, "a/F6"            }, //a/F6      169
  {{ ACC_MAPTEXT,KFN_NOP      ,170 },  4, "a/F7"            }, //a/F7      170
  {{ ACC_MAPTEXT,KFN_NOP      ,171 },  4, "a/F8"            }, //a/F8      171
  {{ ACC_MAPTEXT,KFN_NOP      ,172 },  4, "a/F9"            }, //a/F9      172
  {{ ACC_MAPTEXT,KFN_NOP      ,173 },  5, "a/F10"           }, //a/F10     173
  {{ ACC_MAPTEXT,KFN_NOP      ,174 },  5, "a/F11"           }, //a/F11     174
  {{ ACC_MAPTEXT,KFN_NOP      ,175 },  5, "a/F12"           }, //a/F12     175

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      ,176 },  8, "alt sh a"        }, //alt sh a  176
  {{ ACC_MAPTEXT,KFN_NOP      ,177 },  8, "alt sh b"        }, //alt sh b  177
  {{ ACC_MAPTEXT,KFN_NOP      ,178 },  8, "alt sh c"        }, //alt sh c  178
  {{ ACC_MAPTEXT,KFN_NOP      ,179 },  8, "alt sh d"        }, //alt sh d  179
  {{ ACC_MAPTEXT,KFN_NOP      ,180 },  8, "alt sh e"        }, //alt sh e  180
  {{ ACC_MAPTEXT,KFN_NOP      ,181 },  8, "alt sh f"        }, //alt sh f  181
  {{ ACC_MAPTEXT,KFN_NOP      ,182 },  8, "alt sh g"        }, //alt sh g  182
  {{ ACC_MAPTEXT,KFN_NOP      ,183 },  8, "alt sh h"        }, //alt sh h  183
  {{ ACC_MAPTEXT,KFN_NOP      ,184 },  8, "alt sh i"        }, //alt sh i  184
  {{ ACC_MAPTEXT,KFN_NOP      ,185 },  8, "alt sh j"        }, //alt sh j  185
  {{ ACC_MAPTEXT,KFN_NOP      ,186 },  8, "alt sh k"        }, //alt sh k  186
  {{ ACC_MAPTEXT,KFN_NOP      ,187 },  8, "alt sh l"        }, //alt sh l  187
  {{ ACC_MAPTEXT,KFN_NOP      ,188 },  8, "alt sh m"        }, //alt sh m  188

  {{ ACC_MAPTEXT,KFN_NOP      ,189 },  8, "alt sh n"        }, //alt sh n  189
  {{ ACC_MAPTEXT,KFN_NOP      ,190 },  8, "alt sh o"        }, //alt sh o  190
  {{ ACC_MAPTEXT,KFN_NOP      ,191 },  8, "alt sh p"        }, //alt sh p  191
  {{ ACC_MAPTEXT,KFN_NOP      ,192 },  8, "alt sh q"        }, //alt sh q  192
  {{ ACC_MAPTEXT,KFN_NOP      ,193 },  8, "alt sh r"        }, //alt sh r  193
  {{ ACC_MAPTEXT,KFN_NOP      ,194 },  8, "alt sh s"        }, //alt sh s  194
  {{ ACC_MAPTEXT,KFN_NOP      ,195 },  8, "alt sh t"        }, //alt sh t  195
  {{ ACC_MAPTEXT,KFN_NOP      ,196 },  8, "alt sh u"        }, //alt sh u  196
  {{ ACC_MAPTEXT,KFN_NOP      ,197 },  8, "alt sh v"        }, //alt sh v  197
  {{ ACC_MAPTEXT,KFN_NOP      ,198 },  8, "alt sh w"        }, //alt sh w  198
  {{ ACC_MAPTEXT,KFN_NOP      ,199 },  8, "alt sh x"        }, //alt sh x  199
  {{ ACC_MAPTEXT,KFN_NOP      ,200 },  8, "alt sh y"        }, //alt sh y  200
  {{ ACC_MAPTEXT,KFN_NOP      ,201 },  8, "alt sh z"        }, //alt sh z  201

  {{ ACC_MAPTEXT,KFN_NOP      ,202 },  8, "alt sh `"        }, //alt sh `  202
  {{ ACC_MAPTEXT,KFN_NOP      ,203 },  8, "alt sh -"        }, //alt sh -  203
  {{ ACC_MAPTEXT,KFN_NOP      ,204 },  8, "alt sh ="        }, //alt sh =  204
  {{ ACC_MAPTEXT,KFN_NOP      ,205 },  8, "alt sh ["        }, //alt sh [  205
  {{ ACC_MAPTEXT,KFN_NOP      ,206 },  8, "alt sh ]"        }, //alt sh ]  206
  {{ ACC_MAPTEXT,KFN_NOP      ,207 },  8, "alt sh ;"        }, //alt sh ;  207
  {{ ACC_MAPTEXT,KFN_NOP      ,208 },  8, "alt sh '"        }, //alt sh '  208
  {{ ACC_MAPTEXT,KFN_NOP      ,209 },  8, "alt sh ,"        }, //alt sh ,  209
  {{ ACC_MAPTEXT,KFN_NOP      ,210 },  8, "alt sh ."        }, //alt sh .  210
  {{ ACC_MAPTEXT,KFN_NOP      ,211 },  8, "alt sh /"        }, //alt sh /  211
  {{ ACC_MAPTEXT,KFN_NOP      ,212 },  8, "alt sh \\"       }, //alt sh \  212

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      ,213 },  8, "alt ct a"        }, //alt ct a  213
  {{ ACC_MAPTEXT,KFN_NOP      ,214 },  8, "alt ct b"        }, //alt ct b  214
  {{ ACC_MAPTEXT,KFN_NOP      ,215 },  8, "alt ct c"        }, //alt ct c  215
  {{ ACC_MAPTEXT,KFN_NOP      ,216 },  8, "alt ct d"        }, //alt ct d  216
  {{ ACC_MAPTEXT,KFN_NOP      ,217 },  8, "alt ct e"        }, //alt ct e  217
  {{ ACC_MAPTEXT,KFN_NOP      ,218 },  8, "alt ct f"        }, //alt ct f  218
  {{ ACC_MAPTEXT,KFN_NOP      ,219 },  8, "alt ct g"        }, //alt ct g  219
  {{ ACC_MAPTEXT,KFN_NOP      ,220 },  8, "alt ct h"        }, //alt ct h  220
  {{ ACC_MAPTEXT,KFN_NOP      ,221 },  8, "alt ct i"        }, //alt ct i  221
  {{ ACC_MAPTEXT,KFN_NOP      ,222 },  8, "alt ct j"        }, //alt ct j  222
  {{ ACC_MAPTEXT,KFN_NOP      ,223 },  8, "alt ct k"        }, //alt ct k  223
  {{ ACC_MAPTEXT,KFN_NOP      ,224 },  8, "alt ct l"        }, //alt ct l  224
  {{ ACC_MAPTEXT,KFN_NOP      ,225 },  8, "alt ct m"        }, //alt ct m  225

  {{ ACC_MAPTEXT,KFN_NOP      ,226 },  8, "alt ct n"        }, //alt ct n  226
  {{ ACC_MAPTEXT,KFN_NOP      ,227 },  8, "alt ct o"        }, //alt ct o  227
  {{ ACC_MAPTEXT,KFN_NOP      ,228 },  8, "alt ct p"        }, //alt ct p  228
  {{ ACC_MAPTEXT,KFN_NOP      ,229 },  8, "alt ct q"        }, //alt ct q  229
  {{ ACC_MAPTEXT,KFN_NOP      ,230 },  8, "alt ct r"        }, //alt ct r  230
  {{ ACC_MAPTEXT,KFN_NOP      ,231 },  8, "alt ct s"        }, //alt ct s  231
  {{ ACC_MAPTEXT,KFN_NOP      ,232 },  8, "alt ct t"        }, //alt ct t  232
  {{ ACC_MAPTEXT,KFN_NOP      ,233 },  8, "alt ct u"        }, //alt ct u  233
  {{ ACC_MAPTEXT,KFN_NOP      ,234 },  8, "alt ct v"        }, //alt ct v  234
  {{ ACC_MAPTEXT,KFN_NOP      ,235 },  8, "alt ct w"        }, //alt ct w  235
  {{ ACC_MAPTEXT,KFN_NOP      ,236 },  8, "alt ct x"        }, //alt ct x  236
  {{ ACC_MAPTEXT,KFN_NOP      ,237 },  8, "alt ct y"        }, //alt ct y  237
  {{ ACC_MAPTEXT,KFN_NOP      ,238 },  8, "alt ct z"        }, //alt ct z  238

  {{ ACC_MAPTEXT,KFN_NOP      ,239 },  8, "alt ct `"        }, //alt ct `  239
  {{ ACC_MAPTEXT,KFN_NOP      ,240 },  8, "alt ct -"        }, //alt ct -  240
  {{ ACC_MAPTEXT,KFN_NOP      ,241 },  8, "alt ct ="        }, //alt ct =  241
  {{ ACC_MAPTEXT,KFN_NOP      ,242 },  8, "alt ct ["        }, //alt ct [  242
  {{ ACC_MAPTEXT,KFN_NOP      ,243 },  8, "alt ct ]"        }, //alt ct ]  243
  {{ ACC_MAPTEXT,KFN_NOP      ,244 },  8, "alt ct ;"        }, //alt ct ;  244
  {{ ACC_MAPTEXT,KFN_NOP      ,245 },  8, "alt ct '"        }, //alt ct '  245
  {{ ACC_MAPTEXT,KFN_NOP      ,246 },  8, "alt ct ,"        }, //alt ct ,  246
  {{ ACC_MAPTEXT,KFN_NOP      ,247 },  8, "alt ct ."        }, //alt ct .  247
  {{ ACC_MAPTEXT,KFN_NOP      ,248 },  8, "alt ct /"        }, //alt ct /  248
  {{ ACC_MAPTEXT,KFN_NOP      ,249 },  8, "alt ct \\"       }, //alt ct \  249

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPTEXT,KFN_NOP      ,250 }, 11, "alt ct sh a"     }, //a/sh ct a 250
  {{ ACC_MAPTEXT,KFN_NOP      ,251 }, 11, "alt ct sh b"     }, //a/sh ct b 251
  {{ ACC_MAPTEXT,KFN_NOP      ,252 }, 11, "alt ct sh c"     }, //a/sh ct c 252
  {{ ACC_MAPTEXT,KFN_NOP      ,253 }, 11, "alt ct sh d"     }, //a/sh ct d 253
  {{ ACC_MAPTEXT,KFN_NOP      ,254 }, 11, "alt ct sh e"     }, //a/sh ct e 254
  {{ ACC_MAPTEXT,KFN_NOP      ,255 }, 11, "alt ct sh f"     }, //a/sh ct f 255
  {{ ACC_MAPTEXT,KFN_NOP      ,256 }, 11, "alt ct sh g"     }, //a/sh ct g 256
  {{ ACC_MAPTEXT,KFN_NOP      ,257 }, 11, "alt ct sh h"     }, //a/sh ct h 257
  {{ ACC_MAPTEXT,KFN_NOP      ,258 }, 11, "alt ct sh i"     }, //a/sh ct i 258
  {{ ACC_MAPTEXT,KFN_NOP      ,259 }, 11, "alt ct sh j"     }, //a/sh ct j 259
  {{ ACC_MAPTEXT,KFN_NOP      ,260 }, 11, "alt ct sh k"     }, //a/sh ct k 260
  {{ ACC_MAPTEXT,KFN_NOP      ,261 }, 11, "alt ct sh l"     }, //a/sh ct l 261
  {{ ACC_MAPTEXT,KFN_NOP      ,262 }, 11, "alt ct sh m"     }, //a/sh ct m 262

  {{ ACC_MAPTEXT,KFN_NOP      ,263 }, 11, "alt ct sh n"     }, //a/sh ct n 263
  {{ ACC_MAPTEXT,KFN_NOP      ,264 }, 11, "alt ct sh o"     }, //a/sh ct o 264
  {{ ACC_MAPTEXT,KFN_NOP      ,265 }, 11, "alt ct sh p"     }, //a/sh ct p 265
  {{ ACC_MAPTEXT,KFN_NOP      ,266 }, 11, "alt ct sh q"     }, //a/sh ct q 266
  {{ ACC_MAPTEXT,KFN_NOP      ,267 }, 11, "alt ct sh r"     }, //a/sh ct r 267
  {{ ACC_MAPTEXT,KFN_NOP      ,268 }, 11, "alt ct sh s"     }, //a/sh ct s 268
  {{ ACC_MAPTEXT,KFN_NOP      ,269 }, 11, "alt ct sh t"     }, //a/sh ct t 269
  {{ ACC_MAPTEXT,KFN_NOP      ,270 }, 11, "alt ct sh u"     }, //a/sh ct u 270
  {{ ACC_MAPTEXT,KFN_NOP      ,271 }, 11, "alt ct sh v"     }, //a/sh ct v 271
  {{ ACC_MAPTEXT,KFN_NOP      ,272 }, 11, "alt ct sh w"     }, //a/sh ct w 272
  {{ ACC_MAPTEXT,KFN_NOP      ,273 }, 11, "alt ct sh x"     }, //a/sh ct x 273
  {{ ACC_MAPTEXT,KFN_NOP      ,274 }, 11, "alt ct sh y"     }, //a/sh ct y 274
  {{ ACC_MAPTEXT,KFN_NOP      ,275 }, 11, "alt ct sh z"     }, //a/sh ct z 275

  {{ ACC_MAPTEXT,KFN_NOP      ,276 }, 11, "alt ct sh `"     }, //a/sh ct ` 276
  {{ ACC_MAPTEXT,KFN_NOP      ,277 }, 11, "alt ct sh -"     }, //a/sh ct - 277
  {{ ACC_MAPTEXT,KFN_NOP      ,278 }, 11, "alt ct sh ="     }, //a/sh ct = 278
  {{ ACC_MAPTEXT,KFN_NOP      ,279 }, 11, "alt ct sh ["     }, //a/sh ct [ 279
  {{ ACC_MAPTEXT,KFN_NOP      ,280 }, 11, "alt ct sh ]"     }, //a/sh ct ] 280
  {{ ACC_MAPTEXT,KFN_NOP      ,281 }, 11, "alt ct sh ;"     }, //a/sh ct ; 281
  {{ ACC_MAPTEXT,KFN_NOP      ,282 }, 11, "alt ct sh '"     }, //a/sh ct ' 282
  {{ ACC_MAPTEXT,KFN_NOP      ,283 }, 11, "alt ct sh ,"     }, //a/sh ct , 283
  {{ ACC_MAPTEXT,KFN_NOP      ,284 }, 11, "alt ct sh ."     }, //a/sh ct . 284
  {{ ACC_MAPTEXT,KFN_NOP      ,285 }, 11, "alt ct sh /"     }, //a/sh ct / 285
  {{ ACC_MAPTEXT,KFN_NOP      ,286 }, 11, "alt ct sh \\"    }, //a/sh ct \ 286

   }
};

#else

ACC_RES_STRUCT ars   =
{
// ars.heapsize
   0,             // not calculated yet!
// ars.Flag1
   0,
// ars.Flag2
   0,
// ars.mss[NUMACCSTRINGS]
   {

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ ACC_MAPECHO,KFN_NOP      ,  0 },  1, "\x01"            }, //ct a        0
  {{ ACC_MAPECHO,KFN_NOP      ,  1 },  1, "\x02"            }, //ct b        1
  {{ ACC_MAPECHO,KFN_NOP      ,  2 },  1, "\x03"            }, //ct c        2
  {{ ACC_MAPECHO,KFN_NOP      ,  3 },  1, "\x04"            }, //ct d        3
  {{ ACC_MAPECHO,KFN_NOP      ,  4 },  1, "\x05"            }, //ct e        4
  {{ ACC_MAPECHO,KFN_NOP      ,  5 },  1, "\x06"            }, //ct f        5
  {{ ACC_MAPECHO,KFN_NOP      ,  6 },  1, "\x07"            }, //ct g        6
  {{ ACC_MAPECHO,KFN_NOP      ,  7 },  1, "\x08"            }, //ct h        7
  {{ ACC_MAPECHO,KFN_NOP      ,  8 },  1, "\x09"            }, //ct i        8
  {{ ACC_MAPECHO,KFN_NOP      ,  9 },  1, "\x0A"            }, //ct j        9
  {{ ACC_MAPECHO,KFN_NOP      , 10 },  1, "\x0B"            }, //ct k       10
  {{ ACC_MAPECHO,KFN_NOP      , 11 },  1, "\x0C"            }, //ct l       11
  {{ ACC_MAPECHO,KFN_NOP      , 12 },  1, "\x0D"            }, //ct m       12

  {{ ACC_MAPECHO,KFN_NOP      , 13 },  1, "\x0E"            }, //ct n       13
  {{ ACC_MAPECHO,KFN_NOP      , 14 },  1, "\x0F"            }, //ct o       14
  {{ ACC_MAPECHO,KFN_NOP      , 15 },  1, "\x10"            }, //ct p       15
  {{ KBD_FNACCEL,KFN_PLAYREST , 16 },  0, ""                }, //ct q       16
  {{ ACC_MAPECHO,KFN_NOP      , 17 },  1, "\x12"            }, //ct r       17
  {{ KBD_FNACCEL,KFN_PLAYPAUS , 18 },  0, ""                }, //ct s       18
  {{ ACC_MAPECHO,KFN_NOP      , 19 },  1, "\x14"            }, //ct t       19
  {{ ACC_MAPECHO,KFN_NOP      , 20 },  1, "\x15"            }, //ct u       20
  {{ ACC_MAPECHO,KFN_NOP      , 21 },  1, "\x16"            }, //ct v       21
  {{ ACC_MAPECHO,KFN_NOP      , 22 },  1, "\x17"            }, //ct w       22
  {{ ACC_MAPECHO,KFN_NOP      , 23 },  1, "\x18"            }, //ct x       23
  {{ ACC_MAPECHO,KFN_NOP      , 24 },  1, "\x19"            }, //ct y       24
  {{ ACC_MAPECHO,KFN_NOP      , 25 },  1, "\x1A"            }, //ct z       25

  {{ KBD_NA_____,KFN_NOP      , 26 },  0, ""                }, //ct `       26
  {{ ACC_MAPECHO,KFN_NOP      , 27 },  1, "\x1F"            }, //ct -       27
  {{ KBD_NA_____,KFN_NOP      , 28 },  0, ""                }, //ct =       28
  {{ ACC_MAPECHO,KFN_NOP      , 29 },  1, "\x1B"            }, //ct [       29
  {{ ACC_MAPECHO,KFN_NOP      , 30 },  1, "\x1D"            }, //ct ]       30
  {{ KBD_NA_____,KFN_NOP      , 31 },  0, ""                }, //ct ;       31
  {{ KBD_NA_____,KFN_NOP      , 32 },  0, ""                }, //ct '       32
  {{ KBD_NA_____,KFN_NOP      , 33 },  0, ""                }, //ct ,       33
  {{ KBD_NA_____,KFN_NOP      , 34 },  0, ""                }, //ct .       34
  {{ KBD_NA_____,KFN_NOP      , 35 },  0, ""                }, //ct /       35
  {{ ACC_MAPECHO,KFN_NOP      , 36 },  1, "\x1C"            }, //ct \       36

  {{ KBD_NA_____,KFN_NOP      , 37 },  0, ""                }, //ct 1       37
  {{ ACC_MAPECHO,KFN_NOP      , 38 },  1, "\x00"            }, //ct 2       38
  {{ KBD_NA_____,KFN_NOP      , 39 },  0, ""                }, //ct 3       39
  {{ KBD_NA_____,KFN_NOP      , 40 },  0, ""                }, //ct 4       40
  {{ KBD_NA_____,KFN_NOP      , 41 },  0, ""                }, //ct 5       41
  {{ ACC_MAPECHO,KFN_NOP      , 42 },  1, "\x1E"            }, //ct 6       42
  {{ KBD_NA_____,KFN_NOP      , 43 },  0, ""                }, //ct 7       43
  {{ KBD_NA_____,KFN_NOP      , 44 },  0, ""                }, //ct 8       44
  {{ KBD_NA_____,KFN_NOP      , 45 },  0, ""                }, //ct 9       45
  {{ KBD_NA_____,KFN_NOP      , 46 },  0, ""                }, //ct 0       46

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_NA_____,KFN_NOP      , 47 },  0, ""                }, //ct sh a    47
  {{ KBD_NA_____,KFN_NOP      , 48 },  0, ""                }, //ct sh b    48
  {{ KBD_NA_____,KFN_NOP      , 49 },  0, ""                }, //ct sh c    49
  {{ KBD_NA_____,KFN_NOP      , 50 },  0, ""                }, //ct sh d    50
  {{ KBD_NA_____,KFN_NOP      , 51 },  0, ""                }, //ct sh e    51
  {{ KBD_NA_____,KFN_NOP      , 52 },  0, ""                }, //ct sh f    52
  {{ KBD_NA_____,KFN_NOP      , 53 },  0, ""                }, //ct sh g    53
  {{ KBD_NA_____,KFN_NOP      , 54 },  0, ""                }, //ct sh h    54
  {{ KBD_NA_____,KFN_NOP      , 55 },  0, ""                }, //ct sh i    55
  {{ KBD_NA_____,KFN_NOP      , 56 },  0, ""                }, //ct sh j    56
  {{ KBD_NA_____,KFN_NOP      , 57 },  0, ""                }, //ct sh k    57
  {{ KBD_NA_____,KFN_NOP      , 58 },  0, ""                }, //ct sh l    58
  {{ KBD_NA_____,KFN_NOP      , 59 },  0, ""                }, //ct sh m    59

  {{ KBD_NA_____,KFN_NOP      , 60 },  0, ""                }, //ct sh n    60
  {{ KBD_NA_____,KFN_NOP      , 61 },  0, ""                }, //ct sh o    61
  {{ KBD_NA_____,KFN_NOP      , 62 },  0, ""                }, //ct sh p    62
  {{ KBD_NA_____,KFN_NOP      , 63 },  0, ""                }, //ct sh q    63
  {{ KBD_NA_____,KFN_NOP      , 64 },  0, ""                }, //ct sh r    64
  {{ KBD_NA_____,KFN_NOP      , 65 },  0, ""                }, //ct sh s    65
  {{ KBD_NA_____,KFN_NOP      , 66 },  0, ""                }, //ct sh t    66
  {{ KBD_NA_____,KFN_NOP      , 67 },  0, ""                }, //ct sh u    67
  {{ KBD_NA_____,KFN_NOP      , 68 },  0, ""                }, //ct sh v    68
  {{ KBD_NA_____,KFN_NOP      , 69 },  0, ""                }, //ct sh w    69
  {{ KBD_NA_____,KFN_NOP      , 70 },  0, ""                }, //ct sh x    70
  {{ KBD_NA_____,KFN_NOP      , 71 },  0, ""                }, //ct sh y    71
  {{ KBD_NA_____,KFN_NOP      , 72 },  0, ""                }, //ct sh z    72

  {{ KBD_NA_____,KFN_NOP      , 73 },  0, ""                }, //ct sh `    73
  {{ ACC_MAPECHO,KFN_NOP      , 74 },  1, "\x1F"            }, //ct sh -    74
  {{ KBD_NA_____,KFN_NOP      , 75 },  0, ""                }, //ct sh =    75
  {{ KBD_NA_____,KFN_NOP      , 76 },  0, ""                }, //ct sh [    76
  {{ KBD_NA_____,KFN_NOP      , 77 },  0, ""                }, //ct sh ]    77
  {{ KBD_NA_____,KFN_NOP      , 78 },  0, ""                }, //ct sh ;    78
  {{ KBD_NA_____,KFN_NOP      , 79 },  0, ""                }, //ct sh '    79
  {{ KBD_NA_____,KFN_NOP      , 80 },  0, ""                }, //ct sh ,    80
  {{ KBD_NA_____,KFN_NOP      , 81 },  0, ""                }, //ct sh .    81
  {{ KBD_NA_____,KFN_NOP      , 82 },  0, ""                }, //ct sh /    82
  {{ KBD_NA_____,KFN_NOP      , 83 },  0, ""                }, //ct sh \    83

  {{ KBD_NA_____,KFN_NOP      , 84 },  0, ""                }, //ct sh 1    84
  {{ ACC_MAPECHO,KFN_NOP      , 85 },  1, "\x00"            }, //ct sh 2    85
  {{ KBD_NA_____,KFN_NOP      , 86 },  0, ""                }, //ct sh 3    86
  {{ KBD_NA_____,KFN_NOP      , 87 },  0, ""                }, //ct sh 4    87
  {{ KBD_NA_____,KFN_NOP      , 88 },  0, ""                }, //ct sh 5    88
  {{ ACC_MAPECHO,KFN_NOP      , 89 },  1, "\x1E"            }, //ct sh 6    89
  {{ KBD_NA_____,KFN_NOP      , 90 },  0, ""                }, //ct sh 7    90
  {{ KBD_NA_____,KFN_NOP      , 91 },  0, ""                }, //ct sh 8    91
  {{ KBD_NA_____,KFN_NOP      , 92 },  0, ""                }, //ct sh 9    92
  {{ KBD_NA_____,KFN_NOP      , 93 },  0, ""                }, //ct sh 0    93

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_NA_____,KFN_NOP      , 94 },  0, ""                }, //alt a      94
  {{ KBD_FNACCEL,KFN_SENDBRK  , 95 },  0, ""                }, //alt b      95
  {{ KBD_FNACCEL,KFN_TRMCLEAR , 96 },  0, ""                }, //alt c      96
  {{ KBD_FNACCEL,KFN_SHOWDDIR , 97 },  0, ""                }, //alt d      97
  {{ KBD_NA_____,KFN_NOP      , 98 },  0, ""                }, //alt e      98
  {{ KBD_NA_____,KFN_NOP      , 99 },  0, ""                }, //alt f      99
  {{ KBD_FNACCEL,KFN_SCR2FILE ,100 },  0, ""                }, //alt g     100
  {{ KBD_NA_____,KFN_NOP      ,101 },  0, ""                }, //alt h     101
  {{ KBD_NA_____,KFN_NOP      ,102 },  0, ""                }, //alt i     102
  {{ KBD_FNACCEL,KFN_INITMODM ,103 },  0, ""                }, //alt j     103
  {{ KBD_FNACCEL,KFN_SCR2BUF  ,104 },  0, ""                }, //alt k     104
  {{ KBD_FNACCEL,KFN_SCR2PRN  ,105 },  0, ""                }, //alt l     105
  {{ KBD_FNACCEL,KFN_METAMAP  ,106 },  0, ""                }, //alt m     106

  {{ KBD_FNACCEL,KFN_PRINT    ,107 },  0, ""                }, //alt n     107
  {{ KBD_NA_____,KFN_NOP      ,108 },  0, ""                }, //alt o     108
  {{ KBD_FNACCEL,KFN_RAPIDSCR ,109 },  0, ""                }, //alt p     109
  {{ KBD_FNACCEL,KFN_AUTO5    ,110 },  0, ""                }, //alt q     110
  {{ KBD_FNACCEL,KFN_RAPIDDI  ,111 },  0, ""                }, //alt r     111
  {{ KBD_NA_____,KFN_NOP      ,112 },  0, ""                }, //alt s     112
  {{ KBD_NA_____,KFN_NOP      ,113 },  0, ""                }, //alt t     113
  {{ KBD_FNACCEL,KFN_TRMRESET ,114 },  0, ""                }, //alt u     114
  {{ KBD_FNACCEL,KFN_SCR2CLIP ,115 },  0, ""                }, //alt v     115
  {{ KBD_NA_____,KFN_NOP      ,116 },  0, ""                }, //alt w     116
  {{ KBD_FNACCEL,KFN_EXIT     ,117 },  0, ""                }, //alt x     117
  {{ KBD_FNACCEL,KFN_AUTO1    ,118 },  0, ""                }, //alt y     118
  {{ KBD_FNACCEL,KFN_HLPCONT  ,119 },  0, ""                }, //alt z     119

  {{ KBD_NA_____,KFN_NOP      ,120 },  0, ""                }, //alt `     120
  {{ KBD_FNACCEL,KFN_CYCLEBAR ,121 },  0, ""                }, //alt -     121
  {{ KBD_FNACCEL,KFN_FILECLIP ,122 },  0, ""                }, //alt =     122
  {{ KBD_NA_____,KFN_NOP      ,123 },  0, ""                }, //alt [     123
  {{ KBD_FNACCEL,KFN_RECORD   ,124 },  0, ""                }, //alt ]     124
  {{ KBD_NA_____,KFN_NOP      ,125 },  0, ""                }, //alt ;     125
  {{ KBD_NA_____,KFN_NOP      ,126 },  0, ""                }, //alt '     126
  {{ KBD_NA_____,KFN_NOP      ,127 },  0, ""                }, //alt ,     127
  {{ KBD_FNACCEL,KFN_SCRIPT   ,128 },  0, ""                }, //alt .     128
  {{ KBD_FNACCEL,KFN_DEBUGBOX ,129 },  0, ""                }, //alt /     129
  {{ KBD_FNACCEL,KFN_MONITOR  ,130 },  0, ""                }, //alt \     130

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      ,131 },  0, ""                }, //a/bksp    131
  {{ KBD_NA_____,KFN_NOP      ,132 },  0, ""                }, //a/tab     132
  {{ KBD_NA_____,KFN_NOP      ,133 },  0, ""                }, //a/clear   133
  {{ KBD_MAPECHO,KFN_NOP      ,134 },  0, ""                }, //a/enter   134
  {{ KBD_MAPECHO,KFN_NOP      ,135 },  0, ""                }, //a/pd ent  135
  {{ KBD_MAPTEXT,KFN_NOP      ,136 },  0, ""                }, //a/pause   136

  {{ KBD_NA_____,KFN_NOP      ,137 },  0, ""                }, //a/pd pgup 137
  {{ KBD_NA_____,KFN_NOP      ,138 },  0, ""                }, //a/pd pgdn 138
  {{ KBD_NA_____,KFN_NOP      ,139 },  0, ""                }, //a/pd end  139
  {{ KBD_NA_____,KFN_NOP      ,140 },  0, ""                }, //a/pd home 140
  {{ KBD_NA_____,KFN_NOP      ,141 },  0, ""                }, //a/pd lf   141
  {{ KBD_NA_____,KFN_NOP      ,142 },  0, ""                }, //a/pd up   142
  {{ KBD_NA_____,KFN_NOP      ,143 },  0, ""                }, //a/pd rt   143
  {{ KBD_NA_____,KFN_NOP      ,144 },  0, ""                }, //a/pd dn   144

  {{ KBD_INTFUNC,KFN_SCL_UPGE ,145 },  0, ""                }, //a/gr pgup 145
  {{ KBD_INTFUNC,KFN_SCL_DPGE ,146 },  0, ""                }, //a/gr pgdn 146
  {{ KBD_INTFUNC,KFN_SCL_DBOT ,147 },  0, ""                }, //a/gr end  147
  {{ KBD_INTFUNC,KFN_SCL_UTOP ,148 },  0, ""                }, //a/gr home 148
  {{ KBD_INTFUNC,KFN_SCL_L1   ,149 },  0, ""                }, //a/gr lf   149
  {{ KBD_INTFUNC,KFN_SCL_U1   ,150 },  0, ""                }, //a/gr up   150
  {{ KBD_INTFUNC,KFN_SCL_R1   ,151 },  0, ""                }, //a/gr rt   151
  {{ KBD_INTFUNC,KFN_SCL_D1   ,152 },  0, ""                }, //a/gr dn   152

  {{ KBD_NA_____,KFN_NOP      ,153 },  0, ""                }, //a/pd ins  153
  {{ KBD_NA_____,KFN_NOP      ,154 },  0, ""                }, //a/pd del  154
  {{ KBD_MAPECHO,KFN_NOP      ,155 },  0, ""                }, //a/gr ins  155
  {{ KBD_MAPECHO,KFN_NOP      ,156 },  0, ""                }, //a/gr del  156

  {{ KBD_NA_____,KFN_NOP      ,157 },  0, ""                }, //a/numlk   157
  {{ KBD_MAPTEXT,KFN_NOP      ,158 },  0, ""                }, //a/scrlk   158

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_MAPECHO,KFN_NOP      ,159 },  0, ""                }, //a/pd *    159
  {{ KBD_MAPECHO,KFN_NOP      ,160 },  0, ""                }, //a/pd +    160
  {{ KBD_MAPECHO,KFN_NOP      ,161 },  0, ""                }, //a/pd -    161
  {{ KBD_MAPECHO,KFN_NOP      ,162 },  0, ""                }, //a/pd .    162
  {{ KBD_MAPECHO,KFN_NOP      ,146 },  0, ""                }, //a/pd /    146
  {{ KBD_FNACCEL,KFN_LOG      ,164 },  0, ""                }, //a/F1      164
  {{ KBD_FNACCEL,KFN_ONLINE   ,165 },  0, ""                }, //a/F2      165
  {{ KBD_FNACCEL,KFN_EDITASP  ,166 },  0, ""                }, //a/F3      166
  {{ KBD_NA_____,KFN_NOP      ,167 },  0, ""                }, //a/F4      167
  {{ KBD_FNACCEL,KFN_RUNASP   ,168 },  0, ""                }, //a/F5      168
  {{ KBD_FNACCEL,KFN_NEXTWIN  ,169 },  0, ""                }, //a/F6      169
  {{ KBD_FNACCEL,KFN_KRMGET   ,170 },  0, ""                }, //a/F7      170
  {{ KBD_FNACCEL,KFN_KBDMAP   ,171 },  0, ""                }, //a/F8      171
  {{ KBD_FNACCEL,KFN_BUF2CLIP ,172 },  0, ""                }, //a/F9      172
  {{ KBD_FNACCEL,KFN_ABOUT    ,173 },  0, ""                }, //a/F10     173
  {{ KBD_FNACCEL,KFN_BUF2FILE ,174 },  0, ""                }, //a/F11     174
  {{ KBD_NA_____,KFN_NOP      ,175 },  0, ""                }, //a/F12     175

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_NA_____,KFN_NOP      ,176 },  0, ""                }, //alt sh a  176
  {{ KBD_NA_____,KFN_NOP      ,177 },  0, ""                }, //alt sh b  177
  {{ KBD_NA_____,KFN_NOP      ,178 },  0, ""                }, //alt sh c  178
  {{ KBD_NA_____,KFN_NOP      ,179 },  0, ""                }, //alt sh d  179
  {{ KBD_NA_____,KFN_NOP      ,180 },  0, ""                }, //alt sh e  180
  {{ KBD_NA_____,KFN_NOP      ,181 },  0, ""                }, //alt sh f  181
  {{ KBD_NA_____,KFN_NOP      ,182 },  0, ""                }, //alt sh g  182
  {{ KBD_NA_____,KFN_NOP      ,183 },  0, ""                }, //alt sh h  183
  {{ KBD_NA_____,KFN_NOP      ,184 },  0, ""                }, //alt sh i  184
  {{ KBD_NA_____,KFN_NOP      ,185 },  0, ""                }, //alt sh j  185
  {{ KBD_NA_____,KFN_NOP      ,186 },  0, ""                }, //alt sh k  186
  {{ KBD_NA_____,KFN_NOP      ,187 },  0, ""                }, //alt sh l  187
  {{ KBD_NA_____,KFN_NOP      ,188 },  0, ""                }, //alt sh m  188

  {{ KBD_NA_____,KFN_NOP      ,189 },  0, ""                }, //alt sh n  189
  {{ KBD_NA_____,KFN_NOP      ,190 },  0, ""                }, //alt sh o  190
  {{ KBD_NA_____,KFN_NOP      ,191 },  0, ""                }, //alt sh p  191
  {{ KBD_NA_____,KFN_NOP      ,192 },  0, ""                }, //alt sh q  192
  {{ KBD_NA_____,KFN_NOP      ,193 },  0, ""                }, //alt sh r  193
  {{ KBD_NA_____,KFN_NOP      ,194 },  0, ""                }, //alt sh s  194
  {{ KBD_NA_____,KFN_NOP      ,195 },  0, ""                }, //alt sh t  195
  {{ KBD_NA_____,KFN_NOP      ,196 },  0, ""                }, //alt sh u  196
  {{ KBD_NA_____,KFN_NOP      ,197 },  0, ""                }, //alt sh v  197
  {{ KBD_NA_____,KFN_NOP      ,198 },  0, ""                }, //alt sh w  198
  {{ KBD_NA_____,KFN_NOP      ,199 },  0, ""                }, //alt sh x  199
  {{ KBD_NA_____,KFN_NOP      ,200 },  0, ""                }, //alt sh y  200
  {{ KBD_NA_____,KFN_NOP      ,201 },  0, ""                }, //alt sh z  201

  {{ KBD_NA_____,KFN_NOP      ,202 },  0, ""                }, //alt sh `  202
  {{ KBD_NA_____,KFN_NOP      ,203 },  0, ""                }, //alt sh -  203
  {{ KBD_NA_____,KFN_NOP      ,204 },  0, ""                }, //alt sh =  204
  {{ KBD_NA_____,KFN_NOP      ,205 },  0, ""                }, //alt sh [  205
  {{ KBD_NA_____,KFN_NOP      ,206 },  0, ""                }, //alt sh ]  206
  {{ KBD_NA_____,KFN_NOP      ,207 },  0, ""                }, //alt sh ;  207
  {{ KBD_NA_____,KFN_NOP      ,208 },  0, ""                }, //alt sh '  208
  {{ KBD_NA_____,KFN_NOP      ,209 },  0, ""                }, //alt sh ,  209
  {{ KBD_NA_____,KFN_NOP      ,210 },  0, ""                }, //alt sh .  210
  {{ KBD_NA_____,KFN_NOP      ,211 },  0, ""                }, //alt sh /  211
  {{ KBD_NA_____,KFN_NOP      ,212 },  0, ""                }, //alt sh \  212

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_NA_____,KFN_NOP      ,213 },  0, ""                }, //alt ct a  213
  {{ KBD_NA_____,KFN_NOP      ,214 },  0, ""                }, //alt ct b  214
  {{ KBD_NA_____,KFN_NOP      ,215 },  0, ""                }, //alt ct c  215
  {{ KBD_NA_____,KFN_NOP      ,216 },  0, ""                }, //alt ct d  216
  {{ KBD_NA_____,KFN_NOP      ,217 },  0, ""                }, //alt ct e  217
  {{ KBD_NA_____,KFN_NOP      ,218 },  0, ""                }, //alt ct f  218
  {{ KBD_NA_____,KFN_NOP      ,219 },  0, ""                }, //alt ct g  219
  {{ KBD_NA_____,KFN_NOP      ,220 },  0, ""                }, //alt ct h  220
  {{ KBD_NA_____,KFN_NOP      ,221 },  0, ""                }, //alt ct i  221
  {{ KBD_NA_____,KFN_NOP      ,222 },  0, ""                }, //alt ct j  222
  {{ KBD_NA_____,KFN_NOP      ,223 },  0, ""                }, //alt ct k  223
  {{ KBD_NA_____,KFN_NOP      ,224 },  0, ""                }, //alt ct l  224
  {{ KBD_NA_____,KFN_NOP      ,225 },  0, ""                }, //alt ct m  225

  {{ KBD_NA_____,KFN_NOP      ,226 },  0, ""                }, //alt ct n  226
  {{ KBD_NA_____,KFN_NOP      ,227 },  0, ""                }, //alt ct o  227
  {{ KBD_NA_____,KFN_NOP      ,228 },  0, ""                }, //alt ct p  228
  {{ KBD_NA_____,KFN_NOP      ,229 },  0, ""                }, //alt ct q  229
  {{ KBD_NA_____,KFN_NOP      ,230 },  0, ""                }, //alt ct r  230
  {{ KBD_NA_____,KFN_NOP      ,231 },  0, ""                }, //alt ct s  231
  {{ KBD_NA_____,KFN_NOP      ,232 },  0, ""                }, //alt ct t  232
  {{ KBD_NA_____,KFN_NOP      ,233 },  0, ""                }, //alt ct u  233
  {{ KBD_NA_____,KFN_NOP      ,234 },  0, ""                }, //alt ct v  234
  {{ KBD_NA_____,KFN_NOP      ,235 },  0, ""                }, //alt ct w  235
  {{ KBD_NA_____,KFN_NOP      ,236 },  0, ""                }, //alt ct x  236
  {{ KBD_NA_____,KFN_NOP      ,237 },  0, ""                }, //alt ct y  237
  {{ KBD_NA_____,KFN_NOP      ,238 },  0, ""                }, //alt ct z  238

  {{ KBD_NA_____,KFN_NOP      ,239 },  0, ""                }, //alt ct `  239
  {{ KBD_NA_____,KFN_NOP      ,240 },  0, ""                }, //alt ct -  240
  {{ KBD_NA_____,KFN_NOP      ,241 },  0, ""                }, //alt ct =  241
  {{ KBD_NA_____,KFN_NOP      ,242 },  0, ""                }, //alt ct [  242
  {{ KBD_NA_____,KFN_NOP      ,243 },  0, ""                }, //alt ct ]  243
  {{ KBD_NA_____,KFN_NOP      ,244 },  0, ""                }, //alt ct ;  244
  {{ KBD_NA_____,KFN_NOP      ,245 },  0, ""                }, //alt ct '  245
  {{ KBD_NA_____,KFN_NOP      ,246 },  0, ""                }, //alt ct ,  246
  {{ KBD_NA_____,KFN_NOP      ,247 },  0, ""                }, //alt ct .  247
  {{ KBD_NA_____,KFN_NOP      ,248 },  0, ""                }, //alt ct /  248
  {{ KBD_NA_____,KFN_NOP      ,249 },  0, ""                }, //alt ct \  249

//                            str   str   str                  key       array
//   vkeytype    funcndx      ndx   size  contents             title     index
//   ----------- ------------ ----- ----  ---------            -----     -----
  {{ KBD_NA_____,KFN_NOP      ,250 },  0, ""                }, //a/sh ct a 250
  {{ KBD_NA_____,KFN_NOP      ,251 },  0, ""                }, //a/sh ct b 251
  {{ KBD_NA_____,KFN_NOP      ,252 },  0, ""                }, //a/sh ct c 252
  {{ KBD_NA_____,KFN_NOP      ,253 },  0, ""                }, //a/sh ct d 253
  {{ KBD_NA_____,KFN_NOP      ,254 },  0, ""                }, //a/sh ct e 254
  {{ KBD_NA_____,KFN_NOP      ,255 },  0, ""                }, //a/sh ct f 255
  {{ KBD_NA_____,KFN_NOP      ,256 },  0, ""                }, //a/sh ct g 256
  {{ KBD_NA_____,KFN_NOP      ,257 },  0, ""                }, //a/sh ct h 257
  {{ KBD_NA_____,KFN_NOP      ,258 },  0, ""                }, //a/sh ct i 258
  {{ KBD_NA_____,KFN_NOP      ,259 },  0, ""                }, //a/sh ct j 259
  {{ KBD_NA_____,KFN_NOP      ,260 },  0, ""                }, //a/sh ct k 260
  {{ KBD_NA_____,KFN_NOP      ,261 },  0, ""                }, //a/sh ct l 261
  {{ KBD_NA_____,KFN_NOP      ,262 },  0, ""                }, //a/sh ct m 262

  {{ KBD_NA_____,KFN_NOP      ,263 },  0, ""                }, //a/sh ct n 263
  {{ KBD_NA_____,KFN_NOP      ,264 },  0, ""                }, //a/sh ct o 264
  {{ KBD_NA_____,KFN_NOP      ,265 },  0, ""                }, //a/sh ct p 265
  {{ KBD_NA_____,KFN_NOP      ,266 },  0, ""                }, //a/sh ct q 266
  {{ KBD_NA_____,KFN_NOP      ,267 },  0, ""                }, //a/sh ct r 267
  {{ KBD_NA_____,KFN_NOP      ,268 },  0, ""                }, //a/sh ct s 268
  {{ KBD_NA_____,KFN_NOP      ,269 },  0, ""                }, //a/sh ct t 269
  {{ KBD_NA_____,KFN_NOP      ,270 },  0, ""                }, //a/sh ct u 270
  {{ KBD_NA_____,KFN_NOP      ,271 },  0, ""                }, //a/sh ct v 271
  {{ KBD_NA_____,KFN_NOP      ,272 },  0, ""                }, //a/sh ct w 272
  {{ KBD_NA_____,KFN_NOP      ,273 },  0, ""                }, //a/sh ct x 273
  {{ KBD_NA_____,KFN_NOP      ,274 },  0, ""                }, //a/sh ct y 274
  {{ KBD_NA_____,KFN_NOP      ,275 },  0, ""                }, //a/sh ct z 275

  {{ KBD_NA_____,KFN_NOP      ,276 },  0, ""                }, //a/sh ct ` 276
  {{ KBD_NA_____,KFN_NOP      ,277 },  0, ""                }, //a/sh ct - 277
  {{ KBD_NA_____,KFN_NOP      ,278 },  0, ""                }, //a/sh ct = 278
  {{ KBD_NA_____,KFN_NOP      ,279 },  0, ""                }, //a/sh ct [ 279
  {{ KBD_NA_____,KFN_NOP      ,280 },  0, ""                }, //a/sh ct ] 280
  {{ KBD_NA_____,KFN_NOP      ,281 },  0, ""                }, //a/sh ct ; 281
  {{ KBD_NA_____,KFN_NOP      ,282 },  0, ""                }, //a/sh ct ' 282
  {{ KBD_NA_____,KFN_NOP      ,283 },  0, ""                }, //a/sh ct , 283
  {{ KBD_NA_____,KFN_NOP      ,284 },  0, ""                }, //a/sh ct . 284
  {{ KBD_NA_____,KFN_NOP      ,285 },  0, ""                }, //a/sh ct / 285
  {{ KBD_NA_____,KFN_NOP      ,286 },  0, ""                }, //a/sh ct \ 286

   }
};

#endif

KBD_FILEHDR_STRUCT kfs =
{
   // kfs.szFileNotes
   {";default accelerator table"},
   // kfs.Version
   {"PW200940504A"},
   // kfs.flags
   0
};


int main(int argc, char * argv[])
{
   int      size;
   FILE     *fptr;
   int      j,k;
   char FAR *a;
   char filespec[256];
   char *filename;

   // create files in same path used to launch app
   _fstrcpy(filespec,argv[0]);
   filename = filespec + strlen(filespec);
   while((filename != filespec) && (*(filename - 1) != '\\') &&
      (*(filename - 1) != ':'))
      --filename;

/*
 
                                                                          
  create accel key resource                                               
                                                                          
 

*/

   _fstrcpy(filename,"vtxdlt.acc");
   if(!(fptr = fopen(filespec,"wb")))
      return (-1);

   // write header
   size = sizeof(KBD_FILEHDR_STRUCT);
   a = (char FAR *)&kfs.szFileNotes;
   for (k=0;k<size;k++)
   {
      putc(*a,fptr);
      a++;
   }

   // now write accel struct; calc heapsize first
   ars.heapsize = 0;
   for (j=0;j<NUMACCSTRINGS;j++)
      ars.heapsize += ars.mss[j].strsize+1;
   size = sizeof(unsigned int);

   // we are now writing info out in a format compatible with
   // ACC_VKEY_FILE_STRUCT, which it will be read into during a file load.
   a = (char FAR *)&ars.heapsize;
   for (k=0;k<size;k++)
   {
      putc(*a,fptr);
      a++;
   }
   a = (char FAR *)&ars.Flag1;
   for (k=0;k<size;k++)
   {
      putc(*a,fptr);
      a++;
   }
   a = (char FAR *)&ars.Flag2;
   for (k=0;k<size;k++)
   {
      putc(*a,fptr);
      a++;
   }

   for (j=0;j<NUMACCSTRINGS;j++)
   {
      a = (char FAR *)&ars.mss[j].vks.vkeytype;
      for (k=0;k<sizeof(VIRT_KEY_CODE_STRUCT);k++) // copy virt key structs
      {
         putc(*a,fptr);
         a++;
      }
   }
   for (j=0;j<NUMACCSTRINGS;j++)
   {
      a = (char FAR *)&ars.mss[j].strsize;
      size = *a;
      putc(*a++,fptr);     // put size char no matter what
      for (k=0;k<size;k++) // copy str chars
         putc(*a++,fptr);
   }
   fclose(fptr);

   _fstrcpy(filename,"pwmkacc.bin");
   if(fptr = fopen(filespec, "wb"))
      fclose(fptr) ;

   return 0;
}

