/*
 
                                                                          
                     Copyright (C) 1999 Symantec Corp.                    
                            All Rights Reserved                           
                                                                          
       Information in this file is proprietary and confidential, and      
         may not be copied, reproduced or distributed in any manner       
      without the express written permission of Symantec Corp.            
                                                                          
 
*/

#ifndef _INC_XDLT
   #define _INC_XDLT

#ifndef  _INC_VXPRINT
   #include "vxprtdlx.h"               // for def of HVXP.
#endif

/*

  Interface structure.                                                

*/

typedef struct tagPW_DLT
{
   /*
   
     Set by PW and not modified by DLT.                                                             
   
   */
#ifndef MIPS
   #pragma  pack(2)
#endif
   int         wSize;                  // Sizeof(this struct)

   HINSTANCE   hInst;                  // Handle to PW Instance
   HWND        hWndMain;               // Handle to top level PW window
   HWND        hWndTerminal;           // Handle to the Terminal window
   HDC         hDCTerminal;            // Permanent hDC of the Terminal window

#ifndef MIPS
   #pragma  pack(4)
#endif
   COMM_HANDLE FAR*  lphCid;           // Pointer to handle to comm port.
                                       //    Changes during run-time.
   int   FAR*  lpState;                // Pointer to the internal STATE of PW.  Defined by
                                       //    the IDX_* #defined in pw.h
   HDC   FAR*  lphPrinterDC;           // Pointer to handle to printer device context.
   BYTE  FAR*  lpaspdisplay;           // Pointer to aspdisplay, TRUE if DLT can decode
                                       //    sequences and display on the screen.
                                       //    If FALSE, do not decode.
   FILE_HANDLE FAR*  lphRecordFile;    // Pointer to handle to record file, used to determine
                                       //    if P_RecordModeChar and P_RecordModeChange calls should be made.
   BYTE  FAR*  lpPauseChar;            // Pointer to the character, which, if embedded in
                                       //    a string, will cause a 1/2 second before the
                                       //    sending of the next character.  It is read/only.
   LPPW_CALLBACK_STRUCT lpcbs;         // Pointer to the callback struct defined in
                                       //    callback.h
   BYTE  FAR*  lpExtraBytes;           // Pointer to the ExtraBytes area of the current
                                       //    terminal structure.  This area will contain the
                                       //    advanced setup information that the .DLT has
                                       //    stored there during DLT_DoAdvancedSetupDialog().
   UINT        lenExtra;               // Length of the ExtraBytes field.
   UINT        uExtraUsed;             // Number of bytes in ExtraBytes area actually used
                                       //    by the .DLT
   BYTE  FAR*  lpScrollBackMode;       // Pointer to a flag, TRUE if the emulation is in
                                       //    scrollback mode, false otherwise.
   BYTE  FAR*  lpTerminalHasCaret;     // Pointer to a flag, TRUE if the terminal window
                                       //    logically has the caret and should handle it.
   HWND  FAR*  lphWndVertSB;           // Pointer to the vertical scrollbar window handle
   HWND  FAR*  lphWndHorzSB;           // Pointer to the horizontal scrollbar window handle
   LPNTTS      lpntts;                 // Pointer to the TERMINALSET structure that defines
                                       //    this emulation (defined in PW.H).

   /*
   
     Set by DLT and not modified by PW.                                                             
   
   */
#ifndef MIPS
   #pragma  pack(4)
#endif
   int         iDLLMagicIndex;         // A number for defining which instance of PW is calling the DLT.
                                       //    It is initialized to -1.
   int         iDLLAnything;           // Used by the DLL for anything
#ifndef MIPS
   #pragma  pack()
#endif

   /*
   
     Additional stuff for PW 2.1 
   
   */

   //
   // The incoming translate table is a 256 byte array used to convert raw
   //    data as the user desires.  A typical translation scheme might be
   //    to translate all ^G (bell) characters to null (which hopefully
   //    does nothing).  Another translation scheme might be to convert a
   //    '/' on the line to a '' incoming, and '' outgoing to a '/' on
   //    the line.
   // It is important that the incoming translation only be done on
   //    characters which are NOT in escape sequences.
   // It is important that keystrokes that are going out have any ANSI to
   //    OEM conversion done BEFORE they are translated, so that the
   //    translation is always occuring on data which is in the OEM format.
   // To use a translation table, index it.  For example, if the incoming
   //    character is in BYTE ch, then the translated value is in
   //    lpXlateIn[ch].
   //

   BYTE  FAR*  lpXlatIn;               // Used for translating incoming characters
   BYTE  FAR*  lpXlatOut;              // Used for translating outgoing characters

} PW_DLT;
typedef PW_DLT FAR* LPPW_DLT;

/*

  DLL Entry point definition.                                         

*/
#ifdef   __cplusplus
extern "C" {
#endif

EXPORTED int   FAR   PASCAL   DLT_Interface
(
   int      FunctionCode,              // Function switch
   LPVOID   lpvoid,                    // General pointer to whatever needed
   LPPW_DLT lppw_dlt                   // Pointer to PW_DLT structure
);

typedef int (FAR PASCAL *DLT_IPROC)( int, LPVOID, LPPW_DLT);

#ifdef   __cplusplus
}
#endif

/*

  Structure for Emulation Capabilities.                               

*/

typedef struct tagTERMINAL_MENU_GRAYING_FLAGS   // Flags which define menu items to be grayed
{                                               //    for this particular emulation
   UINT  fACTION_PRINT        :  1; // Printer logging icon
   UINT  fPLAYBACK            :  1; // File Replay
   UINT  fACTION_LOG          :  1; // Capture File
   UINT  fCOPY                :  1; // Copy selection to clipboard (NO LONGER USED, HERE ONLY TO PREVENT STRUCTURE CHANGES)
   UINT  fPASTE               :  1; // Paste from clipboard to comm port
   UINT  fSCREEN_TO_CLIP      :  1; // Copy screen to clipboard
   UINT  fSCREEN_TO_LOG       :  1; // Copy screen to capture file
   UINT  fSCREEN_TO_FILE      :  1; // Copy screen to general file
   UINT  fSCREEN_TO_PRINTER   :  1; // Copy screen to printer
   UINT  fSCREEN_TO_BUFF      :  1; // Copy screen to scrollback
   UINT  fSCREEN_TO_MAIL      :  1; // Copy screen to mail
   UINT  fBUFF_TO_CLIP        :  1; // Copy buffer to clipboard
   UINT  fBUFF_TO_LOG         :  1; // Copy buffer to capture file
   UINT  fBUFF_TO_FILE        :  1; // Copy buffer to general file
   UINT  fBUFF_TO_PRINTER     :  1; // Copy buffer to printer
   UINT  fBUFF_TO_MAIL        :  1; // Copy buffer to mail
   UINT  fFILECLIP            :  1; // Go into file clipboard
   UINT  fACTION_PAUSE        :  1; // Go into scrollback mode
   UINT  fTERM_CLEAR          :  1; // Clear the terminal screen
   UINT  fTERM_RESET          :  1; // Soft reset the emulation
   UINT  fACTION_CHAT         :  1; // Bring up the chat window
   UINT  fMONITOR             :  1; // Bring up the monitor window
   UINT  fFIND                :  1; // Find text in the current screen and scrollback buffer
   UINT  fSCREEN_TO_FAX       :  1; // Copy screen to fax (Added in PW3.0)
   UINT  fBUFF_TO_FAX         :  1; // Copy buffer to fax (Added in PW3.0)
}  TERMINAL_MENU_GRAYING_FLAGS;

/*

  #defines for the interface.  

*/

//
// #defines for the NEED_FLAGS bit array.
//
typedef  WORD              NEED_FLAGS;

#define  NF_NONE           0x00        // DLT has no needs from PW
#define  NF_CONSTANT_TIMER 0x01        // DLT needs constant polling, even in file transfers &c.
#define  NF_ADVANCED_SETUP 0x02        // DLT needs an advanced setup dialog

//
// Function codes are defined:
//
#define  DLT_RequestNumOfEmuls         0
#define  DLT_RequestEmulationName      1
#define  DLT_RequestEmulationNeeds     2
#define  DLT_RequestEmulationCaps      3
#define  DLT_Startup                   4
#define  DLT_Timer                     5
#define  DLT_Reset                     6
#define  DLT_ShutDown                  7
#define  DLT_KeyChar                   8
#define  DLT_SnapShot_Printer          9
#define  DLT_SnapShot_File             10
#define  DLT_SnapShot_Clipboard        11
#define  DLT_ReadFromDisplay           12
#define  DLT_StartCapture              13
#define  DLT_EndCapture                14
#define  DLT_StartReplay               15
#define  DLT_EndReplay                 16
#define  DLT_PauseReplay               17
#define  DLT_ContinueReplay            18
#define  DLT_TerminalWriteBuffer       19
#define  DLT_DoAdvancedSetupDialog     20
#define  DLT_Terminal                  21
#define  DLT_ComputeScrollRange        22
#define  DLT_SetupFinalSize            23
#define  DLT_SetupCaret                24
#define  DLT_RemoveCaret               25
#define  DLT_QueryEscape               26
#define  DLT_PerformEscape             27
#define  DLT_QueryString               28
#define  DLT_TerminalChanged           29
#define  DLT_MenuNotification          30
#define  DLT_SpecialKeys               31
#define  DLT_QueryRowColInfo           32
#define  DLT_TerminalPollExt           33
#define  DLT_SnapShot_Mail             34
#define  DLT_SnapShot_Capture          35
#define  DLT_SnapShot_Fax              36

#define  NUMBER_OF_DLT_INTERFACE_CODES 37

#define  DLT_FUNCTION_NOT_IMPLEMENTED  -1

/*

  Structures pointed to by the lpvoid in the DLT_Interface call are   
     defined here by name.                                            

*/

typedef struct tagRequestNumOfEmulsStruct // 0
{
   int   wSize;                        // Sizeof(this struct)
   int   nEmulations;
}  RequestNumOfEmulsStruct;
typedef RequestNumOfEmulsStruct  FAR*  lpRequestNumOfEmulsStruct;


typedef struct tagRequestEmulationNameStruct // 1
{
   int   wSize;                        // Sizeof(this struct)
   int   nEmulation;                   // Number of emulation (0-based)
   int   nMaxLen;                      // Length of buffer provided
   LPSTR lpszEmulationName;            // Pointer to buffer provided
}  RequestEmulationNameStruct;
typedef RequestEmulationNameStruct  FAR*  lpRequestEmulationNameStruct;


typedef struct tagRequestEmulationNeedsStruct   // 2
{
   int         wSize;                  // Sizeof(this struct)
   int         nEmulation;             // Number of emulation (0-based)
   NEED_FLAGS  nf;                     // Need flags returned from DLT
   POINT       rgptResAvail[3];        // [Optional] Array of x,y resolution
}  RequestEmulationNeedsStruct;
typedef RequestEmulationNeedsStruct FAR*  lpRequestEmulationNeedsStruct;


typedef struct tagRequestEmulationCapsStruct // 3
{
   int   wSize;                        // Sizeof(this struct)
   int   nEmulation;                   // Number of emulation (0-based)
   TERMINAL_MENU_GRAYING_FLAGS tmgf;   // Menu flags returned from DLT
}  RequestEmulationCapsStruct;
typedef RequestEmulationCapsStruct  FAR*  lpRequestEmulationCapsStruct;


typedef struct tagStartupStruct        // 4
{
   int   wSize;                        // Sizeof(this struct)
   int   nEmulationRequested;          // Emulation number of this .DLT requested
   int   iPointSizeRequested;          // Number of points that the user would like to see
   int   nMaxFileNameLen;              // Maximum number of characters that
                                       //    can go into the
                                       //    szKeyboardAcceleratorFileName.
                                       // Name of keyboard accelerator file,
                                       //    if needed, NULL if not
   unsigned char szKeyboardAcceleratorFileName[ MAXFILENAME ];
}  StartupStruct;
typedef StartupStruct   FAR*  lpStartupStruct;


//#define   DLT_Timer                     5
//#define   DLT_Reset                     6
//#define   DLT_ShutDown                  7
//#define   DLT_KeyChar                   8


typedef struct tagSnapShot_PrinterStruct// 9
{
   int      wSize;                     // Sizeof(this struct)
   LPRECT   lprPage;                   // Pointer to rectangle in pixels specifying the page boundaries of the printable page
   LPINT    lpxCurrent;                // Pointer to current horizontal pixel position on device
   LPINT    lpyCurrent;                // Pointer to current vertical pixel position on device
   LPINT    lpLineHeight;              // Pointer to number of pixels of height of current default font
}  SnapShot_PrinterStruct;
typedef SnapShot_PrinterStruct   FAR*  lpSnapShot_PrinterStruct;


typedef struct tagSnapShot_FileStruct  // 10
{
   int   wSize;                        // Sizeof(this struct)
   FBPTR hFile;                        // An open file
   BOOL  fAppend;                      // True if this file is not new,
                                       //    that is, it is in append mode.
}  SnapShot_FileStruct;
typedef SnapShot_FileStruct   FAR*  lpSnapShot_FileStruct;


//#define   DLT_SnapShot_Clipboard        11


typedef struct tagReadFromDisplayStruct// 12
{
   int   wSize;                        // Sizeof(this struct)
   int   colStart;                     // Beginning column
   int   rowStart;                     // Beginning row
   int   lenRead;                      // Number of characters to read
   LPSTR lpDest;                       // Pointer to destination string buffer
}  ReadFromDisplayStruct;
typedef ReadFromDisplayStruct FAR*  lpReadFromDisplayStruct;


typedef struct tagStartCaptureStruct   // 13
{
   int   wSize;                        // Sizeof(this struct)
   FBPTR hCaptureFile;                 // Open writable stream to write data to

   //
   // Type of capture file:
   //    0: Just as it looks on the screen, This implies it is captured
   //       as it scrolls off the screen.
   //
   //    1: Filtered, which is incoming data and CR, LF, FF, TAB, VERTAB
   //       chars, but no other control chars or any ESC sequences.
   //
   //    2: Raw, which is all incoming data that reaches the terminal with
   //       the exception of sequences which would cause the beginning of a
   //       file transfer.  The understanding of raw is that one could play
   //       back a raw captured file into the terminal and see exactly what
   //       was seen when the data actually came in.
   //
   int   nCaptureType;                 // Type of capture file:

}  StartCaptureStruct;
typedef StartCaptureStruct FAR*  lpStartCaptureStruct;


//#define   DLT_EndCapture                14
//#define   DLT_StartReplay               15
//#define   DLT_EndReplay                 16
//#define   DLT_PauseReplay               17
//#define   DLT_ContinueReplay            18


typedef struct tagTerminalWriteBufferStruct  // 19
{
   int   wSize;                        // Sizeof(this struct)
   int   colStart;                     // Beginning column
   int   rowStart;                     // Beginning row
   int   lenWrite;                     // Number of characters in the buffer
   LPSTR lpSrc;                        // Pointer to buffer
   BOOL  fUseRowCol;                   // Flag TRUE if the data must be written
                                       //    at colStart/rowStart.  If FALSE,
                                       //    the data can be written at the
                                       //    current position.
}  TerminalWriteBufferStruct;
typedef TerminalWriteBufferStruct   FAR*  lpTerminalWriteBufferStruct;


typedef struct tagDoAdvancedSetupDialogStruct   // 20
{
   int      wSize;                     // Sizeof(this struct)
   HWND     hWndParent;                // Handle to parent window of advanced setup dialog
   int      nEmulation;                // Emulation number to be set
   LPVOID   lpExtraBytes;              // Pointer to place to put data
   UINT     lenExtra;                  // Length of the ExtraBytes field.
   UINT     uExtraUsed;                // Number of bytes in ExtraBytes area actually used
}  DoAdvancedSetupDialogStruct;
typedef DoAdvancedSetupDialogStruct FAR*  lpDoAdvancedSetupDialogStruct;


//#define   DLT_Terminal                  21


typedef struct tagComputeScrollRangeStruct   // 22
{
   int      wSize;                     // Sizeof(this struct)
                                       // Input values:
   int      SB_type;                   //    SB_HORZ or SB_VERT: defines which scrollbar is being queried.
   RECT     rectAvail;                 //    Pixels available for the terminal window client area.
                                       // Returned values:
   int      iFontWidth;                //    Width (in pixels) of a character cell
   int      iFontHeight;               //    Height (in pixels) of a character cell
   WORD     wRows;                     //    Number of rows the .DLT requests
   WORD     wColumns;                  //    Number of columns the .DLT requests
   int      iMin;                      //    Low value of scrollbar range to set.  The range should be (0,0) if no scrollbar is needed.
   int      iMax;                      //    High value of scrollbar range to set.
   int      iPos;                      //    ScrollBar position to set.  It should be 0 if no scrollbar is needed.
}  ComputeScrollRangeStruct;
typedef ComputeScrollRangeStruct FAR*  lpComputeScrollRangeStruct;


//#define   DLT_SetupFinalSize            23
//#define   DLT_SetupCaret                24
//#define   DLT_RemoveCaret               25


//#define   DLT_QueryEscape               26
//#define   DLT_PerformEscape             27


typedef struct tagEscapeStruct         // 26 && 27
{
   int      wSize;                     // Sizeof(this struct)
   int      nEmulation;                // Which DLT emulation this call relates to.
   int      nAction;                   // What to do:
                                       //    0: On query, return the number of Escape options supported.
                                       //    0: On perform, reserved (do nothing).
                                       //    N: On query, requests that nReturnedValue be set to 1
                                       //       if the DLT supports this escape function, 0 otherwise.
                                       //    1: On perform, toggle VTX "hidden" attribute.
                                       //    2: On perform, toggle VTX "color" attribute.
   int      nReturnedValue;            // Returned value.  Generally return success or failure.
}  EscapeStruct;
typedef EscapeStruct FAR*  lpEscapeStruct;


typedef struct tagQueryStringStruct    // 28
{
   int      wSize;                     // Sizeof(this struct)
   int      nItem;                     // Which string item to return:
                                       //    1: The file extension, without the <.>, of the currently
                                       //       defined SnapShot_File format.  Typically, either
                                       //       TXT for ASCII type files, and BMP for bitmap files.
                                       //    All other values are currently undefined
   int      lenDest;                   // Length of the destination buffer.
   LPBYTE   lpDest;                    // Pointer to destination buffer into which to copy
                                       //    the string.  The string should be null terminated
                                       //    and truncated if necessary to fit into the buffer.
}  QueryStringStruct;
typedef QueryStringStruct  FAR*  lpQueryStringStruct;


//#define   DLT_TerminalChanged           29


typedef struct tagMenuNotification     // 30
{
   int      wSize;                     // Sizeof(this struct)
   WPARAM   wParam;                    // wParam of WM_COMMAND message
   LPARAM   lParam;                    // lParam of WM_COMMAND message
                                       // NOTE: this function should return 1
                                       //    if the message was handled and
                                       //    0 if not.
}  MenuNotificationStruct;
typedef MenuNotificationStruct   FAR*  lpMenuNotificationStruct;

typedef struct tagSpecialKeysStruct    // 31
{
   int      wSize;                     // Sizeof(this struct)
   int      nStrLen;                   // Length of string.
   LPSTR    lpKeyString;               // Text from keyboard or meta mapper.
   BYTE     cbDoPause;                 // Do special keys with pause.
   BYTE     cbDoRecord;                // Add character to record if applicable.
} SpecialKeysStruct;
typedef SpecialKeysStruct FAR * lpSpecialKeysStruct;


typedef struct tagQueryRowColInfoStruct   // 32
{
   int      wSize;                     // Sizeof(this struct)
   int      nType;                     // Type of query (store results in ptRetData):
                                       //    0 - Current location of cursor
                                       //    1 - number of current ROWS/COLS (1 based)
                                       //    2 - maximum 0-based ROW/COL values
                                       //
                                       //    The rest are currently undefined.
                                       //
   POINT    ptRetData;                 // Holds result of query.  Different meaning based
                                       //    on value of nType.
                                       //
                                       // NOTE: The return value from this function is >0
                                       //       if successful or 0 if failure (or not
                                       //       implemented).
} QueryRowColInfoStruct;
typedef QueryRowColInfoStruct FAR*  lpQueryRowColInfoStruct;

typedef struct tagTerminalPollExtStruct   // 33
{
   int      wSize;                     // Sizeof(this struct)
   DWORD    dwmsEnd;                   // Time to quit polling (set by PW, acknowledged by DLT)
}  TerminalPollExtStruct;
typedef TerminalPollExtStruct FAR*  lpTerminalPollExtStruct;

//#define   DLT_SnapShot_Mail             34

typedef struct tagSnapShot_CaptureStruct  // 35
{
   int   wSize;                        // Sizeof(this struct)
   FBPTR hCaptureFile;                 // Handle to open capture file
}  SnapShot_CaptureStruct;
typedef SnapShot_CaptureStruct   FAR*  lpSnapShot_CaptureStruct;

//#define   DLT_SnapShot_Fax              36

typedef struct tagSnapShot_Fax   // 36
{
   HDC      hdc;                       // HDC of fax driver
   HVXP     hvxp;                      // HVXP of fax driver (for VXPRINT.DLL usage).
   int      wSize;                     // Sizeof(this struct)
   LPRECT   lprPage;                   // Pointer to rectangle in pixels specifying the page boundaries of the printable page
   LPINT    lpxCurrent;                // Pointer to current horizontal pixel position on device
   LPINT    lpyCurrent;                // Pointer to current vertical pixel position on device
   LPINT    lpLineHeight;              // Pointer to number of pixels of height of current default font
}  SnapShot_FaxStruct;
typedef SnapShot_FaxStruct FAR*  lpSnapShot_FaxStruct;

#endif // _INC_XDLT
